@@ -159,8 +159,13 @@ private Q_SLOTS:
     void saveState( QSessionManager& sm ) {
         if (KDevelop::Core::self() && KDevelop::Core::self()->sessionController()) {
             QString x11SessionId = QString("%1_%2").arg(sm.sessionId()).arg(sm.sessionKey());
-            QString kdevelopSessionId = KDevelop::Core::self()->sessionController()->activeSession()->id().toString();
+            const auto activeSession = KDevelop::Core::self()->sessionController()->activeSession();
+            if (!activeSession) {
+                qWarning() << "No active session, can't save state";
+                return;
+            }
 
+            QString kdevelopSessionId = activeSession->id().toString();
             sm.setRestartCommand(QStringList() << QCoreApplication::applicationFilePath() << "-session" << x11SessionId << "-s" << kdevelopSessionId);
         }
     }
@@ -308,7 +313,8 @@ int main( int argc, char *argv[] )
 
     static const char description[] = I18N_NOOP( "The KDevelop Integrated Development Environment" );
     KAboutData aboutData( "kdevelop", i18n( "KDevelop" ), QByteArray(VERSION), i18n(description), KAboutLicense::GPL,
-                          i18n("Copyright 1999-2015, The KDevelop developers"), QString(), "http://www.kdevelop.org/");
+                          i18n("Copyright 1999-2016, The KDevelop developers"), QString(), "http://www.kdevelop.org/");
+    aboutData.setDesktopFileName(QStringLiteral("org.kde.kdevelop.desktop"));
     aboutData.addAuthor( i18n("Aleix Pol Gonzalez"), i18n( "Co-Maintainer, CMake Support, Run Support, Kross Support" ), "aleixpol@gmail.com" );
     aboutData.addAuthor( i18n("Milian Wolff"), i18n( "Co-Maintainer, C++/Clang, Generic manager, Webdevelopment Plugins, Snippets, Performance" ), "mail@milianw.de" );
     aboutData.addAuthor( i18n("Kevin Funk"), i18n( "C++/Clang, General Improvements, QA, Windows Support" ), "kfunk@kde.org" );
@@ -560,7 +566,19 @@ int main( int argc, char *argv[] )
             qerr << endl << i18nc("@info:shell", "Specify the binary you want to debug.") << endl;
             return 1;
         }
-        debugeeName = i18n("Debug %1", QUrl( debugArgs.first() ).fileName());
+
+        QFileInfo binaryInfo(debugArgs.first());
+        if (!binaryInfo.exists()) {
+            binaryInfo = QStandardPaths::findExecutable(debugArgs.first());
+            if (!binaryInfo.exists()) {
+                QTextStream qerr(stderr);
+                qerr << endl << i18nc("@info:shell", "Specified binary does not exist.") << endl;
+                return 1;
+            }
+        }
+
+        debugArgs.first() = binaryInfo.absoluteFilePath();
+        debugeeName = i18n("Debug %1", binaryInfo.fileName());
         session = debugeeName;
     } else if ( parser.isSet("new-session") )
     {
