@@ -192,7 +192,7 @@ void GDB::readyReadStandardOutput()
 void GDB::readyReadStandardError()
 {
     process_->setReadChannel(QProcess::StandardOutput);
-    emit internalCommandOutput(QString::fromUtf8(process_->readAll()));
+    emit debuggerInternalOutput(QString::fromUtf8(process_->readAll()));
 }
 
 void GDB::processLine(const QByteArray& line)
@@ -308,17 +308,16 @@ void GDB::processLine(const QByteArray& line)
 
             if (s.subkind == GDBMI::StreamRecord::Target) {
                 emit applicationOutput(s.message);
-            } else {
+            } else if (s.subkind == GDBMI::StreamRecord::Console) {
                 if (currentCmd_ && currentCmd_->isUserCommand())
                     emit userCommandOutput(s.message);
-                else if (s.subkind == GDBMI::StreamRecord::Console) {
-                    emit applicationOutput(s.message);
-                } else {
+                else
                     emit internalCommandOutput(s.message);
-                }
 
                 if (currentCmd_)
                     currentCmd_->newOutput(s.message);
+            } else {
+                emit debuggerInternalOutput(s.message);
             }
 
             emit streamRecord(s);
