@@ -2,6 +2,7 @@
     Copyright 2009 Aleix Pol <aleixpol@kde.org>
     Copyright 2009 David Nolden <david.nolden.kdevelop@art-master.de>
     Copyright 2010 Benjamin Port <port.benjamin@gmail.com>
+    Copyright 2016 Andreas Cord-Landwehr <cordlandwehr@kde.org>
 
     This library is free software; you can redistribute it and/or
     modify it under the terms of the GNU Library General Public
@@ -27,7 +28,7 @@
 #include <QStandardPaths>
 
 #include <KLocalizedString>
-#include <KProcess>
+#include <QProcess>
 
 #include <algorithm>
 
@@ -47,6 +48,7 @@ QString qmakeCandidate()
 
 QtHelpQtDoc::QtHelpQtDoc(QObject *parent, const QVariantList &args)
     : QtHelpProviderAbstract(parent, "qthelpcollection.qhc", args)
+    , m_path(QString())
 {
     Q_UNUSED(args);
     registerDocumentations();
@@ -56,49 +58,81 @@ void QtHelpQtDoc::registerDocumentations()
 {
     const QString qmake = qmakeCandidate();
     if (!qmake.isEmpty()) {
-        KProcess *p = new KProcess;
-        p->setOutputChannelMode(KProcess::MergedChannels);
-        p->setProgram(qmake, QStringList("-query") << "QT_INSTALL_DOCS");
+        QProcess *p = new QProcess;
+        p->setProcessChannelMode(QProcess::MergedChannels);
+        p->setProgram(qmake);
+        p->setArguments({QLatin1String("-query"), QLatin1String("QT_INSTALL_DOCS")});
         p->start();
-        connect(p, static_cast<void(KProcess::*)(int)>(&KProcess::finished), this, &QtHelpQtDoc::lookupDone);
+        connect(p, static_cast<void(QProcess::*)(int)>(&QProcess::finished), this, &QtHelpQtDoc::lookupDone);
     }
 }
 
 void QtHelpQtDoc::lookupDone(int code)
 {
-    if(code==0) {
-        KProcess* p = qobject_cast<KProcess*>(sender());
-
-        QString path = QDir::fromNativeSeparators(QString::fromLatin1(p->readAllStandardOutput().trimmed()));
-        qCDebug(QTHELP) << "Detected doc path:" << path;
-
-        if (!path.isEmpty()) {
-            loadDirectory(path);
-            loadDirectory(path+"/qch/");
-        }
+    QProcess *p = qobject_cast<QProcess*>(sender());
+    if(code == QProcess::NormalExit) {
+        m_path = QDir::fromNativeSeparators(QString::fromLatin1(p->readAllStandardOutput().trimmed()));
+        qCDebug(QTHELP) << "Detected doc path:" << m_path;
+    } else {
+        qCCritical(QTHELP) << "qmake query returned error:" << QString::fromLatin1(p->readAllStandardError());
+        qCDebug(QTHELP) << "last standard output was:" << QString::fromLatin1(p->readAllStandardOutput());
     }
+
     sender()->deleteLater();
 }
 
-void QtHelpQtDoc::loadDirectory(const QString& path)
+void QtHelpQtDoc::loadDocumentation()
 {
-    QDir d(path);
-    if(path.isEmpty() || !d.exists()) {
-        qCDebug(QTHELP) << "no QtHelp found at all";
+    if(m_path.isEmpty()) {
         return;
     }
 
-    foreach(const QString& file, d.entryList(QDir::Files)) {
-        QString fileName=path+'/'+file;
-        QString fileNamespace = QHelpEngineCore::namespaceName(fileName);
+    QStringList files = qchFiles();
+    if(files.isEmpty()) {
+        qCWarning(QTHELP) << "could not find QCH file in directory" << m_path;
+        return;
+    }
 
+    foreach(const QString &fileName, files) {
+        QString fileNamespace = QHelpEngineCore::namespaceName(fileName);
         if (!fileNamespace.isEmpty() && !m_engine.registeredDocumentations().contains(fileNamespace)) {
             qCDebug(QTHELP) << "loading doc" << fileName << fileNamespace;
             if(!m_engine.registerDocumentation(fileName))
-                qCDebug(QTHELP) << "error >> " << fileName << m_engine.error();
+                qCCritical(QTHELP) << "error >> " << fileName << m_engine.error();
         }
     }
-    qCDebug(QTHELP) << "registered" << m_engine.error() << m_engine.registeredDocumentations();
+}
+
+void QtHelpQtDoc::unloadDocumentation()
+{
+    foreach(const QString &fileName, qchFiles()) {
+        QString fileNamespace = QHelpEngineCore::namespaceName(fileName);
+        if(!fileName.isEmpty() && m_engine.registeredDocumentations().contains(fileNamespace)) {
+            m_engine.unregisterDocumentation(fileName);
+        }
+    }
+}
+
+QStringList QtHelpQtDoc::qchFiles() const
+{
+    QStringList files;
+
+    QVector<QString> paths; // test directories
+    paths << m_path << m_path+"/qch/";
+
+    foreach (const auto &path, paths) {
+        QDir d(path);
+        if(path.isEmpty() || !d.exists()) {
+            continue;
+        }
+        foreach(const auto& file, d.entryInfoList(QDir::Files)) {
+            files << file.absoluteFilePath();
+        }
+    }
+    if (files.isEmpty()) {
+        qCDebug(QTHELP) << "no QCH file found at all";
+    }
+    return files;
 }
 
 QIcon QtHelpQtDoc::icon() const
