@@ -25,29 +25,33 @@
 #include <KAboutData>
 #include <QTextStream>
 #include <QTemporaryFile>
-#include <KDebug>
+#include <QMimeDatabase>
 #include <KProcess>
 #include <interfaces/icore.h>
 #include <interfaces/isourceformattercontroller.h>
 #include <interfaces/isourceformatter.h>
 #include <memory>
 #include <QDir>
+#include <QLoggingCategory>
+Q_DECLARE_LOGGING_CATEGORY(CUSTOMSCRIPT)
+Q_LOGGING_CATEGORY(CUSTOMSCRIPT, "kdevelop.formatters.customscript")
+
 #include <util/formattinghelpers.h>
 #include <interfaces/iprojectcontroller.h>
 #include <interfaces/iproject.h>
 #include <KMessageBox>
 #include <interfaces/iuicontroller.h>
 #include <KParts/MainWindow>
+#include <KLocalizedString>
 #include <interfaces/ilanguagecontroller.h>
-#include <interfaces/ilanguage.h>
 #include <language/interfaces/ilanguagesupport.h>
+#include <util/path.h>
 
 using namespace KDevelop;
 
-static QWeakPointer<CustomScriptPlugin> indentPluginSingleton;
+static QPointer<CustomScriptPlugin> indentPluginSingleton;
 
-K_PLUGIN_FACTORY(CustomScriptFactory, registerPlugin<CustomScriptPlugin>();)
-K_EXPORT_PLUGIN(CustomScriptFactory(KAboutData("kdevcustomscript","kdevformatters", ki18n("Custom Script Formatter"), "0.2", ki18n("A formatter using custom scripts"), KAboutData::License_GPL)))
+K_PLUGIN_FACTORY_WITH_JSON(CustomScriptFactory, "kdevcustomscript.json", registerPlugin<CustomScriptPlugin>();)
 
 // Replaces ${KEY} in command with variables[KEY]
 static QString replaceVariables( QString command, QMap<QString, QString> variables )
@@ -59,12 +63,12 @@ static QString replaceVariables( QString command, QMap<QString, QString> variabl
 		if(end == -1)
 			break;
 		QString key = command.mid( pos+2, end-pos-2 );
-		
+
 		if( variables.contains( key ) )
 		{
 			command.replace( pos, 1 + end - pos, variables[key] );
 		}else{
-			kDebug() << "found no variable while replacing in shell-command" << command << "key" << key << "available:" << variables;
+			qCDebug(CUSTOMSCRIPT) << "found no variable while replacing in shell-command" << command << "key" << key << "available:" << variables;
 			command.replace( pos, 1 + end - pos, "" );
 		}
 	}
@@ -72,7 +76,7 @@ static QString replaceVariables( QString command, QMap<QString, QString> variabl
 }
 
 CustomScriptPlugin::CustomScriptPlugin(QObject *parent, const QVariantList&)
-		: IPlugin(CustomScriptFactory::componentData(), parent)
+	: IPlugin("kdevcustomscript", parent)
 {
 	KDEV_USE_EXTENSION_INTERFACE(ISourceFormatter)
         m_currentStyle = predefinedStyles().at(0);
@@ -105,11 +109,11 @@ QString CustomScriptPlugin::description()
 				"can be easily shared by all team members, independent of their preferred IDE.");
 }
 
-QString CustomScriptPlugin::formatSourceWithStyle(SourceFormatterStyle style, const QString& text, const KUrl& url, const KMimeType::Ptr& /*mime*/, const QString& leftContext, const QString& rightContext)
+QString CustomScriptPlugin::formatSourceWithStyle(SourceFormatterStyle style, const QString& text, const QUrl &url, const QMimeType& /*mime*/, const QString& leftContext, const QString& rightContext)
 {
 	KProcess proc;
 	QTextStream ios(&proc);
-	
+
 	std::unique_ptr<QTemporaryFile> tmpFile;
 
 	if (style.content().isEmpty())
@@ -117,67 +121,67 @@ QString CustomScriptPlugin::formatSourceWithStyle(SourceFormatterStyle style, co
 		style = predefinedStyle(style.name());
 		if (style.content().isEmpty())
 		{
-			kWarning() << "Empty contents for style" << style.name() << "for indent plugin";
+			qWarning() << "Empty contents for style" << style.name() << "for indent plugin";
 			return text;
 		}
 	}
-	
+
 	QString useText = text;
 	useText = leftContext + useText + rightContext;
-	
+
 	QMap<QString, QString> projectVariables;
 	foreach(IProject* project, ICore::self()->projectController()->projects())
-		projectVariables[project->name()] = project->folder().toLocalFile();
-	
+		projectVariables[project->name()] = project->path().toUrl().toLocalFile();
+
 	QString command = style.content();
-	
+
 	// Replace ${Project} with the project path
 	command = replaceVariables( command, projectVariables );
 	command.replace("$FILE", url.toLocalFile());
-	
+
 	if(command.contains("$TMPFILE"))
 	{
 		tmpFile.reset(new QTemporaryFile(QDir::tempPath() + "/code"));
 		tmpFile->setAutoRemove(false);
 		if(tmpFile->open())
 		{
-			kDebug() << "using temporary file" << tmpFile->fileName();
+			qCDebug(CUSTOMSCRIPT) << "using temporary file" << tmpFile->fileName();
 			command.replace("$TMPFILE", tmpFile->fileName());
 			QByteArray useTextArray = useText.toLocal8Bit();
 			if( tmpFile->write(useTextArray) != useTextArray.size() )
 			{
-				kWarning() << "failed to write text to temporary file";
+				qWarning() << "failed to write text to temporary file";
 				return text;
 			}
-			
+
 		}else{
-			kWarning() << "Failed to create a temporary file";
+			qWarning() << "Failed to create a temporary file";
 			return text;
 		}
 		tmpFile->close();
 	}
-	
-	kDebug() << "using shell command for indentation: " << command;
+
+	qCDebug(CUSTOMSCRIPT) << "using shell command for indentation: " << command;
 	proc.setShellCommand(command);
 	proc.setOutputChannelMode(KProcess::OnlyStdoutChannel);
-	
+
 	proc.start();
 	if(!proc.waitForStarted()) {
-		kDebug() << "Unable to start indent" << endl;
+		qCDebug(CUSTOMSCRIPT) << "Unable to start indent" << endl;
 		return text;
 	}
-	
+
 	if(!tmpFile.get())
 		proc.write(useText.toLocal8Bit());
-	
+
 	proc.closeWriteChannel();
 	if(!proc.waitForFinished()) {
-		kDebug() << "Process doesn't finish" << endl;
+		qCDebug(CUSTOMSCRIPT) << "Process doesn't finish" << endl;
 		return text;
 	}
-	
+
 	QString output;
-	
+
 	if(tmpFile.get())
 	{
 		QFile f(tmpFile->fileName());
@@ -185,7 +189,7 @@ QString CustomScriptPlugin::formatSourceWithStyle(SourceFormatterStyle style, co
 		{
 			output = QString::fromLocal8Bit(f.readAll());
 		}else{
-			kWarning() << "Failed opening the temporary file for reading";
+			qWarning() << "Failed opening the temporary file for reading";
 			return text;
 		}
 	}else{
@@ -193,7 +197,7 @@ QString CustomScriptPlugin::formatSourceWithStyle(SourceFormatterStyle style, co
 	}
 	if (output.isEmpty())
 	{
-		kWarning() << "indent returned empty text for style" << style.name() << style.content();
+		qWarning() << "indent returned empty text for style" << style.name() << style.content();
 		return text;
 	}
 
@@ -210,15 +214,15 @@ QString CustomScriptPlugin::formatSourceWithStyle(SourceFormatterStyle style, co
     return KDevelop::extractFormattedTextFromContext(output, text, leftContext, rightContext, tabWidth);
 }
 
-QString CustomScriptPlugin::formatSource(const QString& text, const KUrl& url, const KMimeType::Ptr& mime, const QString& leftContext, const QString& rightContext)
+QString CustomScriptPlugin::formatSource(const QString& text, const QUrl &url, const QMimeType& mime, const QString& leftContext, const QString& rightContext)
 {
 	return formatSourceWithStyle( KDevelop::ICore::self()->sourceFormatterController()->styleForMimeType( mime ), text, url, mime, leftContext, rightContext );
 }
 
 static QList<SourceFormatterStyle> stylesFromLanguagePlugins() {
 	QList<KDevelop::SourceFormatterStyle> styles;
-	for ( ILanguage* lang: ICore::self()->languageController()->loadedLanguages() ) {
-		SourceFormatterItemList languageStyles = lang->languageSupport()->sourceFormatterItems();
+	foreach (auto lang, ICore::self()->languageController()->loadedLanguages()) {
+		const SourceFormatterItemList& languageStyles = lang->sourceFormatterItems();
 		for ( const SourceFormatterStyleItem& item: languageStyles ) {
 			if ( item.engine == "customscript" ) {
 				styles << item.style;
@@ -231,7 +235,7 @@ static QList<SourceFormatterStyle> stylesFromLanguagePlugins() {
 KDevelop::SourceFormatterStyle CustomScriptPlugin::predefinedStyle(const QString& name)
 {
 	for ( auto langStyle: stylesFromLanguagePlugins() ) {
-		qDebug() << "looking at style from language with custom sample" << langStyle.description() << langStyle.overrideSample();
+		qCDebug(CUSTOMSCRIPT) << "looking at style from language with custom sample" << langStyle.description() << langStyle.overrideSample();
 		if ( langStyle.name() == name ) {
 			return langStyle;
 		}
@@ -253,7 +257,7 @@ KDevelop::SourceFormatterStyle CustomScriptPlugin::predefinedStyle(const QString
 		result.setUsePreview(false);
 		result.setDescription(i18n( "Description:<br />"
 									"<b>kdev_format_source</b> is a script bundled with KDevelop "
-			                        "which allows using fine-grained formatting rules by placing "   
+			                        "which allows using fine-grained formatting rules by placing "
 									"meta-files called <b>format_sources</b> into the file-system.<br /><br />"
 									"Each line of the <b>format_sources</b> files defines a list of wildcards "
 									"followed by a colon and the used formatting-command.<br /><br />"
@@ -268,8 +272,11 @@ KDevelop::SourceFormatterStyle CustomScriptPlugin::predefinedStyle(const QString
 									"This will reformat all files in subdirectory <b>subdir</b> using the <b>uncrustify</b> "
 									"tool with the config-file <b>uncrustify.config</b>." ));
 	}
-	using P = SourceFormatterStyle::MimeHighlightPair;
-	result.setMimeTypes(SourceFormatterStyle::MimeList() << P{"text/x-c++src", "C++"} << P{"text/x-c++hdr", "C++"});
+	result.setMimeTypes({
+		{"text/x-c++src", "C++"}, {"text/x-chdr", "C"},
+		{"text/x-c++hdr", "C++"}, {"text/x-csrc", "C"},
+		{"text/x-java", "Java"}, {"text/x-csharp", "C#"}
+	});
 	return result;
 }
 
@@ -283,7 +290,7 @@ QList<KDevelop::SourceFormatterStyle> CustomScriptPlugin::predefinedStyles()
 	return styles;
 }
 
-KDevelop::SettingsWidget* CustomScriptPlugin::editStyleWidget(const KMimeType::Ptr &mime)
+KDevelop::SettingsWidget* CustomScriptPlugin::editStyleWidget(const QMimeType& mime)
 {
 	Q_UNUSED(mime);
 	return new CustomScriptPreferences();
@@ -291,7 +298,7 @@ KDevelop::SettingsWidget* CustomScriptPlugin::editStyleWidget(const KMimeType::P
 
 static QString formattingSample()
 {
-    return 
+    return
     "// Formatting\n"
 	"void func(){\n"
     "\tif(isFoo(a,b))\n"
@@ -379,7 +386,7 @@ static QString indentingSample()
     "\tbarArg3);\n";
 }
 
-QString CustomScriptPlugin::previewText(const SourceFormatterStyle& style, const KMimeType::Ptr& mime)
+QString CustomScriptPlugin::previewText(const SourceFormatterStyle& style, const QMimeType& /*mime*/)
 {
 	if ( ! style.overrideSample().isEmpty() ) {
 		return style.overrideSample();
@@ -388,16 +395,16 @@ QString CustomScriptPlugin::previewText(const SourceFormatterStyle& style, const
 }
 
 
-QStringList CustomScriptPlugin::computeIndentationFromSample( const KUrl& url )
+QStringList CustomScriptPlugin::computeIndentationFromSample( const QUrl &url )
 {
 	QStringList ret;
 
-    QList<ILanguage*> lang = ICore::self()->languageController()->languagesForUrl( url );
-    if( lang.isEmpty() )
+    auto languages = ICore::self()->languageController()->languagesForUrl( url );
+    if (languages.isEmpty())
         return ret;
 
-    QString sample = lang[0]->languageSupport()->indentationSample();
-    QString formattedSample = formatSource( sample, url, KMimeType::findByUrl( url ), QString(), QString() );
+    QString sample = languages[0]->indentationSample();
+    QString formattedSample = formatSource(sample, url, QMimeDatabase().mimeTypeForUrl(url), QString(), QString());
 
     QStringList lines = formattedSample.split( "\n" );
     foreach( QString line, lines )
@@ -416,17 +423,17 @@ QStringList CustomScriptPlugin::computeIndentationFromSample( const KUrl& url )
 			ret.push_back(indent);
 	  }
 	}
-	
+
 	return ret;
 }
 
-CustomScriptPlugin::Indentation CustomScriptPlugin::indentation( const KUrl& url )
+CustomScriptPlugin::Indentation CustomScriptPlugin::indentation( const QUrl &url )
 {
     Indentation ret;
     QStringList indent = computeIndentationFromSample( url );
     if( indent.isEmpty() )
     {
-        kDebug() << "failed extracting a valid indentation from sample for url" << url;
+        qCDebug(CUSTOMSCRIPT) << "failed extracting a valid indentation from sample for url" << url;
         return ret; // No valid indentation could be extracted
     }
 
@@ -435,7 +442,7 @@ CustomScriptPlugin::Indentation CustomScriptPlugin::indentation( const KUrl& url
 
 	if( !indent.join("").contains('	') )
 		ret.indentationTabWidth = -1; // Tabs are not used for indentation
-	
+
 	if( indent[0] == "	" )
 	{
 		// The script indents with tabs-only
@@ -451,7 +458,7 @@ CustomScriptPlugin::Indentation CustomScriptPlugin::indentation( const KUrl& url
 		// Tabs are used for indentation, alongside with spaces
 		// Try finding out how many spaces one tab stands for.
 		// Do it by assuming a uniform indentation-step with each level.
-		
+
 		for(int pos = 0; pos < indent.size(); ++pos)
 		{
 			if(indent[pos] == "	" && pos >= 1)
@@ -460,26 +467,26 @@ CustomScriptPlugin::Indentation CustomScriptPlugin::indentation( const KUrl& url
 				int prevWidth = indent[pos-1].length();
 				int prevPrevWidth = (pos >= 2) ? indent[pos-2].length() : 0;
 				int step = prevWidth - prevPrevWidth;
-				kDebug() << "found in line " << pos << prevWidth << prevPrevWidth << step;
+				qCDebug(CUSTOMSCRIPT) << "found in line " << pos << prevWidth << prevPrevWidth << step;
 				if(step > 0 && step <= prevWidth)
 				{
-					kDebug() << "Done";
+					qCDebug(CUSTOMSCRIPT) << "Done";
 					ret.indentationTabWidth = prevWidth + step;
 					break;
 				}
 			}
 		}
 	}
-    
-    kDebug() << "indent-sample" << "\"" + indent.join("\n") + "\"" << "extracted tab-width" << ret.indentationTabWidth << "extracted indentation width" << ret.indentWidth;
-    
+
+    qCDebug(CUSTOMSCRIPT) << "indent-sample" << "\"" + indent.join("\n") + "\"" << "extracted tab-width" << ret.indentationTabWidth << "extracted indentation width" << ret.indentWidth;
+
     return ret;
 }
 
 void CustomScriptPreferences::updateTimeout()
 {
-	const QString& text = indentPluginSingleton.data()->previewText ( m_style, KMimeType::Ptr() );
-    QString formatted = indentPluginSingleton.data()->formatSourceWithStyle ( m_style, text, KUrl(), KMimeType::Ptr() );
+	const QString& text = indentPluginSingleton.data()->previewText(m_style, QMimeType());
+    QString formatted = indentPluginSingleton.data()->formatSourceWithStyle(m_style, text, QUrl(), QMimeType());
     emit previewTextChanged ( formatted );
 }
 
@@ -487,7 +494,7 @@ CustomScriptPreferences::CustomScriptPreferences()
 {
     m_updateTimer = new QTimer ( this );
     m_updateTimer->setSingleShot ( true );
-    connect ( m_updateTimer, SIGNAL (timeout()), SLOT (updateTimeout()) );
+    connect ( m_updateTimer, &QTimer::timeout, this, &CustomScriptPreferences::updateTimeout );
     m_vLayout = new QVBoxLayout ( this );
     m_captionLabel = new QLabel;
     m_vLayout->addWidget ( m_captionLabel );
@@ -511,14 +518,14 @@ CustomScriptPreferences::CustomScriptPreferences()
 			   "<br />"
                "If you add <b>$TMPFILE</b> into the command, then <br />"
                "a temporary file is used for transferring the code." ) );
-    connect ( m_commandEdit, SIGNAL (textEdited(QString)), SLOT (textEdited(QString)) );
+    connect ( m_commandEdit, &QLineEdit::textEdited, this, &CustomScriptPreferences::textEdited );
 
 	m_vLayout->addSpacing ( 10 );
 
 	m_moreVariablesButton = new QPushButton( i18n("More Variables") );
-	connect( m_moreVariablesButton, SIGNAL(clicked(bool)), SLOT(moreVariablesClicked(bool)) );
+	connect( m_moreVariablesButton, &QPushButton::clicked, this, &CustomScriptPreferences::moreVariablesClicked );
 	m_vLayout->addWidget( m_moreVariablesButton );
-	
+
 }
 
 void CustomScriptPreferences::load ( const KDevelop::SourceFormatterStyle& style )
@@ -549,7 +556,7 @@ void CustomScriptPreferences::moreVariablesClicked ( bool )
 		 "<br />"
 		 "<b>${PROJECT_NAME}</b> will be replaced by the path of <br />"
 		 "the currently open project with the matching name."
-			
+
 	), i18n("Variable Replacements") );
 }
 
