@@ -54,7 +54,7 @@
 #include "util/clangtypes.h"
 
 #include "clangsupport.h"
-#include "documentfinderhelpers.h"
+#include "duchain/documentfinderhelpers.h"
 
 #include <QFile>
 #include <QStringList>
@@ -170,7 +170,7 @@ ClangParseJob::ClangParseJob(const IndexedString& url, ILanguageSupport* languag
     } else {
         m_environment.addIncludes(IDefinesAndIncludesManager::manager()->includes(tuUrl.str()));
         m_environment.addDefines(IDefinesAndIncludesManager::manager()->defines(tuUrl.str()));
-        m_environment.setParserSettings(ClangSettingsManager::self()->parserSettings(nullptr));
+        m_environment.setParserSettings(ClangSettingsManager::self()->parserSettings(tuUrl.str()));
     }
     const bool isSource = ClangHelpers::isSource(tuUrl.str());
     m_environment.setQuality(
@@ -189,7 +189,9 @@ ClangParseJob::ClangParseJob(const IndexedString& url, ILanguageSupport* languag
 
     foreach(auto document, ICore::self()->documentController()->openDocuments()) {
         auto textDocument = document->textDocument();
-        if (!textDocument || !textDocument->isModified() || !textDocument->url().isLocalFile()
+        // TODO: Introduce a cache so we don't have to re-read all the open documents
+        // which were not changed since the last run
+        if (!textDocument || !textDocument->url().isLocalFile()
             || !DocumentFinderHelpers::mimeTypesList().contains(textDocument->mimeType()))
         {
             continue;
@@ -197,6 +199,9 @@ ClangParseJob::ClangParseJob(const IndexedString& url, ILanguageSupport* languag
         m_unsavedFiles << UnsavedFile(textDocument->url().toLocalFile(), textDocument->textLines(textDocument->documentRange()));
         const IndexedString indexedUrl(textDocument->url());
         m_unsavedRevisions.insert(indexedUrl, ModificationRevision::revisionForFile(indexedUrl));
+        if (indexedUrl == tuUrl) {
+            m_tuDocumentIsUnsaved = true;
+        }
     }
 
     if (auto tracker = trackerForUrl(url)) {
@@ -219,6 +224,13 @@ void ClangParseJob::run(ThreadWeaver::JobPointer /*self*/, ThreadWeaver::Thread*
 
     {
         const auto tuUrlStr = m_environment.translationUnitUrl().str();
+        if (!m_tuDocumentIsUnsaved && !QFile::exists(tuUrlStr)) {
+            // maybe we requested a parse job some time ago but now the file
+            // does not exist anymore. return early then
+            clang()->index()->unpinTranslationUnitForUrl(document());
+            return;
+        }
+
         m_environment.addIncludes(IDefinesAndIncludesManager::manager()->includesInBackground(tuUrlStr));
         m_environment.addDefines(IDefinesAndIncludesManager::manager()->definesInBackground(tuUrlStr));
         m_environment.setPchInclude(userDefinedPchIncludeForFile(tuUrlStr));
@@ -304,7 +316,8 @@ void ClangParseJob::run(ThreadWeaver::JobPointer /*self*/, ThreadWeaver::Thread*
     }
 
     auto context = ClangHelpers::buildDUChain(session.mainFile(), imports, session,
-                                              minimumFeatures(), includedFiles, clang()->index());
+                                              minimumFeatures(), includedFiles,
+                                              clang()->index(), [this] { return abortRequested(); });
     setDuChain(context);
 
     if (abortRequested()) {
