@@ -41,6 +41,7 @@
 #include <interfaces/idocumentcontroller.h>
 #include <language/interfaces/iastcontainer.h>
 
+#include "codegen/clangrefactoring.h"
 #include "codegen/adaptsignatureassistant.h"
 #include "duchain/documentfinderhelpers.h"
 #include "duchain/clangindex.h"
@@ -53,7 +54,6 @@
 #include <language/assistant/renameassistant.h>
 #include <language/backgroundparser/backgroundparser.h>
 #include <language/codecompletion/codecompletion.h>
-#include <language/codegen/basicrefactoring.h>
 #include <language/highlighting/codehighlighting.h>
 #include <language/interfaces/editorcontext.h>
 #include <language/duchain/duchainlock.h>
@@ -184,7 +184,7 @@ ClangSupport::ClangSupport(QObject* parent, const QVariantList& )
     ClangIntegration::DUChainUtils::registerDUChainItems();
 
     m_highlighting = new ClangHighlighting(this);
-    m_refactoring = new BasicRefactoring(this);
+    m_refactoring = new ClangRefactoring(this);
     m_index.reset(new ClangIndex);
 
     auto model = new KDevelop::CodeCompletion( this, new ClangCodeCompletionModel(m_index.data(), this), name() );
@@ -277,7 +277,13 @@ void ClangSupport::createActionsForMainWindow (Sublime::MainWindow* /*window*/,
     renameDeclarationAction->setIcon(QIcon::fromTheme(QStringLiteral("edit-rename")));
     actions.setDefaultShortcut(renameDeclarationAction, Qt::CTRL | Qt::SHIFT | Qt::Key_R);
     connect(renameDeclarationAction, &QAction::triggered,
-            m_refactoring, &BasicRefactoring::executeRenameAction);
+            m_refactoring, &ClangRefactoring::executeRenameAction);
+
+    QAction* moveIntoSourceAction = actions.addAction(QStringLiteral("code_move_definition"));
+    moveIntoSourceAction->setText(i18n("Move into Source"));
+    actions.setDefaultShortcut(moveIntoSourceAction, Qt::CTRL | Qt::ALT | Qt::Key_S);
+    connect(moveIntoSourceAction, &QAction::triggered,
+            m_refactoring, &ClangRefactoring::executeMoveIntoSourceAction);
 }
 
 KDevelop::ContextMenuExtension ClangSupport::contextMenuExtension(KDevelop::Context* context)
@@ -400,6 +406,15 @@ static void setKeywordCompletion(KTextEditor::View* view, bool enabled)
     }
 }
 
+int ClangSupport::suggestedReparseDelayForChange(KTextEditor::Document* /*doc*/, const KTextEditor::Range& /*changedRange*/,
+                                                 const QString& changedText, bool /*removal*/) const
+{
+    if ( changedText.contains(QLatin1Char('\n')) || changedText.contains(QLatin1Char(';')) ) {
+        return ILanguageSupport::DefaultDelay;
+    }
+    return 3000;
+}
+
 void ClangSupport::disableKeywordCompletion(KTextEditor::View* view)
 {
     setKeywordCompletion(view, false);
