@@ -32,15 +32,16 @@
 #include <QVariantList>
 
 class ClangIndex;
+class ClangRefactoring;
 namespace KDevelop
 {
-class BasicRefactoring;
 class IDocument;
 }
 
 namespace KTextEditor
 {
 class View;
+class Document;
 }
 
 class ClangSupport : public KDevelop::IPlugin, public KDevelop::ILanguageSupport, public KDevelop::IBuddyDocumentFinder
@@ -77,6 +78,9 @@ public:
 
     int configPages() const override;
 
+    int suggestedReparseDelayForChange(KTextEditor::Document* doc, const KTextEditor::Range& changedRange,
+                                       const QString& changedText, bool removal) const override;
+
     //BEGIN IBuddyDocumentFinder
 
     bool areBuddies(const QUrl &url1, const QUrl& url2) override;
@@ -92,7 +96,7 @@ private slots:
 
 private:
     KDevelop::ICodeHighlighting *m_highlighting;
-    KDevelop::BasicRefactoring *m_refactoring;
+    ClangRefactoring *m_refactoring;
     QScopedPointer<ClangIndex> m_index;
 };
 
