@@ -23,32 +23,34 @@
 #ifndef CLANGPROBLEM_H
 #define CLANGPROBLEM_H
 
-#include <duchain/clangduchainexport.h>
+#include "clangprivateexport.h"
 
 #include <language/duchain/problem.h>
 #include <interfaces/iassistant.h>
 
 #include <clang-c/Index.h>
 
-struct KDEVCLANGDUCHAIN_EXPORT ClangFixit
+struct KDEVCLANGPRIVATE_EXPORT ClangFixit
 {
     QString replacementText;
     KDevelop::DocumentRange range;
     QString description;
+    QString currentText;
 
     bool operator==(const ClangFixit& other) const
     {
         return replacementText == other.replacementText
             && range == other.range
-            && description == other.description;
+            && description == other.description
+            && currentText == other.currentText;
     }
 };
 
-QDebug KDEVCLANGDUCHAIN_EXPORT operator<<(QDebug debug, const ClangFixit& fixit);
+QDebug KDEVCLANGPRIVATE_EXPORT operator<<(QDebug debug, const ClangFixit& fixit);
 
 using ClangFixits = QVector<ClangFixit>;
 
-class KDEVCLANGDUCHAIN_EXPORT ClangProblem : public KDevelop::Problem
+class KDEVCLANGPRIVATE_EXPORT ClangProblem : public KDevelop::Problem
 {
 public:
     using Ptr = QExplicitlySharedDataPointer<ClangProblem>;
@@ -78,7 +80,7 @@ private:
 };
 
 
-class KDEVCLANGDUCHAIN_EXPORT ClangFixitAssistant : public KDevelop::IAssistant
+class KDEVCLANGPRIVATE_EXPORT ClangFixitAssistant : public KDevelop::IAssistant
 {
     Q_OBJECT
 
@@ -97,7 +99,7 @@ private:
     ClangFixits m_fixits;
 };
 
-class KDEVCLANGDUCHAIN_EXPORT ClangFixitAction : public KDevelop::IAssistantAction
+class KDEVCLANGPRIVATE_EXPORT ClangFixitAction : public KDevelop::IAssistantAction
 {
     Q_OBJECT
 
