@@ -74,7 +74,7 @@ QVector<QByteArray> argsForSession(const QString& path, ParseSessionData::Option
 
     if (parserSettings.parserOptions.isEmpty()) {
         // The parserOptions can be empty for some unit tests that use ParseSession directly
-        auto defaultArguments = ClangSettingsManager::self()->parserSettings(nullptr).toClangAPI();
+        auto defaultArguments = ClangSettingsManager::self()->parserSettings(path).toClangAPI();
         Q_ASSERT(!defaultArguments.isEmpty());
         defaultArguments.append(QByteArrayLiteral("-nostdinc"));
         defaultArguments.append(QByteArrayLiteral("-nostdinc++"));
@@ -84,7 +84,9 @@ QVector<QByteArray> argsForSession(const QString& path, ParseSessionData::Option
 
     auto result = parserSettings.toClangAPI();
     result.append(QByteArrayLiteral("-nostdinc"));
-    result.append(QByteArrayLiteral("-nostdinc++"));
+    if (parserSettings.isCpp()) {
+        result.append(QByteArrayLiteral("-nostdinc++"));
+    }
 
     if (options & ParseSessionData::PrecompiledHeader) {
         result.append(parserSettings.isCpp() ? QByteArrayLiteral("-xc++-header") : QByteArrayLiteral("-xc-header"));
@@ -134,6 +136,13 @@ bool needGccCompatibility(const ClangParsingEnvironment& environment)
         && !environment.defines().contains(QStringLiteral("__clang__"));
 }
 
+bool hasQtIncludes(const Path::List& includePaths)
+{
+    return std::find_if(includePaths.begin(), includePaths.end(), [] (const Path& path) {
+        return path.lastPathSegment() == QLatin1String("QtCore");
+    }) != includePaths.end();
+}
+
 }
 
 ParseSessionData::ParseSessionData(const QVector<UnsavedFile>& unsavedFiles, ClangIndex* index,
@@ -142,7 +151,11 @@ ParseSessionData::ParseSessionData(const QVector<UnsavedFile>& unsavedFiles, Cla
     , m_unit(nullptr)
 {
     unsigned int flags = CXTranslationUnit_CXXChainedPCH
-        | CXTranslationUnit_DetailedPreprocessingRecord;
+        | CXTranslationUnit_DetailedPreprocessingRecord
+#if CINDEX_VERSION_MINOR >= 34
+        | CXTranslationUnit_KeepGoing
+#endif
+    ;
     if (options.testFlag(SkipFunctionBodies)) {
         flags |= CXTranslationUnit_SkipFunctionBodies;
     }
@@ -185,22 +198,29 @@ ParseSessionData::ParseSessionData(const QVector<UnsavedFile>& unsavedFiles, Cla
 
     if (needGccCompatibility(environment)) {
         const auto compatFile = QStandardPaths::locate(QStandardPaths::GenericDataLocation, QStringLiteral("kdevclangsupport/gcc_compat.h")).toUtf8();
-        smartArgs << compatFile;
-        clangArguments << "-include" << compatFile.constData();
+        if (!compatFile.isEmpty()) {
+            smartArgs << compatFile;
+            clangArguments << "-include" << compatFile.constData();
+        }
+    }
+
+    if (hasQtIncludes(includes.system)) {
+        const auto wrappedQtHeaders = QStandardPaths::locate(QStandardPaths::GenericDataLocation,
+                                                             QStringLiteral("kdevclangsupport/wrappedQtHeaders"),
+                                                             QStandardPaths::LocateDirectory).toUtf8();
+        if (!wrappedQtHeaders.isEmpty()) {
+            smartArgs << wrappedQtHeaders;
+            clangArguments << "-isystem" << wrappedQtHeaders.constData();
+            const auto qtCore = wrappedQtHeaders + "/QtCore";
+            smartArgs << qtCore;
+            clangArguments << "-isystem" << qtCore.constData();
+        }
     }
 
     addIncludes(&clangArguments, &smartArgs, includes.system, "-isystem");
     addIncludes(&clangArguments, &smartArgs, includes.project, "-I");
 
-    m_definesFile.open();
-    QTextStream definesStream(&m_definesFile);
-    Q_ASSERT(m_definesFile.isWritable());
-    const auto& defines = environment.defines();
-    for (auto it = defines.begin(); it != defines.end(); ++it) {
-        definesStream << QStringLiteral("#define ") << it.key() << ' ' << it.value() << '\n';
-    }
-    definesStream.flush();
-    smartArgs << m_definesFile.fileName().toUtf8();
+    smartArgs << writeDefinesFile(environment.defines());
     clangArguments << "-imacros" << smartArgs.last().constData();
 
     // append extra args from environment variable
@@ -216,13 +236,13 @@ ParseSessionData::ParseSessionData(const QVector<UnsavedFile>& unsavedFiles, Cla
     }
 
     // debugging: print hypothetical clang invocation including args (for easy c&p for local testing)
-    {
-        auto dbg = qDebug(KDEV_CLANG);
-        dbg << "Invocation: clang";
+    if (qEnvironmentVariableIsSet("KDEV_CLANG_DISPLAY_ARGS")) {
+        QTextStream out(stdout);
+        out << "Invocation: clang";
         foreach (const auto& arg, clangArguments) {
-            dbg << arg;
+            out << " " << arg;
         }
-        dbg << tuUrl.byteArray().constData();
+        out << " " << tuUrl.byteArray().constData() << "\n";
     }
 
     const CXErrorCode code = clang_parseTranslationUnit2(
@@ -256,13 +276,30 @@ ParseSessionData::~ParseSessionData()
     clang_disposeTranslationUnit(m_unit);
 }
 
+QByteArray ParseSessionData::writeDefinesFile(const QMap<QString, QString>& defines)
+{
+    m_definesFile.open();
+    Q_ASSERT(m_definesFile.isWritable());
+
+    QTextStream definesStream(&m_definesFile);
+    // don't show warnings about redefined macros
+    definesStream << "#pragma clang system_header\n";
+    for (auto it = defines.begin(); it != defines.end(); ++it) {
+        definesStream << QStringLiteral("#define ") << it.key() << ' ' << it.value() << '\n';
+    }
+
+    return m_definesFile.fileName().toUtf8();
+}
+
 void ParseSessionData::setUnit(CXTranslationUnit unit)
 {
-    Q_ASSERT(!m_unit || unit == m_unit);
-
     m_unit = unit;
-    const ClangString unitFile(clang_getTranslationUnitSpelling(unit));
-    m_file = clang_getFile(m_unit, unitFile.c_str());
+    if (m_unit) {
+        const ClangString unitFile(clang_getTranslationUnitSpelling(unit));
+        m_file = clang_getFile(m_unit, unitFile.c_str());
+    } else {
+        m_file = nullptr;
+    }
 }
 
 ClangParsingEnvironment ParseSessionData::environment() const
@@ -332,7 +369,9 @@ QList<ProblemPointer> ParseSession::problemsForFile(CXFile file) const
         CXSourceLocation location = clang_getDiagnosticLocation(diagnostic);
         CXFile diagnosticFile;
         clang_getFileLocation(location, &diagnosticFile, nullptr, nullptr, nullptr);
-        if (diagnosticFile != file) {
+        // missing-include problems are so severe in clang that we always propagate
+        // them to this document, to ensure that the user will see the error.
+        if (diagnosticFile != file && ClangDiagnosticEvaluator::diagnosticType(diagnostic) != ClangDiagnosticEvaluator::IncludeFileNotFoundProblem) {
             continue;
         }
 
@@ -393,12 +432,19 @@ bool ParseSession::reparse(const QVector<UnsavedFile>& unsavedFiles, const Clang
 
     auto unsaved = toClangApi(unsavedFiles);
 
-    if (clang_reparseTranslationUnit(d->m_unit, unsaved.size(), unsaved.data(), clang_defaultReparseOptions(d->m_unit)) == 0) {
-        d->setUnit(d->m_unit);
-        return true;
-    } else {
+    const auto code = clang_reparseTranslationUnit(d->m_unit, unsaved.size(), unsaved.data(),
+                                                   clang_defaultReparseOptions(d->m_unit));
+    if (code != CXError_Success) {
+        qWarning() << "clang_reparseTranslationUnit return with error code" << code;
+        // if error code != 0 => clang_reparseTranslationUnit invalidates the old translation unit => clean up
+        clang_disposeTranslationUnit(d->m_unit);
+        d->setUnit(nullptr);
         return false;
     }
+
+    // update state
+    d->setUnit(d->m_unit);
+    return true;
 }
 
 ClangParsingEnvironment ParseSession::environment() const
