@@ -22,10 +22,12 @@
  */
 
 #include "test_codecompletion.h"
+#include <language/backgroundparser/backgroundparser.h>
 
 #include <tests/testcore.h>
 #include <tests/autotestshell.h>
 #include <tests/testfile.h>
+#include <tests/testproject.h>
 
 #include "duchain/parsesession.h"
 #include "util/clangtypes.h"
@@ -46,6 +48,8 @@
 #include <KTextEditor/Document>
 #include <KTextEditor/View>
 
+#include <KConfigGroup>
+
 QTEST_MAIN(TestCodeCompletion);
 
 static const auto NoMacroOrBuiltin = ClangCodeCompletionContext::ContextFilters(
@@ -117,8 +121,12 @@ void executeCompletionTest(const ReferencedTopDUContext& top, const CompletionIt
     const ParseSessionData::Ptr sessionData(dynamic_cast<ParseSessionData*>(top->ast().data()));
     QVERIFY(sessionData);
     lock.unlock();
+    QString text;
+    if (auto doc = ICore::self()->documentController()->documentForUrl(top->url().toUrl())) {
+        text = doc->textDocument()->text({{0, 0}, expectedCompletionItems.position});
+    }
     // TODO: We should not need to pass 'session' to the context, should just use the base class ctor
-    auto context = new ClangCodeCompletionContext(DUContextPointer(top), sessionData, top->url().toUrl(), expectedCompletionItems.position, QString());
+    auto context = new ClangCodeCompletionContext(DUContextPointer(top), sessionData, top->url().toUrl(), expectedCompletionItems.position, text);
     context->setFilters(filters);
     lock.lock();
 
@@ -138,7 +146,12 @@ void executeCompletionTest(const ReferencedTopDUContext& top, const CompletionIt
     tester.names.sort();
     QEXPECT_FAIL("look-ahead function primary type argument", "No API in LibClang to determine expected code completion type", Continue);
     QEXPECT_FAIL("look-ahead template parameter substitution", "No parameters substitution so far", Continue);
+#if CINDEX_VERSION_MINOR < 30
     QEXPECT_FAIL("look-ahead auto item", "Auto type, like many other types, is not exposed through LibClang. We assign DelayedType to it instead of IdentifiedType", Continue);
+#endif
+    if (QTest::currentTestFunction() == QByteArrayLiteral("testImplementAfterEdit") && expectedCompletionItems.position.line() == 3) {
+        QEXPECT_FAIL("", "TU is not properly updated after edit", Continue);
+    }
     if (tester.names.size() != expectedCompletionItems.completions.size()) {
         qDebug() << "different results:\nactual:" << tester.names << "\nexpected:" << expectedCompletionItems.completions;
     }
@@ -217,15 +230,23 @@ void executeMemberAccessReplacerTest(const QString& code, const CompletionItems&
 
     lock.unlock();
 
-    auto context = new ClangCodeCompletionContext(topPtr, sessionData, file.url().toUrl(), expectedCompletionItems.position, code);
+    QExplicitlySharedDataPointer<ClangCodeCompletionContext> context(
+        new ClangCodeCompletionContext(topPtr, sessionData, file.url().toUrl(),
+                                       expectedCompletionItems.position, code));
 
     QApplication::processEvents();
     document->close(KDevelop::IDocument::Silent);
+
     // The previous ClangCodeCompletionContext call should replace member access.
-    context = new ClangCodeCompletionContext(topPtr, sessionData, file.url().toUrl(), expectedCompletionItems.position, QString());
+    // That triggers an update request in the duchain which we are not interested in,
+    // so let's stop that request.
+    ICore::self()->languageController()->backgroundParser()->removeDocument(file.url());
+
+    context = new ClangCodeCompletionContext(topPtr, sessionData, file.url().toUrl(),
+                                             expectedCompletionItems.position, QString());
     context->setFilters(filters);
     lock.lock();
-    auto tester = ClangCodeCompletionItemTester(QExplicitlySharedDataPointer<ClangCodeCompletionContext>(context));
+    auto tester = ClangCodeCompletionItemTester(context);
 
     tester.names.sort();
     QCOMPARE(tester.names, expectedCompletionItems.completions);
@@ -451,8 +472,18 @@ void TestCodeCompletion::testClangCodeCompletion_data()
             "LookAhead",
             "i",
             "instance",
-            "instance.intItem"
+            "instance.intItem",
+            "main"
         }};
+
+    QTest::newRow("variadic template recursive class")
+        << R"(
+template <typename Head, typename ...Tail>
+struct my_class : Head, my_class<Tail...>
+{
+    using base = Head;
+};)"
+        << CompletionItems{{3, 17}, { "Head", "Tail", "my_class" }};
 }
 
 void TestCodeCompletion::testReplaceMemberAccess()
@@ -538,6 +569,18 @@ void TestCodeCompletion::testVirtualOverride_data()
         << "class Foo { virtual void foo(const int b) const; virtual void overridden(const int b) const; }\n;"
            "class Bar : Foo \n{void overridden(const int b) const override;\n}"
         << CompletionItems{{3, 1}, {"foo(const int b) const"}};
+
+    QTest::newRow("dont-override")
+        << R"(class A {
+                  virtual void something() = 0;
+              };
+              class B : public A
+              {
+              public:
+                  void foo();
+              };
+              void B::foo() {}
+        )" << CompletionItems{{8, 14}, {}};
 }
 
 void TestCodeCompletion::testImplement()
@@ -708,8 +751,6 @@ void TestCodeCompletion::testImplement_data()
         << "int x();\n"
            "int x(int)=  delete;\n"
         << CompletionItems{{2,1}, {"x()"}};
-    // FIXME: the rage seems to be wrong here (stops after =), but I don't know how to fix that
-    // QDEBUG : TestCodeCompletion::testImplement(deleted-overload-global) default: "int x(int)=" contains "=\\s*delete\\s*;" = false
     QTest::newRow("defaulted-copy-ctor")
         << "struct S { S(); S(const S&) = default; };"
         << CompletionItems{{1,1}, {"S::S()"}};
@@ -746,6 +787,20 @@ void TestCodeCompletion::testImplement_data()
                 };
             )"
         << CompletionItems{{8,0}, {"Hello::Private::test()"}};
+
+    QTest::newRow("lineOfNextFunction")
+        << "void foo();\nvoid bar() {}"
+        << CompletionItems{{1,0}, {"foo()"}};
+
+    QTest::newRow("pure")
+        << R"(
+                struct Hello {
+                    virtual void foo() = 0;
+                    virtual void bar();
+                };
+            )"
+        << CompletionItems{{5, 0}, {"Hello::bar()"}};
+
 }
 
 void TestCodeCompletion::testImplementOtherFile()
@@ -766,6 +821,30 @@ void TestCodeCompletion::testImplementOtherFile()
     executeCompletionTest(impl.topContext(), expectedItems);
 }
 
+void TestCodeCompletion::testImplementAfterEdit()
+{
+    TestFile header1("void foo();", "h");
+    QVERIFY(header1.parseAndWait());
+    TestFile impl(QString("#include \"%1\"\n"
+                          "void asdf() {}\nvoid bar() {}")
+                    .arg(header1.url().str()),
+                  "cpp", &header1);
+
+    auto document = ICore::self()->documentController()->openDocument(impl.url().toUrl());
+
+    QVERIFY(impl.parseAndWait(TopDUContext::AllDeclarationsContextsUsesAndAST));
+
+    CompletionItems expectedItems{{2,0}, {"foo()"}};
+    executeCompletionTest(impl.topContext(), expectedItems);
+
+    document->textDocument()->insertText(expectedItems.position, "\n");
+    expectedItems.position.setLine(3);
+
+    executeCompletionTest(impl.topContext(), expectedItems);
+
+    document->close(IDocument::Discard);
+}
+
 void TestCodeCompletion::testInvalidCompletions()
 {
     QFETCH(QString, code);
@@ -1121,3 +1200,23 @@ void TestCodeCompletion::testCompleteFunction_data()
         << "main"
         << "int foo();\nint main() {\nmain();\n}";
 }
+
+void TestCodeCompletion::testIgnoreGccBuiltins()
+{
+    // TODO: make it easier to change the compiler provider for testing purposes
+    QTemporaryDir dir;
+    auto project = new TestProject(Path(dir.path()), this);
+    auto definesAndIncludesConfig = project->projectConfiguration()->group("CustomDefinesAndIncludes");
+    auto pathConfig = definesAndIncludesConfig.group("ProjectPath0");
+    pathConfig.writeEntry("Path", ".");
+    pathConfig.group("Compiler").writeEntry("Name", "GCC");
+    m_projectController->addProject(project);
+
+    {
+        TestFile file("", "cpp", project, dir.path());
+
+        QVERIFY(file.parseAndWait(TopDUContext::AllDeclarationsContextsUsesAndAST));
+
+        executeCompletionTest(file.topContext(), {});
+    }
+}
