@@ -51,6 +51,7 @@ void TestFiles::initTestCase()
 
     QLoggingCategory::setFilterRules(QStringLiteral("*.debug=false\ndefault.debug=true\nkdevelop.plugins.clang.debug=true\n"));
     QVERIFY(qputenv("KDEV_DISABLE_PLUGINS", "kdevcppsupport"));
+    QVERIFY(qputenv("KDEV_CLANG_DISPLAY_DIAGS", "1"));
     AutoTestShell::init({"kdevclangsupport"});
     TestCore::initialize(Core::NoUi);
     DUChain::self()->disablePersistentStorage();
@@ -90,7 +91,6 @@ void TestFiles::testFiles()
     }
 
     if (!QTest::currentDataTag() || strcmp("invalid.cpp", QTest::currentDataTag()) != 0) {
-        QEXPECT_FAIL("purec.c", "not working properly yet", Continue);
         QVERIFY(top->problems().isEmpty());
     }
 }
