@@ -49,8 +49,8 @@
 #include "../cppduchain/templatedeclaration.h"
 #include "../cpplanguagesupport.h"
 #include "../cpputils.h"
-#include "../cppduchain/environmentmanager.h"
-#include "../cppduchain/cppduchain.h"
+#include "../debug.h"
+
 
 #include "cppdebughelper.h"
 #include "missingincludeitem.h"
@@ -66,8 +66,8 @@
 
 #define LOCKDUCHAIN     DUChainReadLocker lock(DUChain::lock())
 #include <cpputils.h>
-#include <interfaces/ilanguage.h>
-#include <interfaces/foregroundlock.h>
+#include <util/foregroundlock.h>
+#include <util/path.h>
 #include <interfaces/icore.h>
 #include <interfaces/ilanguagecontroller.h>
 
@@ -84,7 +84,7 @@ const int CONTEXT_LINES = 20;
 ///Maximum number of parent contexts
 const int MAX_DEPTH = 10;
 
-/** 
+/**
  * ACCESS_STRINGS are used to determine the special properties of the context.
  * Any alphanum_ word not appearing in ACCESS_STRINGS will be considered an expression.
  * Expressions that fail evaluation invalidate their context and have no completions.
@@ -137,23 +137,23 @@ struct MainThreadHelper : public QObject
   Q_OBJECT
 
   public slots:
-    void replaceCurrentAccess(const KUrl& url, const QString& oldAccess, const QString& newAccess);
+    void replaceCurrentAccess(const QUrl &url, const QString& oldAccess, const QString& newAccess);
 };
 
-void MainThreadHelper::replaceCurrentAccess(const KUrl& url, const QString& oldAccess, const QString& newAccess)
+void MainThreadHelper::replaceCurrentAccess(const QUrl &url, const QString& oldAccess, const QString& newAccess)
 {
   IDocument* document = ICore::self()->documentController()->documentForUrl(url);
   if(document) {
-    KTextEditor::Document* textDocument = document->textDocument();
-    if(textDocument) {
-      KTextEditor::View* activeView = textDocument->activeView();
-      if(activeView) {
+    KTextEditor::View* activeView = document->activeTextView();
+    if(activeView) {
+      KTextEditor::Document* textDocument = activeView->document();
+      if(textDocument) {
         KTextEditor::Cursor cursor = activeView->cursorPosition();
 
-        static KUrl lastUrl;
+        static QUrl lastUrl;
         static KTextEditor::Cursor lastPos;
         if(lastUrl == url && lastPos == cursor) {
-          kDebug() << "Not doing the same access replacement twice at" << lastUrl << lastPos;
+          qCDebug(CPP) << "Not doing the same access replacement twice at" << lastUrl << lastPos;
           return;
         }
         lastUrl = url;
@@ -235,7 +235,7 @@ QString getEndingFromSet( const QString &str, const QSet<QString> &set, int maxM
       return end;
   }
 
-  return QString();  
+  return QString();
 }
 
 QString getEndFunctionOperator( const QString &str ) {
@@ -416,7 +416,7 @@ Declaration* containerDeclForType(const AbstractType::Ptr& givenType, TopDUConte
   if (TypeAliasType::Ptr typeAliasType = givenType.cast<TypeAliasType>())
     return containerDeclForType(typeAliasType->type(), top, typeIsPointer);
 
-  if (const IdentifiedType* identifiedType = dynamic_cast<const IdentifiedType*>(givenType.unsafeData()))
+  if (const IdentifiedType* identifiedType = dynamic_cast<const IdentifiedType*>(givenType.data()))
   {
     if (Declaration *ret = identifiedType->declaration(top))
     {
@@ -494,7 +494,7 @@ CodeCompletionContext( KDevelop::DUContextPointer context, const QString& text,
 
     if ( m_accessType == BinaryOpFunctionCallAccess )
       m_operator = getEndFunctionOperator( accessStr );
- 
+
     if( !m_expression.isEmpty() && !m_expressionResult.isValid() )
       m_functionName = m_expression; //set m_functionName for Missing Include Completion
   }
@@ -540,7 +540,7 @@ void CodeCompletionContext::processArrowMemberAccess() {
 
   //Look for "->" operator
   AbstractType::Ptr realContainer = TypeUtils::realType( containerType, m_duContext->topContext() );
-  IdentifiedType* idType = dynamic_cast<IdentifiedType*>( realContainer.unsafeData() );
+  IdentifiedType* idType = dynamic_cast<IdentifiedType*>( realContainer.data() );
   if ( !idType ) {
     m_valid = false;
     return;
@@ -783,7 +783,7 @@ bool CodeCompletionContext::doConstructorCompletion() {
 
   QStringList hadItems;
 
-  ifDebug( kDebug() << "text:" << text; )
+  ifDebug( qCDebug(CPP) << "text:" << text; )
 
   //Jump over all initializers
   while(!text.isEmpty() && text.endsWith(',')) {
@@ -791,72 +791,72 @@ bool CodeCompletionContext::doConstructorCompletion() {
     //Skip initializer expression
     int start_expr = expressionBefore( text, text.length() );
     QString skip = text.mid(start_expr, text.length() - start_expr);
-    
+
     if(skip.contains('('))
       hadItems << skip.left(skip.indexOf('(')).trimmed();
-    
+
     text = text.left(start_expr).trimmed();
   }
-  
+
   if(!text.trimmed().endsWith(':'))
     return false;
 
   text = text.left(text.length()-1).trimmed();
   //Now we have the declaration in text
-  ifDebug( kDebug() << "should be decl.:" << text; )
+  ifDebug( qCDebug(CPP) << "should be decl.:" << text; )
   if(!text.endsWith(')'))
     return false;
-  
+
   int argumentsStart = text.length()-1;
   QStringList arguments;
   skipFunctionArguments(text, arguments, argumentsStart);
   if(argumentsStart <= 0)
     return false;
-  
+
   int identifierStart = expressionBefore( text, argumentsStart-1 );
   if(identifierStart < 0 || identifierStart == argumentsStart)
     return false;
-  
+
   m_text = QString();
-  
+
   QualifiedIdentifier id(text.mid(identifierStart, argumentsStart-1-identifierStart));
   if(id.isEmpty())
     return false;
   id = id.left(id.count()-1);
-  
+
   DUContext* container = 0;
-  
+
   if(!id.isEmpty()) {
     //Find the class
     QList< KDevelop::Declaration* > decls = m_duContext->findDeclarations(id);
     if(decls.isEmpty()) {
-      ifDebug( kDebug() << "did not find class declaration for" << id.toString(); )
+      ifDebug( qCDebug(CPP) << "did not find class declaration for" << id.toString(); )
       return false;
     }
     container = decls[0]->logicalInternalContext(m_duContext->topContext());
   }else if(m_duContext->parentContext() && m_duContext->parentContext()->type() == DUContext::Class && m_duContext->parentContext()->owner()) {
     container = m_duContext->parentContext();
   }
-  
+
   if(!container)
     return false;
-  
+
   m_onlyShow = ShowVariables;
   m_isConstructorCompletion = true;
   m_accessType = MemberAccess;
   m_doAccessFiltering = false;
-  
+
   QSet<QString> hadItemsSet = hadItems.toSet();
-  
+
   QList<CompletionTreeItemPointer> items;
-  
+
   int pos = 1000;
   bool initializedNormalItems = false;
-  
+
   //Pre-compute the items
   foreach(Declaration* decl, container->localDeclarations(m_duContext->topContext())) {
     ClassMemberDeclaration* classMem = dynamic_cast<ClassMemberDeclaration*>(decl);
-    
+
     if(decl->kind() == Declaration::Instance && !decl->isFunctionDeclaration() && classMem && !classMem->isStatic()) {
       if(!hadItemsSet.contains(decl->identifier().toString())) {
         items << CompletionTreeItemPointer(new NormalDeclarationCompletionItem( DeclarationPointer(decl), KDevelop::CodeCompletionContext::Ptr(this), pos ));
@@ -878,10 +878,10 @@ bool CodeCompletionContext::doConstructorCompletion() {
       }
     }
   }
-  
-  
+
+
   eventuallyAddGroup(i18n("Initialize"), 0, items);
-  
+
   return true;
   ///Step 1: Skip to the ':', to find the back of the function declaration. On the way, all expressions need to be constructor decls.
 }
@@ -976,7 +976,7 @@ findExpressionAndPrefix(QString& expression, QString& expressionPrefix, bool &is
   }
 
   //Add reference and dereference operators to expression
-  QString op; 
+  QString op;
   while ( true ) {
     op = getUnaryOperator(expressionPrefix);
     if (op == "*" || op == "&") {
@@ -1055,7 +1055,7 @@ void CodeCompletionContext::processFunctionCallAccess() {
     helper.setOperator(OverloadResolver::Parameter(m_expressionResult.type.abstractType(), m_expressionResult.isLValue()));
 
     m_functionName = "operator"+m_operator;
-    
+
   } else {
     ///Simply take all the declarations that were found by the expression-parser
 
@@ -1070,7 +1070,7 @@ void CodeCompletionContext::processFunctionCallAccess() {
 
   if( m_accessType == BinaryOpFunctionCallAccess || m_expression == m_functionName )
     helper.setFunctionNameForADL( QualifiedIdentifier(m_functionName) );
-  
+
   OverloadResolver::ParameterList knownParameters;
   foreach( const ExpressionEvaluationResult &result, m_knownArgumentTypes )
     knownParameters.parameters << OverloadResolver::Parameter( result.type.abstractType(), result.isLValue() );
@@ -1108,8 +1108,8 @@ bool CodeCompletionContext::doIncludeCompletion()
 
   //Strip away #include
   line = line.mid(endOfInclude).trimmed();
-  
-  kDebug(9007) << "trimmed include line: " << line;
+
+  qCDebug(CPP) << "trimmed include line: " << line;
 
   if(!line.startsWith('<') && !line.startsWith('"'))
     return true; //We are not behind the beginning of a path-specification
@@ -1117,16 +1117,14 @@ bool CodeCompletionContext::doIncludeCompletion()
   const bool local = line.startsWith('"');
   line = line.mid(1);
 
-  kDebug(9007) << "extract prefix from " << line;
+  qCDebug(CPP) << "extract prefix from " << line;
   //Extract the prefix-path
-  KUrl u(line);
 
   QString prefixPath;
   if(line.contains('/')) {
-    u.setFileName(QString());
-    prefixPath = u.toLocalFile();
+    prefixPath = Path(line).parent().toLocalFile();
   }
-  kDebug(9007) << "extracted prefix " << prefixPath;
+  qCDebug(CPP) << "extracted prefix " << prefixPath;
 
 #ifndef TEST_COMPLETION
   m_includeItems = CppUtils::allFilesInIncludePath(m_duContext->url().str(), local, prefixPath);
@@ -1179,7 +1177,7 @@ QSet<DUContext*> CodeCompletionContext::memberAccessContainers() const {
 
   if(m_expressionResult.isValid() ) {
     AbstractType::Ptr expressionTarget = TypeUtils::targetType(m_expressionResult.type.abstractType(), m_duContext->topContext());
-    const IdentifiedType* idType = dynamic_cast<const IdentifiedType*>( expressionTarget.unsafeData() );
+    const IdentifiedType* idType = dynamic_cast<const IdentifiedType*>( expressionTarget.data() );
       Declaration* idDecl = 0;
     if( idType && (idDecl = idType->declaration(m_duContext->topContext())) ) {
       DUContext* ctx = idDecl->logicalInternalContext(m_duContext->topContext());
@@ -1188,21 +1186,21 @@ QSet<DUContext*> CodeCompletionContext::memberAccessContainers() const {
           ret.insert(ctx);
       }else {
         //Print some debug-output
-        kDebug(9007) << "Could not get internal context from" << m_expressionResult.type.abstractType()->toString();
-        kDebug(9007) << "Declaration" << idDecl->toString() << idDecl->isForwardDeclaration();
+        qCDebug(CPP) << "Could not get internal context from" << m_expressionResult.type.abstractType()->toString();
+        qCDebug(CPP) << "Declaration" << idDecl->toString() << idDecl->isForwardDeclaration();
         if( Cpp::TemplateDeclaration* tempDeclaration = dynamic_cast<Cpp::TemplateDeclaration*>(idDecl) ) {
           if( tempDeclaration->instantiatedFrom() ) {
-            kDebug(9007) << "instantiated from" << dynamic_cast<Declaration*>(tempDeclaration->instantiatedFrom())->toString() << dynamic_cast<Declaration*>(tempDeclaration->instantiatedFrom())->isForwardDeclaration();
-            kDebug(9007) << "internal context" << dynamic_cast<Declaration*>(tempDeclaration->instantiatedFrom())->internalContext();
+            qCDebug(CPP) << "instantiated from" << dynamic_cast<Declaration*>(tempDeclaration->instantiatedFrom())->toString() << dynamic_cast<Declaration*>(tempDeclaration->instantiatedFrom())->isForwardDeclaration();
+            qCDebug(CPP) << "internal context" << dynamic_cast<Declaration*>(tempDeclaration->instantiatedFrom())->internalContext();
           }
         }
 
       }
     }
   }
-  
+
 //   foreach(DUContext* context, ret) {
-//     kDebug() << "member-access container:" << context->url().str() << context->range().textRange() << context->scopeIdentifier(true).toString();
+//     qCDebug(CPP) << "member-access container:" << context->url().str() << context->range() << context->scopeIdentifier(true).toString();
 //   }
 
   return ret;
@@ -1225,7 +1223,7 @@ bool CodeCompletionContext::isValidPosition() {
 
   if( markedText[markedText.length()-1] == '$' ) {
     //We are within a comment or string
-    kDebug(9007) << "code-completion position is invalid, marked text: \n\"" << markedText << "\"\n unmarked text:\n" << m_text << "\n";
+    qCDebug(CPP) << "code-completion position is invalid, marked text: \n\"" << markedText << "\"\n unmarked text:\n" << m_text << "\n";
     return false;
   }
   return true;
@@ -1247,15 +1245,13 @@ bool CodeCompletionContext::isImplementationHelperValid() const
                                  m_duContext->type() == DUContext::Global) );
 }
 
-static TopDUContext* proxyContextForUrl(KUrl url)
+static TopDUContext* proxyContextForUrl(QUrl url)
 {
-  QList< ILanguage* > languages = ICore::self()->languageController()->languagesForUrl(url);
-  foreach(ILanguage* language, languages)
-  {
-    if(language->languageSupport())
-      return language->languageSupport()->standardContext(url, true);
+  auto languages = ICore::self()->languageController()->languagesForUrl(url);
+  foreach (auto language, languages) {
+      return language->standardContext(url, true);
   }
-  
+
   return 0;
 }
 
@@ -1283,13 +1279,14 @@ CodeCompletionContext::AccessType CodeCompletionContext::accessType() const {
 }
 
 CodeCompletionContext* CodeCompletionContext::parentContext() const {
-  return KSharedPtr<CodeCompletionContext>::staticCast(m_parentContext).data();
+  return static_cast<CodeCompletionContext*>(m_parentContext.data());
 }
 
 void getOverridable(DUContext* base, DUContext* current, QMap< QPair<IndexedType, IndexedString>, KDevelop::CompletionTreeItemPointer >& overridable, CodeCompletionContext::Ptr completionContext, int depth = 0) {
-  if(!current)
+  const int maxDepth = 5000;
+  if(!current || (depth > maxDepth))
     return;
-  
+
   foreach(Declaration* decl, current->localDeclarations()) {
     ClassFunctionDeclaration* classFun = dynamic_cast<ClassFunctionDeclaration*>(decl);
     // one can only override the direct parent's ctor
@@ -1312,7 +1309,7 @@ void getOverridable(DUContext* base, DUContext* current, QMap< QPair<IndexedType
 
 // #ifndef TEST_COMPLETION
 
-QList< KSharedPtr< KDevelop::CompletionTreeElement > > CodeCompletionContext::ungroupedElements() {
+QList< QExplicitlySharedDataPointer< KDevelop::CompletionTreeElement > > CodeCompletionContext::ungroupedElements() {
   return m_storedUngroupedItems;
 }
 
@@ -1330,10 +1327,10 @@ QList<CompletionTreeItemPointer> CodeCompletionContext::memberAccessCompletionIt
     typeIsConst = true;
 
   QSet<DUContext*> containers = memberAccessContainers();
-  ifDebug( kDebug() << "got" << containers.size() << "member-access containers"; )
+  ifDebug( qCDebug(CPP) << "got" << containers.size() << "member-access containers"; )
   if (containers.isEmpty())
   {
-    ifDebug( kDebug() << "missing-include completion for" << m_expression << m_expressionResult.toString(); )
+    ifDebug( qCDebug(CPP) << "missing-include completion for" << m_expression << m_expressionResult.toString(); )
     lock.unlock();
     eventuallyAddGroup(i18n("Not Included"), 700, missingIncludeCompletionItems(m_expression, QString(), m_expressionResult, m_duContext, 0, true ));
   }
@@ -1344,7 +1341,7 @@ QList<CompletionTreeItemPointer> CodeCompletionContext::memberAccessCompletionIt
   foreach(DUContext* ctx, containers) {
     if (shouldAbort)
       return items;
-    ifDebug( kDebug() << "container:" << ctx->scopeIdentifier(true).toString(); )
+    ifDebug( qCDebug(CPP) << "container:" << ctx->scopeIdentifier(true).toString(); )
 
     QList<DeclarationDepthPair> decls = ctx->allDeclarations(ctx->range().end, m_duContext->topContext(), false );
     decls += namespaceItems(ctx, ctx->range().end, false, containers);
@@ -1411,7 +1408,7 @@ QList<CompletionTreeItemPointer> CodeCompletionContext::returnAccessCompletionIt
 
   AbstractType::Ptr returnType = functionReturnType(m_duContext.data());
   if (returnType)
-    items << CompletionTreeItemPointer( new TypeConversionCompletionItem( "return " + returnType->toString(), returnType->indexed(), depth(), KSharedPtr <Cpp::CodeCompletionContext >(this) ) );
+    items << CompletionTreeItemPointer( new TypeConversionCompletionItem( "return " + returnType->toString(), returnType->indexed(), depth(), Cpp::CodeCompletionContext::Ptr(this) ) );
   return items;
 }
 
@@ -1443,7 +1440,7 @@ QList<CompletionTreeItemPointer> CodeCompletionContext::caseAccessCompletionItem
   LOCKDUCHAIN; if (!m_duContext) return items;
 
   if (switchExprType.abstractType())
-    items << CompletionTreeItemPointer( new TypeConversionCompletionItem( "case " + switchExprType.abstractType()->toString(), switchExprType, depth(), KSharedPtr <Cpp::CodeCompletionContext >(this) ) );
+    items << CompletionTreeItemPointer( new TypeConversionCompletionItem( "case " + switchExprType.abstractType()->toString(), switchExprType, depth(), Cpp::CodeCompletionContext::Ptr(this) ) );
   return items;
 }
 
@@ -1453,7 +1450,7 @@ QList<CompletionTreeItemPointer> CodeCompletionContext::templateAccessCompletion
   LOCKDUCHAIN; if (!m_duContext) return items;
 
   AbstractType::Ptr type = m_expressionResult.type.abstractType();
-  IdentifiedType* identified = dynamic_cast<IdentifiedType*>(type.unsafeData());
+  IdentifiedType* identified = dynamic_cast<IdentifiedType*>(type.data());
   Declaration* decl = 0;
   if(identified)
     decl = identified->declaration( m_duContext->topContext());
@@ -1527,7 +1524,7 @@ QList< CompletionTreeItemPointer > CodeCompletionContext::binaryFunctionAccessCo
     IntegralType::Ptr t(new IntegralType(IntegralType::TypeInt));
     t->setModifiers(IntegralType::UnsignedModifier);
     QString showName = "operator []";
-    items << CompletionTreeItemPointer( new TypeConversionCompletionItem( showName, t->indexed(), depth(), KSharedPtr <Cpp::CodeCompletionContext >(this) ) );
+    items << CompletionTreeItemPointer( new TypeConversionCompletionItem( showName, t->indexed(), depth(), Cpp::CodeCompletionContext::Ptr(this) ) );
   }
 
   if( m_operator == "=" || integral ) {
@@ -1542,7 +1539,7 @@ QList< CompletionTreeItemPointer > CodeCompletionContext::binaryFunctionAccessCo
       if(decl)
         showName = decl->toString() + " " + m_operator;
     }
-    items << CompletionTreeItemPointer( new TypeConversionCompletionItem( showName, useType, depth(), KSharedPtr <Cpp::CodeCompletionContext >(this) ) );
+    items << CompletionTreeItemPointer( new TypeConversionCompletionItem( showName, useType, depth(), Cpp::CodeCompletionContext::Ptr(this) ) );
   }
 
   return items;
@@ -1567,7 +1564,7 @@ QList<CompletionTreeItemPointer> CodeCompletionContext::functionAccessCompletion
       m_knownArgumentExpressions.isEmpty())
   {
       QString showName = m_expressionResult.type.abstractType()->toString() + "(";
-      items << CompletionTreeItemPointer( new TypeConversionCompletionItem( showName, m_expressionResult.type, depth(), KSharedPtr <Cpp::CodeCompletionContext >(this) ) );
+      items << CompletionTreeItemPointer( new TypeConversionCompletionItem( showName, m_expressionResult.type, depth(), Cpp::CodeCompletionContext::Ptr(this) ) );
   }
 
   return items;
@@ -1599,7 +1596,7 @@ QList<CompletionTreeItemPointer> CodeCompletionContext::signalSlotAccessCompleti
     if(parentContext() && parentContext()->m_knownArgumentTypes.count() > 1 && parentContext()->m_knownArgumentTypes[0].type.isValid()) {
       StructureType::Ptr signalContainerType = TypeUtils::targetType(parentContext()->m_knownArgumentTypes[0].type.abstractType(), m_duContext->topContext()).cast<StructureType>();
       if(signalContainerType) {
-//             kDebug() << "searching signal in container" << signalContainerType->toString() << m_connectedSignalIdentifier.toString();
+//             qCDebug(CPP) << "searching signal in container" << signalContainerType->toString() << m_connectedSignalIdentifier.toString();
           Declaration* signalContainer = signalContainerType->declaration(m_duContext->topContext());
         if(signalContainer && signalContainer->internalContext()) {
           IndexedString signature(m_connectedSignalNormalizedSignature);
@@ -1627,7 +1624,7 @@ QList<CompletionTreeItemPointer> CodeCompletionContext::signalSlotAccessCompleti
     QList<CompletionTreeItemPointer> signalSlots;
     ///Collect all slots/signals to show
     AbstractType::Ptr type = memberAccessContainer().type.abstractType();
-    IdentifiedType* identified = dynamic_cast<IdentifiedType*>(type.unsafeData());
+    IdentifiedType* identified = dynamic_cast<IdentifiedType*>(type.data());
     if(identified) {
       Declaration* decl = identified->declaration(m_duContext->topContext());
       if(decl && decl->internalContext() /*&& Cpp::findLocalDeclarations(decl->internalContext(), Identifier("QObject"), m_duContext->topContext()).count()*/) { //hacky test whether it's a QObject
@@ -1840,7 +1837,7 @@ QList<DeclarationDepthPair> CodeCompletionContext::namespaceItems(DUContext* duC
     if(aliasDecl) {
       ids.insert(aliasDecl->importIdentifier());
     }else{
-      kDebug() << "Import is not based on NamespaceAliasDeclaration";
+      qCDebug(CPP) << "Import is not based on NamespaceAliasDeclaration";
     }
   }
 
@@ -1886,7 +1883,7 @@ QList< CompletionTreeItemPointer > CodeCompletionContext::standardAccessCompleti
 
   QList<DeclarationDepthPair> oldDecls = decls;
   decls.clear();
-  
+
   //Remove pure function-definitions before doing overload-resolution, so they don't hide their own declarations.
   foreach( const DeclarationDepthPair& decl, oldDecls )
     if(!dynamic_cast<FunctionDefinition*>(decl.first) || !static_cast<FunctionDefinition*>(decl.first)->hasDeclaration()) {
@@ -1894,7 +1891,7 @@ QList< CompletionTreeItemPointer > CodeCompletionContext::standardAccessCompleti
         QualifiedIdentifier id = decl.first->qualifiedIdentifier();
         if(hadNamespaceDeclarations.contains(id))
           continue;
-        
+
         hadNamespaceDeclarations.insert(id);
       }
 
@@ -1902,7 +1899,7 @@ QList< CompletionTreeItemPointer > CodeCompletionContext::standardAccessCompleti
         decls << decl;
       }
     }
-    
+
   decls = Cpp::hideOverloadedDeclarations(decls, typeIsConst);
 
   foreach( const DeclarationDepthPair& decl, decls ) {
@@ -1964,7 +1961,7 @@ void CodeCompletionContext::addCPPBuiltin()
     PointerType::Ptr thisPointer(new PointerType());
     thisPointer->setModifiers(AbstractType::ConstModifier);
     thisPointer->setBaseType(classType);
-    KSharedPtr<TypeConversionCompletionItem> item( new TypeConversionCompletionItem("this", thisPointer->indexed(), 0, KSharedPtr <Cpp::CodeCompletionContext >(this)) );
+    QExplicitlySharedDataPointer<TypeConversionCompletionItem> item( new TypeConversionCompletionItem("this", thisPointer->indexed(), 0, Cpp::CodeCompletionContext::Ptr(this)) );
     item->setPrefix(thisPointer->toString());
     QList<CompletionTreeItemPointer> lst;
     lst += CompletionTreeItemPointer(item.data());
@@ -2106,8 +2103,8 @@ QList<CompletionTreeItemPointer> CodeCompletionContext::getImplementationHelpers
     ret += getImplementationHelpersInternal(m_duContext->scopeIdentifier(true), searchInContext);
 
   if(!CppUtils::isHeader( searchInContext->url().toUrl() )) {
-    KUrl headerUrl = CppUtils::sourceOrHeaderCandidate( searchInContext->url().str(), false );
-    searchInContext = ICore::self()->languageController()->language("C++")->languageSupport()->standardContext(headerUrl);
+    QUrl headerUrl = QUrl::fromLocalFile(CppUtils::sourceOrHeaderCandidate( searchInContext->url().str(), false ));
+    searchInContext = ICore::self()->languageController()->language("C++")->standardContext(headerUrl);
     if(searchInContext)
       ret += getImplementationHelpersInternal(m_duContext->scopeIdentifier(true), searchInContext);
   }
@@ -2137,7 +2134,7 @@ QList<CompletionTreeItemPointer> CodeCompletionContext::getImplementationHelpers
     ret << KDevelop::CompletionTreeItemPointer(
       new ImplementationHelperItem( ImplementationHelperItem::CreateDefinition,
                                     DeclarationPointer(decl),
-                                    KSharedPtr<CodeCompletionContext>(this)));
+                                    QExplicitlySharedDataPointer<CodeCompletionContext>(this)));
   }
 
   foreach(DUContext* child, context->childContexts()) {
@@ -2175,7 +2172,7 @@ bool CodeCompletionContext::visibleFromWithin(Declaration* decl, DUContext* curr
     return false;
   if(currentContext->imports(decl->context()))
     return true;
-  
+
   return visibleFromWithin(decl, currentContext->parentContext());
 }
 
@@ -2251,16 +2248,16 @@ bool  CodeCompletionContext::filterDeclaration(Declaration* decl, DUContext* dec
 
   if(dynamic_cast<TemplateParameterDeclaration*>(decl) && !visibleFromWithin(decl, m_duContext.data()))
     return false;
-  
+
   static const IndexedIdentifier friendIdentifier(Identifier("friend"));
-  
+
   if(decl->indexedIdentifier().isEmpty()) //Filter out nameless declarations
     return false;
 
   if(decl->indexedIdentifier() == friendIdentifier || decl->indexedIdentifier() == Cpp::unnamedNamespaceIdentifier()
      || decl->indexedIdentifier() == globalIndexedImportIdentifier())
     return false;
-  
+
   if(excludeReservedIdentifiers)
   {
     //Exclude identifiers starting with "__" or "_Uppercase"
@@ -2287,20 +2284,20 @@ bool  CodeCompletionContext::filterDeclaration(Declaration* decl, DUContext* dec
   if(m_onlyShow == ShowTypes && decl->kind() != Declaration::Type && decl->kind() != Declaration::Namespace
      && decl->kind() != Declaration::NamespaceAlias )
     return false;
-  
+
   if(m_onlyShow == ShowVariables && (decl->kind() != Declaration::Instance || decl->isFunctionDeclaration()))
     return false;
-  
+
   if(m_onlyShow == ShowImplementationHelpers)
     return false; //Implementation helpers don't come here
-    
+
   if(m_onlyShow == ShowSignals || m_onlyShow == ShowSlots) {
     Cpp::QtFunctionDeclaration* qtFunction = dynamic_cast<Cpp::QtFunctionDeclaration*>(decl);
     if(!qtFunction || (m_onlyShow == ShowSignals && !qtFunction->isSignal())
                    || (m_onlyShow == ShowSlots && !qtFunction->isSlot()))
       return false;
   }
-  
+
   if(dynamic && decl->context()->type() == DUContext::Class) {
     ClassMemberDeclaration* classMember = dynamic_cast<ClassMemberDeclaration*>(decl);
     if(classMember)
@@ -2335,14 +2332,14 @@ void CodeCompletionContext::replaceCurrentAccess(const QString& old, const QStri
 {
   //We must not change the document from within the background, so we use a queued connection to an object created in the foregroud
   QMetaObject::invokeMethod(&s_mainThreadHelper, "replaceCurrentAccess", Qt::QueuedConnection,
-                            Q_ARG(KUrl, m_duContext->url().toUrl()), Q_ARG(QString, old), Q_ARG(QString, _new));
+                            Q_ARG(QUrl, m_duContext->url().toUrl()), Q_ARG(QString, old), Q_ARG(QString, _new));
 }
 
 int CodeCompletionContext::matchPosition() const {
   return m_knownArgumentExpressions.count();
 }
 
-void CodeCompletionContext::eventuallyAddGroup(QString name, int priority, QList< KSharedPtr< KDevelop::CompletionTreeItem > > items) {
+void CodeCompletionContext::eventuallyAddGroup(QString name, int priority, QList< QExplicitlySharedDataPointer< KDevelop::CompletionTreeItem > > items) {
   if(items.isEmpty())
     return;
   KDevelop::CompletionCustomGroupNode* node = new KDevelop::CompletionCustomGroupNode(name, priority);
@@ -2350,22 +2347,22 @@ void CodeCompletionContext::eventuallyAddGroup(QString name, int priority, QList
   m_storedUngroupedItems << CompletionTreeElementPointer(node);
 }
 
-QList< KSharedPtr< KDevelop::CompletionTreeItem > > CodeCompletionContext::keywordCompletionItems() {
+QList< QExplicitlySharedDataPointer< KDevelop::CompletionTreeItem > > CodeCompletionContext::keywordCompletionItems() {
   QList<CompletionTreeItemPointer> ret;
   #ifdef TEST_COMPLETION
   return ret;
   #endif
-  #define ADD_TYPED_TOKEN_S(X, type) ret << CompletionTreeItemPointer( new TypeConversionCompletionItem(X, type, 0, KSharedPtr<Cpp::CodeCompletionContext>(this)) )
+  #define ADD_TYPED_TOKEN_S(X, type) ret << CompletionTreeItemPointer( new TypeConversionCompletionItem(X, type, 0, QExplicitlySharedDataPointer<Cpp::CodeCompletionContext>(this)) )
   #define ADD_TYPED_TOKEN(X, type) ADD_TYPED_TOKEN_S(#X, type)
-  
+
   #define ADD_TOKEN(X) ADD_TYPED_TOKEN(X, KDevelop::IndexedType())
   #define ADD_TOKEN_S(X) ADD_TYPED_TOKEN_S(X, KDevelop::IndexedType())
 
   bool restrictedItems = (m_onlyShow == ShowSignals) ||
-                         (m_onlyShow == ShowSlots) || 
+                         (m_onlyShow == ShowSlots) ||
                          (m_onlyShow == ShowTypes) ||
                          (m_onlyShow == ShowImplementationHelpers);
-  
+
   if(!restrictedItems || m_onlyShow == ShowTypes) {
     ADD_TOKEN(bool);
     ADD_TOKEN(char);
@@ -2390,10 +2387,10 @@ QList< KSharedPtr< KDevelop::CompletionTreeItem > > CodeCompletionContext::keywo
     ADD_TOKEN(volatile);
     ADD_TOKEN(wchar_t);
   }
-  
+
   if(restrictedItems && (m_duContext->type() == DUContext::Other || m_duContext->type() == DUContext::Function))
     return ret;
-  
+
   if(m_duContext->type() == DUContext::Class) {
     ADD_TOKEN_S("Q_OBJECT");
     ADD_TOKEN(private);
@@ -2405,7 +2402,7 @@ QList< KSharedPtr< KDevelop::CompletionTreeItem > > CodeCompletionContext::keywo
     ADD_TOKEN(friend);
     ADD_TOKEN(explicit);
   }
-  
+
   if(m_duContext->type() == DUContext::Other) {
     ADD_TOKEN(break);
     ADD_TOKEN(case);
@@ -2445,13 +2442,13 @@ QList< KSharedPtr< KDevelop::CompletionTreeItem > > CodeCompletionContext::keywo
   }else{
     ADD_TOKEN(inline);
   }
-  
+
   if(m_duContext->type() == DUContext::Global) {
     ADD_TOKEN(export);
     ADD_TOKEN(extern);
     ADD_TOKEN(namespace);
   }
-  
+
   ADD_TOKEN(auto);
   ADD_TOKEN(class);
   ADD_TOKEN(operator);
@@ -2463,14 +2460,14 @@ QList< KSharedPtr< KDevelop::CompletionTreeItem > > CodeCompletionContext::keywo
 
   ConstantIntegralType::Ptr trueType(new ConstantIntegralType(IntegralType::TypeBoolean));
   trueType->setValue<bool>(true);
-  
+
   ADD_TYPED_TOKEN(true, trueType->indexed());
 
   ConstantIntegralType::Ptr falseType(new ConstantIntegralType(IntegralType::TypeBoolean));
   falseType->setValue<bool>(false);
 
   ADD_TYPED_TOKEN(false, falseType->indexed());
-  
+
   return ret;
 }
 
