@@ -35,13 +35,14 @@
 #include <language/duchain/duchainutils.h>
 #include <language/duchain/classdeclaration.h>
 #include "../cppduchain/qtfunctiondeclaration.h"
-#include <language/duchain/use.h>
+#include "../debug.h"
 #include <typeutils.h>
 #include <cppduchain.h>
 #include <templatedeclaration.h>
 #include <language/codecompletion/codecompletionhelper.h>
 #include "context.h"
 #include <ktexteditor/codecompletioninterface.h>
+#include <ktexteditor/document.h>
 #include <ktexteditor/movingrange.h>
 #include <ktexteditor/movinginterface.h>
 #include <memory>
@@ -80,7 +81,7 @@ namespace Cpp {
 
 AbstractType::Ptr applyPointerConversions(AbstractType::Ptr type, int pointerConversions, TopDUContext *top)
 {
-  if(pointerConversions == 0 || type.isNull())
+  if(pointerConversions == 0 || type)
     return type;
 
   if(pointerConversions > 0) {
@@ -132,7 +133,7 @@ int getMatchQuality(CodeCompletionContext *context, const Declaration* decl, Top
   return bestQuality;
 }
 
-void executeSignalSlotCompletionItem( KTextEditor::Document* document, const KTextEditor::Range& enteredWord,
+void executeSignalSlotCompletionItem( KTextEditor::View* view, const KTextEditor::Range& enteredWord,
                                       bool isSignal, const QString& name, const QString& signature )
 {
   QString newText;
@@ -144,14 +145,14 @@ void executeSignalSlotCompletionItem( KTextEditor::Document* document, const KTe
   // NOTE: we do not scan for Q_SIGNAL or Q_SLOT, as these words (with "Q_" in beginning)
   // also match ones without "Q_"; thus we keep the user's preference of typing "Q_" or not.
   {
-    QString prefixText = linePrefix( document, word );
+    QString prefixText = linePrefix( view->document(), word );
     // We match SIGNAL or SLOT, followed by spaces, then (maybe) an opening bracket and spaces, then EOL.
     // Thus we ensure that cursor is positioned like "SIGNAL( <here>", not "SIGNAL( something <here>".
     // That is, we match only those SIGNAL/SLOT statements, for which we shall suggest a complete method signature.
     QRegExp signalSlotRegExp( "(SIGNAL|SLOT)\\s*(\\(\\s*)$" );
     int signalSlotAt = signalSlotRegExp.lastIndexIn( prefixText );
     if( signalSlotAt >= 0 ) {
-      word.start().setColumn( signalSlotAt );
+      word.setStart(KTextEditor::Cursor(word.start().line(), signalSlotAt));
     }
   }
 
@@ -175,14 +176,13 @@ void executeSignalSlotCompletionItem( KTextEditor::Document* document, const KTe
   // skip all characters when "nesting > 0" (they are arguments) and stop when "nesting < 0"
   // (i. e., when we encounter connect()'s closing bracket).
   {
-    QString suffixText = lineSuffixAndWord( document, word );
+    QString suffixText = lineSuffixAndWord( view->document(), word );
     int nesting = 0, position = 0;
     for( ; position < suffixText.size(); ++position ) {
       QChar c = suffixText.at( position );
-      char ascii = c.toAscii();
       bool isDelimiter = false;
 
-      switch( ascii ) {
+      switch( c.unicode() ) {
       case '(' : ++nesting; break;
       case ')' : --nesting; break;
       case ',' :
@@ -208,17 +208,17 @@ void executeSignalSlotCompletionItem( KTextEditor::Document* document, const KTe
     // NOTE: a word can span multiple lines. As the suffix text is by definition at the last line of word,
     // the found char is at the last line of the range.
     // Now translate position to column, but using distance from position to suffix text end (rather than to its beginning).
-    int lastLineLength = document->lineLength( word.end().line() );
+    int lastLineLength = view->document()->lineLength( word.end().line() );
     int distanceToTextEnd = suffixText.length() - position;
     int characterColumn = lastLineLength - distanceToTextEnd;
-    word.end().setColumn( characterColumn );
+    word.setEnd(KTextEditor::Cursor(word.end().line(), characterColumn ));
   }
 
-  document->replaceText( word, newText );
+  view->document()->replaceText( word, newText );
   return;
 }
 
-void NormalDeclarationCompletionItem::execute(KTextEditor::Document* document, const KTextEditor::Range& _word) {
+void NormalDeclarationCompletionItem::execute(KTextEditor::View* view, const KTextEditor::Range& _word) {
   if( completionContext() && completionContext()->depth() != 0 )
     return; //Do not replace any text when it is an argument-hint
 
@@ -226,10 +226,10 @@ void NormalDeclarationCompletionItem::execute(KTextEditor::Document* document, c
     KDevelop::DUChainReadLocker lock( KDevelop::DUChain::lock() );
     Cpp::QtFunctionDeclaration* classFun = dynamic_cast<Cpp::QtFunctionDeclaration*>( m_declaration.data() );
     if( !classFun ) {
-      kWarning() << "Signal/slot completion declaration is not a QtFunctionDeclaration";
+      qCWarning(CPP) << "Signal/slot completion declaration is not a QtFunctionDeclaration";
       return;
     }
-    executeSignalSlotCompletionItem( document, _word, classFun->isSignal(),
+    executeSignalSlotCompletionItem( view, _word, classFun->isSignal(),
                                      classFun->identifier().toString(), classFun->normalizedSignature().str() );
     return;
   }
@@ -247,7 +247,7 @@ void NormalDeclarationCompletionItem::execute(KTextEditor::Document* document, c
             newText.prepend (parentScope.toString() + "::");
       }
     } else {
-      kDebug() << "Declaration disappeared";
+      qCDebug(CPP) << "Declaration disappeared";
       if(!alternativeText.isEmpty())
         newText = alternativeText;
       else
@@ -257,32 +257,32 @@ void NormalDeclarationCompletionItem::execute(KTextEditor::Document* document, c
     newText = alternativeText;
   }
   newText.prepend(prefixText);
-  
+
   // Text that will be removed in a separate editing step (so the user can undo it)
-  std::auto_ptr<KTextEditor::MovingRange> removeInSecondStep;
-  
-  KTextEditor::Cursor cursor = document->activeView()->cursorPosition();
+  QScopedPointer<KTextEditor::MovingRange> removeInSecondStep;
+
+  KTextEditor::Cursor cursor = view->cursorPosition();
+  KTextEditor::Document* document = view->document();
   if(cursor != word.end())
   {
     KTextEditor::MovingInterface* moving = dynamic_cast<KTextEditor::MovingInterface*>(document);
     Q_ASSERT(moving);
-    removeInSecondStep =  std::auto_ptr<KTextEditor::MovingRange>(
-      moving->newMovingRange(KTextEditor::Range(cursor, word.end()), KTextEditor::MovingRange::DoNotExpand));
-    word.end() = cursor;
+    removeInSecondStep.reset(moving->newMovingRange(KTextEditor::Range(cursor, word.end()), KTextEditor::MovingRange::DoNotExpand));
+    word.setEnd(cursor);
   }
-  
+
   KTextEditor::Range nextToken = KTextEditor::Range(_word.end(), KTextEditor::Cursor(_word.end().line(), _word.end().column() + 2));
   bool followingColon = document->text(nextToken) == "::";
   bool followingBrace = document->text(nextToken).contains('{');
   document->replaceText(word, newText);
-  
+
   KTextEditor::Cursor end = word.start();
   end.setColumn(end.column() + newText.length());
-  
+
   bool jumpForbidden = false;
-  
+
   KDevelop::DUChainReadLocker lock(KDevelop::DUChain::lock());
-  
+
   if(m_declaration.data())
   {
     if(declarationNeedsTemplateParameters(m_declaration.data())) {
@@ -290,10 +290,10 @@ void NormalDeclarationCompletionItem::execute(KTextEditor::Document* document, c
       lock.unlock();
       document->insertText( end, "<>" );
       end.setColumn(end.column() + 2);
-      document->activeView()->setCursorPosition( end - KTextEditor::Cursor(0, 1) );
+      view->setCursorPosition( end - KTextEditor::Cursor(0, 1) );
       lock.lock();
     }
-    
+
     if(m_declaration.data()->kind() == Declaration::Namespace) {
       CodeCompletionContext* ctx = static_cast<CodeCompletionContext*>(m_completionContext.data());
       if (ctx->accessType() != CodeCompletionContext::NamespaceAccess && !followingColon) {
@@ -310,47 +310,43 @@ void NormalDeclarationCompletionItem::execute(KTextEditor::Document* document, c
         lock.lock();
       }
     }
-      
+
     if( !useAlternativeText && m_declaration && (dynamic_cast<AbstractFunctionDeclaration*>(m_declaration.data()) || completionContext()->isConstructorInitialization()) ) {
       //Do some intelligent stuff for functions with the parens:
       lock.unlock();
       KTextEditor::Cursor insertionPosition = end;
-      if (removeInSecondStep.get()) {
+      if (removeInSecondStep) {
         KTextEditor::Range removeRange = removeInSecondStep->toRange();
         insertionPosition += removeRange.end() - removeRange.start();
       }
-      insertFunctionParenText(document, insertionPosition, m_declaration, jumpForbidden);
+      insertFunctionParenText(view, insertionPosition, m_declaration, jumpForbidden);
     }
-    
-    if (removeInSecondStep.get()) {
+
+    if (removeInSecondStep) {
       //if we would remove text after the inserted text, skip that if it is a property
       //of the executed item and additionally insert a . or ->
       Identifier id(document->text(removeInSecondStep->toRange()));
       QString insertAccessor = keepRemainingWord(id);
       if (!insertAccessor.isEmpty()) {
         document->insertText(removeInSecondStep->toRange().start(), insertAccessor);
-        removeInSecondStep.release();
+        removeInSecondStep.reset(nullptr);
       }
     }
   }
-  
-  if(removeInSecondStep.get())
+
+  if(removeInSecondStep)
   {
     KTextEditor::Range removeRange = removeInSecondStep->toRange();
     if(!removeRange.isEmpty() && removeRange.end() > end && removeRange.end().line() == end.line() && removeRange.end().column() <= document->lineLength(removeRange.end().line()))
     {
       // We stop the editing sequence, which was initiated by kate, so the user can manually undo the removal
-      bool wasEditing = document->endEditing();
-      if(wasEditing)
-        document->startEditing();
-      else
-        kWarning() << "Was not editing";
+      // -- I removed this feature, it's unclear how/if it works with the new transactions and not worth porting
       document->removeText(removeRange);
     }
   }
 }
 
-QString NormalDeclarationCompletionItem::keepRemainingWord(Identifier id)
+QString NormalDeclarationCompletionItem::keepRemainingWord(const Identifier& id)
 {
   DUChainReadLocker lock;
 
@@ -473,36 +469,36 @@ QString NormalDeclarationCompletionItem::shortenedTypeString(KDevelop::Declarati
 {
   if(m_cachedTypeStringDecl == decl && m_cachedTypeStringLength == static_cast<uint>(desiredTypeLength))
     return m_cachedTypeString;
-  
+
   QString ret;
-  
+
   if(completionContext() && completionContext()->duContext())
     ret = Cpp::shortenedTypeString(decl.data(), completionContext()->duContext(), desiredTypeLength);
   else
     ret = KDevelop::NormalDeclarationCompletionItem::shortenedTypeString(decl, desiredTypeLength);
-  
+
   m_cachedTypeString = ret;
   m_cachedTypeStringDecl = decl;
   m_cachedTypeStringLength = desiredTypeLength;
-  
+
   return ret;
 }
 
 KDevelop::QualifiedIdentifier NormalDeclarationCompletionItem::stripPrefix() const {
   if(completionContext() && completionContext()->duContext()) {
     const TopDUContext* top = completionContext()->duContext()->topContext();
-    
+
     if(completionContext()->memberAccessContainer().allDeclarations.size())
       if( Declaration * const decl = completionContext()->memberAccessContainer().allDeclarations[0].getDeclaration(top) ) {
         AbstractType::Ptr t = decl->abstractType();
-        IdentifiedType* idType = dynamic_cast<IdentifiedType*>(t.unsafeData());
+        IdentifiedType* idType = dynamic_cast<IdentifiedType*>(t.data());
         if(idType)
           return idType->qualifiedIdentifier();
       }
-    
+
     return completionContext()->duContext()->scopeIdentifier(true);
   }
-  
+
   return QualifiedIdentifier();
 }
 
@@ -510,12 +506,12 @@ QVariant NormalDeclarationCompletionItem::data(const QModelIndex& index, int rol
 
   DUChainReadLocker lock(DUChain::lock(), 500);
   if(!lock.locked()) {
-    kDebug(9007) << "Failed to lock the du-chain in time";
+    qCDebug(CPP) << "Failed to lock the du-chain in time";
     return QVariant();
   }
-  
+
   if(!completionContext()) {
-    kDebug(9007) << "Missing completion-context";
+    qCDebug(CPP) << "Missing completion-context";
     return QVariant();
   }
 
@@ -565,7 +561,7 @@ QVariant NormalDeclarationCompletionItem::data(const QModelIndex& index, int rol
 
           if(m_declaration->kind() == Declaration::Namespace)
             return QString(indentation + "namespace");
-          
+
           if( NamespaceAliasDeclaration* alias = dynamic_cast<NamespaceAliasDeclaration*>(dec) ) {
             if( alias->identifier().isEmpty() ) {
               return QString(indentation + "using namespace");/* " + alias->importIdentifier().toString();*/
@@ -654,16 +650,16 @@ QVariant NormalDeclarationCompletionItem::data(const QModelIndex& index, int rol
         case CodeCompletionModel::Arguments:
         {
           QString ret;
-          
+
           if(completingTemplateParameters())
             createTemplateArgumentList(*this, ret, 0);
-          
+
           if (dec->type<FunctionType>()) {
             needCachedArgumentList();
-            
+
             return m_cachedArgumentList->text;
           }
-          
+
           return ret;
         }
         break;
@@ -700,19 +696,19 @@ QVariant NormalDeclarationCompletionItem::data(const QModelIndex& index, int rol
     case CodeCompletionModel::CustomHighlight:
     if( index.column() == CodeCompletionModel::Arguments /*&& completionContext()->memberAccessOperation() == Cpp::CodeCompletionContext::FunctionCallAccess*/ ) {
       needCachedArgumentList();
-      
+
       return QVariant(m_cachedArgumentList->highlighting);
     }
 //     if( index.column() == CodeCompletionModel::Name ) {
 //       //Bold
 //       QTextCharFormat boldFormat;
 //       boldFormat.setFontWeight((QFont::Normal + QFont::DemiBold)/2);
-// 
+//
 //       QList<QVariant> ret;
 //       ret << 0;
 //       ret << nameForDeclaration(dec).length();
 //       ret << QVariant(boldFormat);
-// 
+//
 //       return QVariant(ret);
 //     }
     break;
@@ -726,8 +722,8 @@ QVariant NormalDeclarationCompletionItem::data(const QModelIndex& index, int rol
       //If it's a slot, remove all flags except the slot flag, because that will give a nicer icon. Access-rights are checked anyway.
       if(p & CodeCompletionModel::Slot)
         p = CodeCompletionModel::Slot;
-      
-      
+
+
       if( index.column() == CodeCompletionModel::Icon ) {
         lock.unlock();
         return DUChainUtils::iconForProperties(p);
@@ -744,11 +740,11 @@ void NormalDeclarationCompletionItem::needCachedArgumentList() const
 {
   if(!m_cachedArgumentList)
   {
-    m_cachedArgumentList = KSharedPtr<CachedArgumentList>(new CachedArgumentList);
-    
+    m_cachedArgumentList = QExplicitlySharedDataPointer<CachedArgumentList>(new CachedArgumentList);
+
     if(!m_declaration)
       return;
-    
+
     if(m_isTemplateCompletion || declarationNeedsTemplateParameters(m_declaration.data()))
       createTemplateArgumentList(*this, m_cachedArgumentList->text, &m_cachedArgumentList->highlighting);
 
@@ -768,11 +764,13 @@ bool NormalDeclarationCompletionItem::createsExpandingWidget() const
   return true;
 }
 
-KSharedPtr<CodeCompletionContext> NormalDeclarationCompletionItem::completionContext() const {
-  return KSharedPtr<CodeCompletionContext>::staticCast(m_completionContext);
+QExplicitlySharedDataPointer<CodeCompletionContext> NormalDeclarationCompletionItem::completionContext() const {
+  return CodeCompletionContext::Ptr(static_cast<CodeCompletionContext*>(m_completionContext.data()));
 }
 
-void IncludeFileCompletionItem::execute(KTextEditor::Document* document, const KTextEditor::Range& _word) {
+void IncludeFileCompletionItem::execute(KTextEditor::View* view, const KTextEditor::Range& _word)
+{
+  KTextEditor::Document* document = view->document();
 
   KTextEditor::Range word(_word);
 
@@ -789,7 +787,7 @@ void IncludeFileCompletionItem::execute(KTextEditor::Document* document, const K
        newText += '>';
     }
 
-    word.end().setColumn( document->lineLength(word.end().line()) );
+    word.setEnd(KTextEditor::Cursor(word.end().line(), document->lineLength(word.end().line()) ));
   }
 
   document->replaceText(word, newText);
@@ -803,9 +801,9 @@ QList<KDevelop::IndexedType> TypeConversionCompletionItem::type() const {
   return QList<KDevelop::IndexedType>() << m_type;
 }
 
-void TypeConversionCompletionItem::execute(KTextEditor::Document* document, const KTextEditor::Range& word) {
+void TypeConversionCompletionItem::execute(KTextEditor::View* view, const KTextEditor::Range& word) {
   if(argumentHintDepth() == 0)
-    document->replaceText( word, m_text );
+    view->document()->replaceText( word, m_text );
 }
 
 QVariant TypeConversionCompletionItem::data(const QModelIndex& index, int role, const KDevelop::CodeCompletionModel* /*model*/) const
@@ -831,10 +829,10 @@ int TypeConversionCompletionItem::argumentHintDepth() const {
   return m_argumentHintDepth;
 }
 
-TypeConversionCompletionItem::TypeConversionCompletionItem(QString text, KDevelop::IndexedType type, int argumentHintDepth, KSharedPtr<Cpp::CodeCompletionContext> _completionContext) : m_text(text), m_type(type), m_argumentHintDepth(argumentHintDepth), completionContext(_completionContext) {
+TypeConversionCompletionItem::TypeConversionCompletionItem(QString text, KDevelop::IndexedType type, int argumentHintDepth, QExplicitlySharedDataPointer<Cpp::CodeCompletionContext> _completionContext) : m_text(text), m_type(type), m_argumentHintDepth(argumentHintDepth), completionContext(_completionContext) {
 }
 
-MoreArgumentHintsCompletionItem::MoreArgumentHintsCompletionItem(KSharedPtr< KDevelop::CodeCompletionContext > context, QString text, uint oldNumber) : NormalDeclarationCompletionItem(DeclarationPointer(), context) {
+MoreArgumentHintsCompletionItem::MoreArgumentHintsCompletionItem(KDevelop::CodeCompletionContext::Ptr context, QString text, uint oldNumber) : NormalDeclarationCompletionItem(DeclarationPointer(), context) {
   alternativeText = text;
   m_oldNumber = oldNumber;
 }
@@ -849,23 +847,23 @@ uint MoreArgumentHintsCompletionItem::resetMaxArgumentHints(bool isAutomaticComp
 {
   uint ret = currentMaxArgumentHints;
   currentMaxArgumentHints = defaultMaxArgumentHints;
-  
+
   if(isAutomaticCompletion)
     return 1;
-  
+
   return ret;
 }
 
-void MoreArgumentHintsCompletionItem::execute(KTextEditor::Document* document, const KTextEditor::Range& /*word*/)
+void MoreArgumentHintsCompletionItem::execute(KTextEditor::View* view, const KTextEditor::Range& word)
 {
   currentMaxArgumentHints = m_oldNumber + maxArgumentHintsExtensionSteps;
-  
+
   // Restart code-completion
-  KTextEditor::CodeCompletionInterface* iface = dynamic_cast<KTextEditor::CodeCompletionInterface*>(document->activeView());
+  KTextEditor::CodeCompletionInterface* iface = dynamic_cast<KTextEditor::CodeCompletionInterface*>(view);
   Q_ASSERT(iface);
   iface->abortCompletion();
     ///@todo 1. This is a non-public interface, and 2. Completion should be started in "automatic invocation" mode
-  QMetaObject::invokeMethod(document->activeView(), "userInvokedCompletion", Qt::QueuedConnection);
+  QMetaObject::invokeMethod(view, "userInvokedCompletion", Qt::QueuedConnection);
 }
 
 }
