@@ -22,20 +22,23 @@
 #ifndef COMPLETIONITEM_H
 #define COMPLETIONITEM_H
 
-#include <ksharedptr.h>
-#include <ktexteditor/codecompletionmodel.h>
-
 #include <language/duchain/duchainpointer.h>
+#include <language/duchain/types/structuretype.h>
 #include <language/codecompletion/codecompletionitem.h>
 #include <language/codecompletion/normaldeclarationcompletionitem.h>
 #include <language/codecompletion/abstractincludefilecompletionitem.h>
 #include "../cppduchain/navigation/navigationwidget.h"
-#include "context.h"
+
+namespace KDevelop {
+  class QualifiedIdentifier;
+  class Identifier;
+}
 
 namespace KTextEditor {
   class CodeCompletionModel;
   class Document;
   class Range;
+  class View;
   class Cursor;
 }
 
@@ -52,22 +55,21 @@ namespace Cpp {
 
 void setStaticMatchContext(QList<KDevelop::IndexedType> types);
 
-void executeSignalSlotCompletionItem( KTextEditor::Document* document, const KTextEditor::Range& enteredWord,
-                                      bool isSignal, const QString& name, const QString& signature );
+void executeSignalSlotCompletionItem( KTextEditor::View* view, const KTextEditor::Range& enteredWord, bool isSignal, const QString& name, const QString& signature );
 
 //A completion item used for completion of normal declarations while normal code-completion
 class NormalDeclarationCompletionItem : public KDevelop::NormalDeclarationCompletionItem {
 public:
-  NormalDeclarationCompletionItem(KDevelop::DeclarationPointer decl = KDevelop::DeclarationPointer(), KSharedPtr<KDevelop::CodeCompletionContext> context=KSharedPtr<KDevelop::CodeCompletionContext>(), int _inheritanceDepth = 0, int _listOffset=0)
+  NormalDeclarationCompletionItem(KDevelop::DeclarationPointer decl = KDevelop::DeclarationPointer(), QExplicitlySharedDataPointer<KDevelop::CodeCompletionContext> context=QExplicitlySharedDataPointer<KDevelop::CodeCompletionContext>(), int _inheritanceDepth = 0, int _listOffset=0)
     : KDevelop::NormalDeclarationCompletionItem(decl, context, _inheritanceDepth), useAlternativeText(false), prependScopePrefix(false), listOffset(_listOffset), m_isQtSignalSlotCompletion(false), m_isTemplateCompletion(false), m_fixedMatchQuality(-1) {
   }
   
-  virtual void execute(KTextEditor::Document* document, const KTextEditor::Range& word);
+  virtual void execute(KTextEditor::View* view, const KTextEditor::Range& word) override;
 
-  virtual QVariant data(const QModelIndex& index, int role, const KDevelop::CodeCompletionModel* model) const;
+  virtual QVariant data(const QModelIndex& index, int role, const KDevelop::CodeCompletionModel* model) const override;
   
   //Prefix that will be stripped from all identifiers(For example the namespace)
-  QualifiedIdentifier stripPrefix() const;
+  KDevelop::QualifiedIdentifier stripPrefix() const;
   
   bool completingTemplateParameters() const;
   
@@ -90,28 +92,28 @@ public:
   //otherwise this is calculated and cached on the first read
   mutable int m_fixedMatchQuality;
   
-  virtual KTextEditor::CodeCompletionModel::CompletionProperties completionProperties() const;
+  virtual KTextEditor::CodeCompletionModel::CompletionProperties completionProperties() const override;
 
-  KSharedPtr<CodeCompletionContext> completionContext() const;
+  QExplicitlySharedDataPointer<CodeCompletionContext> completionContext() const;
 
 protected:
-  virtual QWidget* createExpandingWidget(const KDevelop::CodeCompletionModel* model) const;
-  virtual bool createsExpandingWidget() const;
-  virtual QString shortenedTypeString(KDevelop::DeclarationPointer decl, int desiredTypeLength) const;
+  virtual QWidget* createExpandingWidget(const KDevelop::CodeCompletionModel* model) const override;
+  virtual bool createsExpandingWidget() const override;
+  virtual QString shortenedTypeString(KDevelop::DeclarationPointer decl, int desiredTypeLength) const override;
 private:
   
   void needCachedArgumentList() const;
   
-  QString keepRemainingWord(Identifier id);
-  QString keepRemainingWord(const StructureType::Ptr &type, const Identifier &id, const QString &insertAccessor);
+  QString keepRemainingWord(const KDevelop::Identifier& id);
+  QString keepRemainingWord(const KDevelop::StructureType::Ptr &type, const KDevelop::Identifier &id, const QString &insertAccessor);
   
 
   
-  mutable DeclarationPointer m_cachedTypeStringDecl;
+  mutable KDevelop::DeclarationPointer m_cachedTypeStringDecl;
   mutable QString m_cachedTypeString;
   mutable uint m_cachedTypeStringLength;
   
-  mutable KSharedPtr<CachedArgumentList> m_cachedArgumentList;
+  mutable QExplicitlySharedDataPointer<CachedArgumentList> m_cachedArgumentList;
 };
 
 // Helper-item that manages the number of shown argument-hints
@@ -119,9 +121,9 @@ private:
 // The number is reset after resetMaxArgumentHints() was called the next time.
 class MoreArgumentHintsCompletionItem : public NormalDeclarationCompletionItem {
 public:
-  MoreArgumentHintsCompletionItem(KSharedPtr<KDevelop::CodeCompletionContext> context, QString text, uint oldNumber);
+  MoreArgumentHintsCompletionItem(KDevelop::CodeCompletionContext::Ptr context, QString text, uint oldNumber);
   
-  virtual void execute(KTextEditor::Document* document, const KTextEditor::Range& word);
+  virtual void execute(KTextEditor::View* view, const KTextEditor::Range& word) override;
   
   // Maximum number of argument-hints that should be shown by code completion
   // Whenever this is called, the maximum number of arguments is reset afterwards,
@@ -138,23 +140,23 @@ public:
     IncludeFileCompletionItem(const KDevelop::IncludeItem& include)
       : BaseIncludeFileCompletionItem(include) {}
 
-    virtual void execute(KTextEditor::Document* document, const KTextEditor::Range& word);
+    virtual void execute(KTextEditor::View* view, const KTextEditor::Range& word) override;
 };
 
 class TypeConversionCompletionItem : public KDevelop::CompletionTreeItem {
   public:
-    TypeConversionCompletionItem(QString text, KDevelop::IndexedType type, int argumentHintDepth, KSharedPtr<Cpp::CodeCompletionContext> completionContext);
-    virtual int argumentHintDepth() const;
-    virtual QVariant data(const QModelIndex& index, int role, const KDevelop::CodeCompletionModel* model) const;
+    TypeConversionCompletionItem(QString text, KDevelop::IndexedType type, int argumentHintDepth, QExplicitlySharedDataPointer<Cpp::CodeCompletionContext> completionContext);
+    virtual int argumentHintDepth() const override;
+    virtual QVariant data(const QModelIndex& index, int role, const KDevelop::CodeCompletionModel* model) const override;
     QList<KDevelop::IndexedType> type() const;
     void setPrefix(QString s);
-    virtual void execute(KTextEditor::Document* document, const KTextEditor::Range& word);
+    virtual void execute(KTextEditor::View*, const KTextEditor::Range& word) override;
   private:
     QString m_prefix;
     QString m_text;
     KDevelop::IndexedType m_type;
     int m_argumentHintDepth;
-    KSharedPtr<Cpp::CodeCompletionContext> completionContext;
+    QExplicitlySharedDataPointer<Cpp::CodeCompletionContext> completionContext;
 };
 
 }
