@@ -19,9 +19,10 @@
 #include "missingincludeitem.h"
 
 
-#include <klocale.h>
+#include <KLocalizedString>
 
-#include <ktexteditor/document.h>
+#include <KTextEditor/Document>
+#include <KTextEditor/View>
 
 #include <language/duchain/namespacealiasdeclaration.h>
 #include <language/duchain/persistentsymboltable.h>
@@ -38,13 +39,14 @@
 #include "../cppduchain/expressionevaluationresult.h"
 
 #include "../cpputils.h"
+#include "../debug.h"
 
 #include "model.h"
 #include "helpers.h"
 #include "sourcemanipulation.h"
 
 //Whether relative urls like "../bla" should be allowed. Even if this is false, they will be preferred over global urls.
-bool allowDotDot = true;
+static const bool allowDotDot = true;
 const uint maxDeclarationCount = 30;
 
 using namespace KTextEditor;
@@ -113,13 +115,14 @@ int findIncludeLineFromDUChain(KTextEditor::Document* document, int maxLine, con
 }
 
 ///Decide whether the file is allowed to be included directly. If yes, this should return false.
-bool isBlacklistedInclude(const KUrl& url) {
+bool isBlacklistedInclude(const QUrl &url) {
   QString fileName = url.fileName();
   if(isSource(fileName))
     return true;
 
   //Do not allow including directly from the bits directory. Instead use one of the forwarding headers in other directories, when possible.
-  if(url.upUrl().fileName() == "bits" && url.path().contains("/include/c++/")) {
+  const QString path = url.path();
+  if(path.contains("/bits/") && path.contains("/include/c++/")) {
     return true;
   }
 
@@ -146,7 +149,7 @@ QList<KDevelop::CompletionTreeItemPointer> itemsForFile(const QString& displayTe
   //We have found a potential declaration. Now find the shortest include path.
   QString shortestDirective;
   bool isRelativeToCurrentDir = false;
-  
+
   if(isSource(file))
     return ret;
 
@@ -156,10 +159,10 @@ QList<KDevelop::CompletionTreeItemPointer> itemsForFile(const QString& displayTe
     QString relative = includePath.relativePath( canonicalFile );
     if(relative.startsWith("./"))
       relative = relative.mid(2);
-    
+
     if(shortestDirective.isEmpty() || (relative.length() < shortestDirective.length() && (allowDotDot || !relative.startsWith(".."))) || (shortestDirective.startsWith("..") && !relative.startsWith(".."))) {
       shortestDirective = relative;
-      
+
       isRelativeToCurrentDir = includePath == currentPath;
     }
   }
@@ -168,10 +171,10 @@ QList<KDevelop::CompletionTreeItemPointer> itemsForFile(const QString& displayTe
       shortestDirective = "\"" + shortestDirective + "\"";
     else
       shortestDirective = "<" + shortestDirective + ">";
-    
+
     if(!directives.contains(shortestDirective))
       ret << KDevelop::CompletionTreeItemPointer(new MissingIncludeCompletionItem(shortestDirective, file, displayTextPrefix, decl, (int)argumentHintDepth));
-    
+
     directives.insert(shortestDirective);
   }
   return ret;
@@ -191,7 +194,7 @@ QStringList candidateIncludeFiles(Declaration* decl) {
   QStringList ret;
 
   bool inBlacklistDir = isBlacklistedInclude(decl->url().toUrl());
-  
+
   foreach(KDevelop::ParsingEnvironmentFilePointer ptr, decl->topContext()->parsingEnvironmentFile()->importers()) {
     if(ptr->imports().count() == 1 || inBlacklistDir) {
       if(isBlacklistedInclude(ptr->url().toUrl()))
@@ -201,15 +204,15 @@ QStringList candidateIncludeFiles(Declaration* decl) {
       //Forwarders must be completely empty
       if(ptr->topContext()->localDeclarations().count())
         continue;
-      
+
       QString file(ptr->url().toUrl().toLocalFile());
       ret << file;
     }
   }
-  
+
   if(!inBlacklistDir)
     ret << decl->url().toUrl().toLocalFile();
-  
+
   return ret;
 }
 
@@ -242,8 +245,8 @@ QStringList candidateIncludeFilesFromNameMatcher(const QList<IncludeItem>& inclu
   return result;
 }
 
-KSharedPtr<MissingIncludeCompletionItem> includeDirectiveFromUrl(const KUrl& fromUrl, const IndexedDeclaration& decl) {
-  KSharedPtr<MissingIncludeCompletionItem> item;
+QExplicitlySharedDataPointer<MissingIncludeCompletionItem> includeDirectiveFromUrl(const QUrl &fromUrl, const IndexedDeclaration& decl) {
+  QExplicitlySharedDataPointer<MissingIncludeCompletionItem> item;
   if(decl.data()) {
     QSet<QString> temp;
     QStringList candidateFiles = candidateIncludeFiles(decl.data());
@@ -254,9 +257,9 @@ KSharedPtr<MissingIncludeCompletionItem> includeDirectiveFromUrl(const KUrl& fro
     foreach(const QString& file, candidateFiles)
       items += itemsForFile(QString(), file, includePaths, fromPath, decl, 0, temp);
 
-    qSort<QList<KDevelop::CompletionTreeItemPointer>::iterator, DirectiveShorterThan>(items.begin(), items.end(), DirectiveShorterThan());
+    std::sort(items.begin(), items.end(), DirectiveShorterThan());
     if(!items.isEmpty()) {
-      item = KSharedPtr<MissingIncludeCompletionItem>(dynamic_cast<MissingIncludeCompletionItem*>(items.begin()->data()));
+      item = QExplicitlySharedDataPointer<MissingIncludeCompletionItem>(dynamic_cast<MissingIncludeCompletionItem*>(items.begin()->data()));
     }
   }
   return item;
@@ -284,14 +287,14 @@ QList<KDevelop::CompletionTreeItemPointer> missingIncludeCompletionItems(const Q
     if(aliasDecl) {
       prefixes.insert(aliasDecl->importIdentifier());
     }else{
-      kDebug() << "Import is not based on NamespaceAliasDeclaration";
+      qCDebug(CPP) << "Import is not based on NamespaceAliasDeclaration";
     }
   }
-  
+
   QualifiedIdentifier namespaceScope = context->scopeIdentifier(false);
   for(int a = 1; a <= namespaceScope.count(); ++a)
     prefixes << namespaceScope.left(a); //Also search within enclosing namespaces
-  
+
   QList<KDevelop::CompletionTreeItemPointer> ret;
   QList<KDevelop::CompletionTreeItemPointer> blacklistRet;
 
@@ -301,18 +304,18 @@ QList<KDevelop::CompletionTreeItemPointer> missingIncludeCompletionItems(const Q
     if(delayed)
       //Remove all template parameters, because the symbol-table doesn't know about those
       identifier = removeTemplateParameters(delayed->identifier().identifier().identifier());
-    IdentifiedType* idType = dynamic_cast<IdentifiedType*>(type.unsafeData());
+    IdentifiedType* idType = dynamic_cast<IdentifiedType*>(type.data());
     if(idType) {
       identifier = removeTemplateParameters(idType->qualifiedIdentifier());
     }
   }else{
     //expression probably contains a part that needs to be resolved
-    
+
     if(expression.contains(".") || expression.contains("->")) {
       ///@todo Check if parts of the expression are unresolved, like in "unresolvedClass.callFunction"
-      kDebug() << "doing nothing with expression" << expression;
+      qCDebug(CPP) << "doing nothing with expression" << expression;
     }else{
-      kDebug() << "looking up" << expression << "as qualified identifier";
+      qCDebug(CPP) << "looking up" << expression << "as qualified identifier";
       identifier = removeTemplateParameters(QualifiedIdentifier(expression));
       QList<Declaration*> visibleDecls = context->findDeclarations(identifier);
       foreach(Declaration* decl, visibleDecls) {
@@ -321,30 +324,30 @@ QList<KDevelop::CompletionTreeItemPointer> missingIncludeCompletionItems(const Q
       }
     }
   }
-  
+
   if(identifier.isEmpty()) {
     return ret;
   }
-  
-  KUrl currentUrl(context->topContext()->url().str());
+
+  QUrl currentUrl = context->topContext()->url().toUrl();
   const auto currentPath = Path(currentUrl).parent();
 
   Cpp::EnvironmentFilePointer env(dynamic_cast<Cpp::EnvironmentFile*>(context->topContext()->parsingEnvironmentFile().data()));
   if(!env)
     return ret;
-  
-  
+
+
   Path::List includePaths;
-  
+
   foreach(const IndexedString& path, env->includePaths())
     includePaths << Path(path.toUrl());
-  
+
   includePaths.prepend(currentPath);
-  
+
   QSet<QString> directives;
-  
+
   QSet<DeclarationId> haveForwardDeclarationItems;
-  
+
   ///Search the persistent symbol table
   foreach(QualifiedIdentifier prefix, prefixes) {
     prefix.setExplicitlyGlobal(false);
@@ -356,19 +359,19 @@ QList<KDevelop::CompletionTreeItemPointer> missingIncludeCompletionItems(const Q
 
     if(declarationCount >  maxDeclarationCount)
       declarationCount = maxDeclarationCount;
-    
+
     for(uint a = 0; a < declarationCount; ++a) {
       KDevelop::ParsingEnvironmentFilePointer env = DUChain::self()->environmentFileForDocument(declarations[a].indexedTopContext());
       if(!env || !dynamic_cast<Cpp::EnvironmentFile*>(env.data()))
         continue;
-      
+
       Declaration* decl = declarations[a].declaration();
-      
+
       if(!decl)
         continue;
       if(dynamic_cast<KDevelop::AliasDeclaration*>(decl))
         continue;
-      
+
       if(!isSource(context->url().str())) {
         if(decl && (decl->context()->type() == DUContext::Namespace || decl->context()->type() == DUContext::Global) && !needInstance && (decl->type<CppClassType>() || decl->type<KDevelop::EnumerationType>()) ) {
           if(!haveForwardDeclarationItems.contains(decl->id()))
@@ -376,16 +379,16 @@ QList<KDevelop::CompletionTreeItemPointer> missingIncludeCompletionItems(const Q
           haveForwardDeclarationItems.insert(decl->id());
         }
       }
-      
+
       if(decl && !decl->isForwardDeclaration()) {
         if(context->topContext()->imports(decl->topContext(), CursorInRevision::invalid()))
           continue;
-        
+
         QString file(decl->url().toUrl().toLocalFile());
-        
+
         bool inBlacklistDir = isBlacklistedInclude(decl->url().toUrl());
         auto candidateFiles = candidateIncludeFiles(decl);
-        kDebug() << "candidates from DUChain:" << candidateFiles;
+        qCDebug(CPP) << "candidates from DUChain:" << candidateFiles;
         for (const QString& file : candidateFiles) {
           ret += itemsForFile(displayTextPrefix, file, includePaths, currentPath, decl, argumentHintDepth, directives);
         }
@@ -406,19 +409,19 @@ QList<KDevelop::CompletionTreeItemPointer> missingIncludeCompletionItems(const Q
     return ret;
 
   auto candidateFiles = candidateIncludeFilesFromNameMatcher(includeItems, identifier);
-  kDebug() << "candidates from name matching:" << candidateFiles;
+  qCDebug(CPP) << "candidates from name matching:" << candidateFiles;
   for (const QString& file : candidateFiles) {
     ret += itemsForFile(displayTextPrefix, file, includePaths, currentPath, IndexedDeclaration(), argumentHintDepth, directives);
   }
 
   if(ret.isEmpty())
     ret += blacklistRet;
-  
+
   {
     //If there is non-relative include directives, remove the relative ones
     QList<KDevelop::CompletionTreeItemPointer> relativeIncludes;
     QList<KDevelop::CompletionTreeItemPointer> nonRelativeIncludes;
-    
+
     for(QList<KDevelop::CompletionTreeItemPointer>::iterator it = ret.begin(); it != ret.end(); ) {
       MissingIncludeCompletionItem* currentItem = dynamic_cast<MissingIncludeCompletionItem*>(it->data());
       if(currentItem) {
@@ -429,15 +432,15 @@ QList<KDevelop::CompletionTreeItemPointer> missingIncludeCompletionItems(const Q
       }
       ++it;
     }
-    
+
     if(!nonRelativeIncludes.isEmpty()) {
       foreach(KDevelop::CompletionTreeItemPointer relative, relativeIncludes)
         ret.removeAll(relative);
     }
   }
 
-  qSort<QList<KDevelop::CompletionTreeItemPointer>::iterator, DirectiveShorterThan>(ret.begin(), ret.end(), DirectiveShorterThan());
-  
+  std::sort(ret.begin(), ret.end(), DirectiveShorterThan());
+
   return ret;
 }
 
@@ -452,25 +455,25 @@ MissingIncludeCompletionItem::MissingIncludeCompletionItem(const QString& addedI
 {
 }
 
-#define RETURN_CACHED_ICON(name) {static QIcon icon(KIcon(name).pixmap(QSize(16, 16))); return icon;}
+#define RETURN_CACHED_ICON(name) {static QIcon icon(QIcon::fromTheme(name).pixmap(QSize(16, 16))); return icon;}
 
 QVariant MissingIncludeCompletionItem::data(const QModelIndex& index, int role, const KDevelop::CodeCompletionModel* model) const {
   DUChainReadLocker lock(DUChain::lock(), 500);
   if(!lock.locked()) {
-    kDebug(9007) << "Failed to lock the du-chain in time";
+    qCDebug(CPP) << "Failed to lock the du-chain in time";
     return QVariant();
   }
   if(role == Qt::DecorationRole)
     if(index.column() == KTextEditor::CodeCompletionModel::Icon)
       RETURN_CACHED_ICON("CTparents")
-  
+
   switch (role) {
     case KTextEditor::CodeCompletionModel::IsExpandable:
       return QVariant(true);
     case KTextEditor::CodeCompletionModel::ExpandingWidget: {
       if(!m_decl.data())
         return QVariant();
-      
+
       Cpp::NavigationWidget* nav = new Cpp::NavigationWidget(DeclarationPointer(m_decl.data()), TopDUContextPointer(m_decl.data()->topContext()));
       model->addNavigationWidget(this, nav);
 
@@ -510,7 +513,8 @@ QString MissingIncludeCompletionItem::lineToInsert() const {
   return "#include " + m_addedInclude;
 }
 
-void MissingIncludeCompletionItem::execute(KTextEditor::Document* document, const KTextEditor::Range& word) {
+void MissingIncludeCompletionItem::execute(View* view, const Range& word) {
+  Document* document = view->document();
   // first try to find a proper include position from the DUChain
   int line = findIncludeLineFromDUChain(document, word.start().line(), m_canonicalPath);
 
@@ -566,9 +570,9 @@ QVariant ForwardDeclarationItem::data(const QModelIndex& index, int role, const
   if(role == Qt::DecorationRole && index.column() == KTextEditor::CodeCompletionModel::Icon) {
     RETURN_CACHED_ICON("dialog-ok"); ///@todo Better icon for the create-forward declaration action
   }
-  
+
   QVariant ret = NormalDeclarationCompletionItem::data(index, role, model);
-  
+
   if(role == Qt::DisplayRole && index.column() == KTextEditor::CodeCompletionModel::Name) {
     //Add some text behind the item, so we get some more info in minimal completion mode
     DUChainReadLocker lock(DUChain::lock());
@@ -577,26 +581,26 @@ QVariant ForwardDeclarationItem::data(const QModelIndex& index, int role, const
     return ret;
 //     return m_displayTextPrefix + ": " + i18n("Add Forward-Declaration");
   }
-  
+
   return ret;
 }
 
-void ForwardDeclarationItem::execute(KTextEditor::Document* document, const KTextEditor::Range& word) {
+void ForwardDeclarationItem::execute(KTextEditor::View* view, const KTextEditor::Range& word) {
   DUChainReadLocker lock(DUChain::lock());
   if(m_declaration) {
-    TopDUContext* top = DUChainUtils::standardContextForUrl(document->url());
+    TopDUContext* top = DUChainUtils::standardContextForUrl(view->document()->url());
     if(!top)
       return;
     Cpp::SourceCodeInsertion insertion(top);
-    
-    insertion.setInsertBefore(KDevelop::SimpleCursor(word.start()));
-    
+
+    insertion.setInsertBefore(KTextEditor::Cursor(word.start()));
+
     insertion.insertForwardDeclaration(m_declaration.data());
-    
+
     lock.unlock();
-    
+
     insertion.changes().setReplacementPolicy(DocumentChangeSet::WarnOnFailedChange);
-    
+
     if(!insertion.changes().applyAllChanges())
       return;
   }
