@@ -24,6 +24,7 @@
 #include <ktexteditor/document.h>
 
 #include <language/duchain/duchain.h>
+#include <language/duchain/duchaindumper.h>
 #include <language/duchain/topducontext.h>
 #include <language/duchain/declaration.h>
 #include <language/duchain/use.h>
@@ -31,15 +32,14 @@
 
 #include "parsesession.h"
 #include "name_compiler.h"
-#include <language/duchain/dumpchain.h>
 #include "environmentmanager.h"
+#include "expressionvisitor.h"
 
-#include <climits>
 #include "cppdebughelper.h"
 #include "debugbuilders.h"
 #include "rpp/chartools.h"
 #include "tokens.h"
-#include <klocalizedstring.h>
+#include "debug.h"
 
 using namespace KTextEditor;
 using namespace KDevelop;
@@ -127,7 +127,7 @@ void ContextBuilder::createUserProblem(AST* node, QString text) {
     DUChainWriteLocker lock(DUChain::lock());
     KDevelop::ProblemPointer problem(new KDevelop::Problem);
     problem->setDescription(text);
-    problem->setSource(KDevelop::ProblemData::DUChainBuilder);
+    problem->setSource(IProblem::DUChainBuilder);
     problem->setFinalLocation(DocumentRange(IndexedString(currentContext()->url().str()), editor()->findRange(node).castToSimpleRange()));
     currentContext()->topContext()->addProblem(problem);
 }
@@ -139,7 +139,7 @@ void ContextBuilder::addBaseType( KDevelop::BaseClassInstance base, BaseSpecifie
 
   Q_ASSERT(currentContext()->type() == DUContext::Class);
   AbstractType::Ptr baseClass = base.baseClass.abstractType();
-  IdentifiedType* idType = dynamic_cast<IdentifiedType*>(baseClass.unsafeData());
+  IdentifiedType* idType = dynamic_cast<IdentifiedType*>(baseClass.data());
   Declaration* idDecl = 0;
   if( idType && (idDecl = idType->declaration(currentContext()->topContext())) ) {
     DUContext* ctx = idDecl->logicalInternalContext(currentContext()->topContext());
@@ -160,7 +160,7 @@ void ContextBuilder::addBaseType( KDevelop::BaseClassInstance base, BaseSpecifie
 
 void addImportedParentContextSafely(DUContext* context, DUContext* import) {
   if(import->imports(context)) {
-    kDebug() << "prevented endless recursive import";
+    qCDebug(CPPDUCHAIN) << "prevented endless recursive import";
   }else{
     context->addImportedParentContext(import);
   }
@@ -214,7 +214,7 @@ ContextBuilder::~ContextBuilder ()
 QPair<DUContext*, QualifiedIdentifier> ContextBuilder::findPrefixContext(const QualifiedIdentifier& id, KDevelop::CursorInRevision pos) {
   if(id.count() < 2)
     return qMakePair((DUContext*)0, QualifiedIdentifier());
-  
+
   QualifiedIdentifier prefixId(id);
   prefixId.pop();
 
@@ -236,11 +236,11 @@ QPair<DUContext*, QualifiedIdentifier> ContextBuilder::findPrefixContext(const Q
         if(prefixId.count() >= currentScopeId.count() && prefixId.left(currentScopeId.count()) == currentScopeId)
           prefixId = prefixId.mid(currentScopeId.count());
         else
-          kDebug() << "resolved bad prefix context. Should start with" << currentScopeId.toString() << "but is" << prefixId.toString();
+          qCDebug(CPPDUCHAIN) << "resolved bad prefix context. Should start with" << currentScopeId.toString() << "but is" << prefixId.toString();
       }
     }
   }
-  
+
   return qMakePair(import, prefixId);
 }
 
@@ -256,7 +256,7 @@ void ContextBuilder::openPrefixContext(AST* ast, const QualifiedIdentifier& id,
   openContext(ast, DUContext::Helper, prefix.second);
 
   DUContext* import = prefix.first;
-  
+
   if(import) {
     DUChainWriteLocker lock(DUChain::lock());
     addImportedParentContextSafely(currentContext(), import);
@@ -272,7 +272,7 @@ void ContextBuilder::closePrefixContext(const QualifiedIdentifier& id) {
 void ContextBuilder::visitTemplateDeclaration(TemplateDeclarationAST * ast) {
 
   ++m_templateDeclarationDepth;
-  
+
   if(!m_onlyComputeSimplified)
   {
     AST* first, *last;
@@ -286,7 +286,7 @@ void ContextBuilder::visitTemplateDeclaration(TemplateDeclarationAST * ast) {
 
     visitNodes(this,ast->template_parameters);
     closeContext();
-    
+
     queueImportedContext(ctx); //Import the context into the following function-argument context(so the template-parameters can be found from there)
   }
 
@@ -298,7 +298,7 @@ void ContextBuilder::visitTemplateDeclaration(TemplateDeclarationAST * ast) {
 KDevelop::TopDUContext* ContextBuilder::buildProxyContextFromContent(Cpp::EnvironmentFilePointer file, const TopDUContextPointer& content, const TopDUContextPointer& updateContext)
 {
   Cpp::EnvironmentFile* filePtr = const_cast<Cpp::EnvironmentFile*>(file.data() );
-  
+
   filePtr->setIsProxyContext(true);
 
   TopDUContext* topLevelContext = 0;
@@ -309,14 +309,14 @@ KDevelop::TopDUContext* ContextBuilder::buildProxyContextFromContent(Cpp::Enviro
     CppDUContext<TopDUContext>* cppContext = 0;
 
     if (topLevelContext) {
-      kDebug(9007) << "ContextBuilder::buildProxyContextFromContent: recompiling";
+      qCDebug(CPPDUCHAIN) << "ContextBuilder::buildProxyContextFromContent: recompiling";
 
       Q_ASSERT(dynamic_cast<CppDUContext<TopDUContext>* >(topLevelContext));
       cppContext = static_cast<CppDUContext<TopDUContext>* >(topLevelContext);
 
       DUChain::self()->updateContextEnvironment( topLevelContext, filePtr );
     } else {
-      kDebug(9007) << "ContextBuilder::buildProxyContextFromContent: compiling";
+      qCDebug(CPPDUCHAIN) << "ContextBuilder::buildProxyContextFromContent: compiling";
 
       topLevelContext = new CppDUContext<TopDUContext>(file->url(), RangeInRevision(), filePtr);
       topLevelContext->setType(DUContext::Global);
@@ -325,12 +325,12 @@ KDevelop::TopDUContext* ContextBuilder::buildProxyContextFromContent(Cpp::Enviro
       cppContext = static_cast<CppDUContext<TopDUContext>* >(topLevelContext);
 
       DUChain::self()->addDocumentChain(topLevelContext);
-      
+
       topLevelContext->updateImportsCache(); //Mark that we will use a cached import-structure
     }
 
     Q_ASSERT(content);
-    
+
     cppContext->clearImportedParentContexts();
     cppContext->addImportedParentContext(content.data());
     cppContext->updateImportsCache(); //Mark that we will use a cached import-structure
@@ -349,25 +349,25 @@ ReferencedTopDUContext ContextBuilder::buildContexts(Cpp::EnvironmentFilePointer
   {
     DUChainWriteLocker lock(DUChain::lock());
     if(updateContext && (updateContext->parsingEnvironmentFile() && updateContext->parsingEnvironmentFile()->isProxyContext())) {
-      kDebug(9007) << "updating a context " << file->url().str() << " from a proxy-context to a content-context";
+      qCDebug(CPPDUCHAIN) << "updating a context " << file->url().str() << " from a proxy-context to a content-context";
       updateContext->parsingEnvironmentFile()->setIsProxyContext(false);
     }
   }
-  
+
   ReferencedTopDUContext topLevelContext;
   {
     DUChainWriteLocker lock(DUChain::lock());
     topLevelContext = updateContext;
 
     RangeInRevision topRange = RangeInRevision(CursorInRevision(0,0), CursorInRevision(INT_MAX, INT_MAX));
-    
+
     if (topLevelContext) {
-      kDebug(9007) << "ContextBuilder::buildContexts: recompiling";
+      qCDebug(CPPDUCHAIN) << "ContextBuilder::buildContexts: recompiling";
       setRecompiling(true);
       DUChain::self()->updateContextEnvironment( topLevelContext, const_cast<Cpp::EnvironmentFile*>(file.data() ) );
       topLevelContext->setRange(topRange);
     } else {
-      kDebug(9007) << "ContextBuilder::buildContexts: compiling";
+      qCDebug(CPPDUCHAIN) << "ContextBuilder::buildContexts: compiling";
       setRecompiling(false);
 
       Q_ASSERT(compilingContexts());
@@ -375,9 +375,8 @@ ReferencedTopDUContext ContextBuilder::buildContexts(Cpp::EnvironmentFilePointer
       topLevelContext = new CppDUContext<TopDUContext>(file->url(), topRange, const_cast<Cpp::EnvironmentFile*>(file.data()));
 
       topLevelContext->setType(DUContext::Global);
-      topLevelContext->setFlags((TopDUContext::Flags)(TopDUContext::UpdatingContext | topLevelContext->flags()));
       DUChain::self()->addDocumentChain(topLevelContext);
-    
+
       topLevelContext->updateImportsCache(); //Mark that we will use a cached import-structure
     }
 
@@ -400,7 +399,7 @@ ReferencedTopDUContext ContextBuilder::buildContexts(Cpp::EnvironmentFilePointer
 
       topLevelContext->addImportedParentContexts(realIncluded);
       topLevelContext->addImportedParentContexts(realTemporaryIncluded, true);
-      
+
       topLevelContext->updateImportsCache();
     }
   }
@@ -408,7 +407,7 @@ ReferencedTopDUContext ContextBuilder::buildContexts(Cpp::EnvironmentFilePointer
   {
     DUChainReadLocker lock(DUChain::lock());
     //If we're debugging the current file, dump its preprocessed contents and the AST
-    ifDebugFile( IndexedString(file->identity().url().str()), { kDebug() << stringFromContents(editor()->parseSession()->contentsVector()); Cpp::DumpChain dump; dump.dump(node, editor()->parseSession()); } );
+    ifDebugFile( IndexedString(file->identity().url().str()), { qCDebug(CPPDUCHAIN) << stringFromContents(editor()->parseSession()->contentsVector()); Cpp::DumpChain dump; dump.dump(node, editor()->parseSession()); } );
   }
 
   if(m_computeEmpty)
@@ -425,29 +424,19 @@ ReferencedTopDUContext ContextBuilder::buildContexts(Cpp::EnvironmentFilePointer
   {
     DUChainReadLocker lock(DUChain::lock());
 
-    kDebug(9007) << "built top-level context with" << topLevelContext->localDeclarations().size() << "declarations and" << topLevelContext->importedParentContexts().size() << "included files";
+    qCDebug(CPPDUCHAIN) << "built top-level context with" << topLevelContext->localDeclarations().size() << "declarations and" << topLevelContext->importedParentContexts().size() << "included files";
     //If we're debugging the current file, dump the du-chain and the smart ranges
-    ifDebugFile( IndexedString(file->identity().url().str()), { KDevelop::dumpDUContext(topLevelContext); } );
-
-/*     if( m_recompiling ) {
-      dumpDUContext(topLevelContext);
-      kDebug(9007) << dump.dotGraph(topLevelContext);
-     }*/
+    ifDebugFile( IndexedString(file->identity().url().str()), { DUChainDumper dumper; dumper.dump(topLevelContext); } );
   }
 
   setCompilingContexts(false);
 
   if (!m_importedParentContexts.isEmpty()) {
     DUChainReadLocker lock(DUChain::lock());
-    kWarning() << file->url().str() << "Previous parameter declaration context didn't get used??" ;
-//    KDevelop::DumpChain dump;
-//    dump.dump(topLevelContext);
+    qCWarning(CPPDUCHAIN) << file->url().str() << "Previous parameter declaration context didn't get used??" ;
     m_importedParentContexts.clear();
   }
 
-
-  DUChainWriteLocker lock(DUChain::lock());
-  topLevelContext->squeeze();
   return topLevelContext;
 }
 
@@ -462,12 +451,12 @@ void ContextBuilder::visitNamespace (NamespaceAST *node)
   }
 
   size_t realStart = node->start_token;
-  
+
   if(node->namespace_name) //Move the start behind the name, the simple + hacky way
     node->start_token = node->namespace_name+1;
-  
+
   openContext(node, DUContext::Namespace, identifier);
-  
+
   node->start_token = realStart;
 
   DefaultVisitor::visitNamespace (node);
@@ -479,7 +468,7 @@ void ContextBuilder::visitEnumSpecifier(EnumSpecifierAST* node)
 {
   if(m_onlyComputeSimplified)
     return;
-  
+
   //The created context must be unnamed if not an "enum class", so the enumerators can be found globally with the correct scope.
   //In case of an "enum class" this enum creates its own context.
   openContext(node, DUContext::Enum, node->isClass ? node->name : 0 );
@@ -521,7 +510,7 @@ void ContextBuilder::visitClassSpecifier (ClassSpecifierAST *node)
     if ((kind == Token_union || id.isEmpty())) {
       //It's an unnamed union context, or an unnamed struct, propagate the declarations to the parent
       DUChainWriteLocker lock(DUChain::lock());
-        
+
       if(kind == Token_enum || kind == Token_union || m_typeSpecifierWithoutInitDeclarators == node->start_token) {
         ///@todo Mark unions in the duchain in some way, instead of just representing them as a class
         currentContext()->setInSymbolTable(currentContext()->parentContext()->inSymbolTable());
@@ -529,7 +518,7 @@ void ContextBuilder::visitClassSpecifier (ClassSpecifierAST *node)
       }
     }
   }
-  
+
   classContextOpened(node, currentContext());
 
   DefaultVisitor::visitClassSpecifier (node);
@@ -554,21 +543,22 @@ void ContextBuilder::visitFunctionDefinition (FunctionDefinitionAST *node)
     identifierForNode(node->declarator->id, functionName);
 
     if (functionName.count() >= 2) {
-      
+
       // This is a class function definition
       DUChainReadLocker lock(DUChain::lock());
       QualifiedIdentifier currentScope = currentContext()->scopeIdentifier(true);
       QualifiedIdentifier className = currentScope + functionName;
       className.pop();
       className.setExplicitlyGlobal(true);
-      
+
       QList<Declaration*> classDeclarations = currentContext()->findDeclarations(className);
 
       if (classDeclarations.count() != 0 && classDeclarations.first()->internalContext()) {
         queueImportedContext(classDeclarations.first()->internalContext());
-        
+
         QualifiedIdentifier newFunctionName(className);
         newFunctionName.push(functionName.last());
+        newFunctionName.setExplicitlyGlobal(false);
         if(newFunctionName.count() > currentScope.count())
           functionName = newFunctionName.mid(currentScope.count());
       }
@@ -579,7 +569,7 @@ void ContextBuilder::visitFunctionDefinition (FunctionDefinitionAST *node)
   if(!m_onlyComputeVisible) { //If we only compute the publically visible, we don't need to go into function bodies
     m_openingFunctionBody = functionName;
 
-    
+
     if (node->constructor_initializers && node->function_body) {
       //Since we put the context around the context for the compound statement, it also gets the local scope identifier.
       openContext(node->constructor_initializers, node->function_body, DUContext::Other, m_openingFunctionBody); //The constructor initializer context
@@ -596,7 +586,7 @@ void ContextBuilder::visitFunctionDefinition (FunctionDefinitionAST *node)
       closeContext();
     }
   }
-  
+
   visit(node->win_decl_specifiers);
   // If still defined, not needed
   m_importedParentContexts.clear();
@@ -612,7 +602,7 @@ DUContext* ContextBuilder::openContextEmpty(AST* rangeNode, DUContext::ContextTy
 {
   if (compilingContexts()) {
 #ifdef DEBUG_UPDATE_MATCHING
-    kDebug() << "opening context with text" << editor()->tokensToStrings( rangeNode->start_token, rangeNode->end_token );
+    qCDebug(CPPDUCHAIN) << "opening context with text" << editor()->tokensToStrings( rangeNode->start_token, rangeNode->end_token );
 #endif
     KDevelop::RangeInRevision range = editor()->findRangeForContext(rangeNode->start_token, rangeNode->end_token);
     range.end = range.start;
@@ -634,7 +624,7 @@ DUContext* ContextBuilder::openContextInternal(const KDevelop::RangeInRevision&
     DUChainWriteLocker lock(DUChain::lock());
     static_cast<CppDUContext<DUContext>*>(ret)->deleteAllInstantiations();
   }
-  
+
   /**
    * @todo either remove this here and add it to the correct other places, or remove it in the over places.
    * The problem: For template-parameter contexts this needs to be imported into function-parameter contexts
@@ -655,7 +645,7 @@ void ContextBuilder::checkRanges()
 {
   for(QHash<KDevelop::DUContext*, KDevelop::RangeInRevision>::iterator it = m_contextRanges.begin(); it != m_contextRanges.end(); ) {
     if(it.key()->range() != *it) {
-      kDebug(9007) << "Range of" << it.key()->scopeIdentifier(true).toString() << "changed from" << (*it).textRange() << "to" << it.key()->range().textRange() << "at\n" << kBacktrace();
+      qCDebug(CPPDUCHAIN) << "Range of" << it.key()->scopeIdentifier(true).toString() << "changed from" << (*it) << "to" << it.key()->range() << "at\n" << kBacktrace();
       it = m_contextRanges.erase(it); //Remove it so we see each change only once
     }else{
       ++it;
@@ -684,7 +674,7 @@ void ContextBuilder::preVisitSimpleDeclaration(SimpleDeclarationAST * node) {
 void ContextBuilder::visitSimpleDeclaration(SimpleDeclarationAST *node)
 {
   preVisitSimpleDeclaration(node);
-  
+
   DefaultVisitor::visitSimpleDeclaration(node);
 
   // Didn't get claimed if it was still set
@@ -717,7 +707,7 @@ class VerifyExpressionVisitor : public Cpp::ExpressionVisitor {
   public:
     VerifyExpressionVisitor(ParseSession* session) : Cpp::ExpressionVisitor(session), result(true) {
     }
-    virtual void problem(AST* /*node*/, const QString& /*str*/) {
+    virtual void problem(AST* /*node*/, const QString& /*str*/) override {
       result = false;
     }
 
@@ -738,7 +728,7 @@ public:
   bool result; //Will be true when this should be an expression, else false.
   CursorInRevision cursor;
 
-  void visitPostfixExpression(PostfixExpressionAST* node)
+  void visitPostfixExpression(PostfixExpressionAST* node) override
   {
     if( node->expression && node->expression->kind == AST::Kind_PrimaryExpression &&
         node->sub_expressions ) {
@@ -757,7 +747,7 @@ public:
     visitNodes( this, node->sub_expressions );
   }
 
-  virtual void visitName (NameAST * node)
+  virtual void visitName (NameAST * node) override
   {
     if (result) {
       QualifiedIdentifier id;
@@ -776,7 +766,7 @@ void ContextBuilder::visitExpressionOrDeclarationStatement(ExpressionOrDeclarati
     visit(node->declaration);
     return;
   }
-  
+
   DUContext::ContextType type;
   {
     DUChainReadLocker lock(DUChain::lock());
@@ -802,7 +792,7 @@ void ContextBuilder::visitExpressionOrDeclarationStatement(ExpressionOrDeclarati
         iv.parse(node->expression);*/
         IdentifierVerifier iv(this, CursorInRevision(editor()->findPosition(node->start_token)));
         iv.visit(node->expression);
-        //kDebug(9007) << editor()->findPosition(node->start_token) << "IdentifierVerifier returned" << iv.result;
+        //qCDebug(CPPDUCHAIN) << editor()->findPosition(node->start_token) << "IdentifierVerifier returned" << iv.result;
         node->expressionChosen = iv.result;
       }
 
@@ -890,9 +880,9 @@ void ContextBuilder::visitParameterDeclarationClause(ParameterDeclarationClauseA
   //Don't assign the initializer to parameter-declarations
   InitializerAST* oldCurrentInitializer = m_currentInitializer;
   m_currentInitializer = 0;
-  
+
   DefaultVisitor::visitParameterDeclarationClause(node);
-  
+
   m_currentInitializer = oldCurrentInitializer;
 }
 
@@ -903,7 +893,7 @@ void ContextBuilder::visitInitDeclarator(InitDeclaratorAST *node)
     //Build a prefix-context for external variable-definitions
     CursorInRevision pos = editor()->findPosition(node->start_token, CppEditorIntegrator::FrontEdge);
     identifierForNode(node->declarator->id, id);
-    
+
     openPrefixContext(node, id, pos);
   }
 
@@ -913,12 +903,12 @@ void ContextBuilder::visitInitDeclarator(InitDeclaratorAST *node)
   if(node->initializer)
     visitInitializer(node->initializer);
   m_currentInitializer = 0;
-  
+
   closePrefixContext(id);
 }
 
 void ContextBuilder::visitDeclarator(DeclaratorAST *node) {
-  
+
   //BEGIN Copied from default visitor
   visit(node->sub_declarator);
   visitNodes(this, node->ptr_ops);
@@ -1041,7 +1031,7 @@ void ContextBuilder::visitSwitchStatement(SwitchStatementAST* node)
 void ContextBuilder::visitDoStatement(DoStatementAST *node)
 {
   if(!node->statement) {
-    kWarning() << "error, no statement"; //Warning instead of crashing here
+    qCWarning(CPPDUCHAIN) << "error, no statement"; //Warning instead of crashing here
     return;
   }
   //We don't need to create a context for compound-statements, since those create a context by themselves
@@ -1096,7 +1086,7 @@ void ContextBuilder::visitCatchStatement(CatchStatementAST *node)
 
   if (node->condition) {
     DUContext* secondParentContext = openContext(node->condition, DUContext::Other);
-    
+
     {
       DUChainReadLocker lock(DUChain::lock());
       contextsToImport.append(DUContext::Import(secondParentContext, 0));
@@ -1149,7 +1139,7 @@ bool ContextBuilder::createContextIfNeeded(AST* node, DUContext* importedParentC
     DUChainReadLocker lock(DUChain::lock());
     imports << DUContext::Import(importedParentContext, 0);
   }
-  
+
   return createContextIfNeeded(node, imports);
 }
 
