@@ -29,24 +29,24 @@
 #include "tokens.h"
 #include "typebuilder.h"
 #include "cpptypes.h"
-#include <language/duchain/dumpchain.h>
 #include "typeutils.h"
 #include "name_visitor.h"
 #include "type_visitor.h"
 #include "lexer.h"
 #include "overloadresolution.h"
-#include "cppduchain.h"
 #include "overloadresolutionhelper.h"
 #include "builtinoperators.h"
 #include "qtfunctiondeclaration.h"
 #include "missingdeclarationtype.h"
 #include "missingdeclarationproblem.h"
 #include "dumpchain.h"
+#include "ptrtomembertype.h"
+#include "debug.h"
 
 //If this is enabled and a type is not found, it is searched again with verbose debug output.
 //#define DEBUG_RESOLUTION_PROBLEMS
 
-//If this is enabled, all encounterd problems will be dumped to kDebug
+//If this is enabled, all encounterd problems will be dumped to qDebug
 // #define DUMP_PROBLEMS
 
 //If this is enabled, problems will be created when no overloaded function was found for a function-call. This is expensive,
@@ -219,9 +219,9 @@ QList<ProblemPointer> ExpressionVisitor::realProblems() const {
 
 void ExpressionVisitor::problem( AST* node, const QString& str ) {
 #ifdef DUMP_PROBLEMS
-  kDebug(9007) << "Cpp::ExpressionVisitor problem:" << str;
+  qCDebug(CPPDUCHAIN) << "Cpp::ExpressionVisitor problem:" << str;
 
-  kDebug(9007) << "Cpp::ExpressionVisitor dumping the node that created the problem";
+  qCDebug(CPPDUCHAIN) << "Cpp::ExpressionVisitor dumping the node that created the problem";
   Cpp::DumpChain d;
 
   d.dump(node, m_session);
@@ -323,8 +323,8 @@ void ExpressionVisitor::findMember( AST* node, AbstractType::Ptr base, const Ide
 
         PointerType::Ptr pnt = realType(m_lastType, topContext()).cast<PointerType>();
         if( pnt ) {
-/*          kDebug(9007) << "got type:" << pnt->toString();
-          kDebug(9007) << "base-type:" << pnt->baseType()->toString();*/
+/*          qCDebug(CPPDUCHAIN) << "got type:" << pnt->toString();
+          qCDebug(CPPDUCHAIN) << "base-type:" << pnt->baseType()->toString();*/
 
           isConst = isConstant(pnt.cast<AbstractType>());
           //It is a pointer, reduce the pointer-depth by one
@@ -407,7 +407,7 @@ void ExpressionVisitor::findMember( AST* node, AbstractType::Ptr base, const Ide
   Declaration* ExpressionVisitor::getDeclaration( const AbstractType::Ptr& base ) {
     if( !base ) return 0;
 
-    const IdentifiedType* idType = dynamic_cast<const IdentifiedType*>(base.unsafeData());
+    const IdentifiedType* idType = dynamic_cast<const IdentifiedType*>(base.data());
     if( idType ) {
       LOCKDUCHAIN;
       return idType->declaration(topContext());
@@ -429,9 +429,9 @@ void ExpressionVisitor::findMember( AST* node, AbstractType::Ptr base, const Ide
     const DUContext* searchInContext = m_currentContext;
 
     m_hadMemberAccess = m_memberAccess;
-    
+
     CursorInRevision position = m_session->positionAt( m_session->token_stream->position(node->start_token) );
-    if( m_currentContext->url() != m_session->m_url ) //.equals( m_session->m_url, KUrl::CompareWithoutTrailingSlash ) )
+    if( m_currentContext->url() != m_session->m_url ) //.equals( m_session->m_url, QUrl::CompareWithoutTrailingSlash ) )
       position = position.invalid();
 
     bool isConst = false;
@@ -471,16 +471,15 @@ void ExpressionVisitor::findMember( AST* node, AbstractType::Ptr base, const Ide
       return;
     }
 
-    QualifiedIdentifier identifier = nameV.identifier();
+    const QualifiedIdentifier& identifier = nameV.identifier();
 
     ///@todo It would be better if the parser would treat true and false exactly
     ///like constant-integer expressions, storing them in a primary expression.
-    static QualifiedIdentifier trueIdentifier("true");
-    static QualifiedIdentifier falseIdentifier("false");
+    static const QualifiedIdentifier trueIdentifier("true");
+    static const QualifiedIdentifier falseIdentifier("false");
 
     if( identifier == trueIdentifier || identifier == falseIdentifier ) {
       ///We have a boolean constant, we need to catch that here
-      LOCKDUCHAIN;
       ConstantIntegralType::Ptr type(new ConstantIntegralType(IntegralType::TypeBoolean));
       type->setValue<qint64>( identifier == trueIdentifier );
       m_lastType = type.cast<AbstractType>();
@@ -495,7 +494,7 @@ void ExpressionVisitor::findMember( AST* node, AbstractType::Ptr base, const Ide
         if(Cpp::isTemplateDependent(m_currentContext) ) {
           if(m_memberAccess || (node->qualified_names && nameV.foundSomething() && Cpp::isTemplateDependent(nameV.foundSomething().data()))) {
           //Do nothing. Within a not instantiated template, we cannot be that sure
-          m_lastType.clear();
+          m_lastType.reset();
           return;
           }
         }
@@ -510,9 +509,9 @@ void ExpressionVisitor::findMember( AST* node, AbstractType::Ptr base, const Ide
 
         if(m_reportRealProblems && m_problems.size() < maxExpressionVisitorProblems) {
           ProblemPointer problem(new Cpp::MissingDeclarationProblem(missing));
-          problem->setSource(KDevelop::ProblemData::SemanticAnalysis);
+          problem->setSource(IProblem::SemanticAnalysis);
           CppEditorIntegrator editor(session());
-          
+
           problem->setFinalLocation(DocumentRange(m_currentContext->url(), editor.findRange(node).castToSimpleRange()));
           if(!problem->range().isEmpty() && !editor.findRangeForContext(node->start_token, node->end_token).isEmpty())
             m_problems << problem;
@@ -533,7 +532,7 @@ void ExpressionVisitor::findMember( AST* node, AbstractType::Ptr base, const Ide
         if (m_propagateConstness && isConst && m_lastType && !isConstant(m_lastType)) {
           m_lastType->setModifiers(m_lastType->modifiers() | AbstractType::ConstModifier);
         }
-        //kDebug(9007) << "found declaration: " << m_lastDeclarations.first()->toString();
+        //qCDebug(CPPDUCHAIN) << "found declaration: " << m_lastDeclarations.first()->toString();
 
         ///If the found declaration declares a type, this is a type-expression and m_lastInstance should be zero.
         ///The declaration declares a type if its abstractType's declaration is that declaration. Else it is an insantiation, and m_lastType should be filled.
@@ -592,7 +591,6 @@ void ExpressionVisitor::findMember( AST* node, AbstractType::Ptr base, const Ide
     if (token.kind == Token_number_literal) {
       QString num = m_session->token_stream->symbolString(token);
 
-      LOCKDUCHAIN;
       if( num.indexOf('.') != -1 || num.endsWith('f') || num.endsWith('d') ) {
         double val = 0;
         bool ok = false;
@@ -637,7 +635,6 @@ void ExpressionVisitor::findMember( AST* node, AbstractType::Ptr base, const Ide
       return;
     } else if(token.kind == Token_char_literal) {
       // char literal e.g. 'x'
-      LOCKDUCHAIN;
       ConstantIntegralType::Ptr charType(new ConstantIntegralType(IntegralType::TypeChar));
       if ( token.size == 3 ) {
         charType->setValue<char>( m_session->token_stream->symbolByteArray(token).at(1) );
@@ -645,13 +642,13 @@ void ExpressionVisitor::findMember( AST* node, AbstractType::Ptr base, const Ide
         QByteArray symbol = m_session->token_stream->symbolByteArray(token);
         if (symbol.startsWith('L')) {
           charType->setDataType(IntegralType::TypeWchar_t);
-          symbol.right(symbol.size() - 1);
+          symbol.remove(0, 1);
         } else if (symbol.startsWith('u')) {
           charType->setDataType(IntegralType::TypeChar16_t);
-          symbol.right(symbol.size() - 1);
+          symbol.remove(0, 1);
         } else if (symbol.startsWith('U')) {
           charType->setDataType(IntegralType::TypeChar32_t);
-          symbol.right(symbol.size() - 1);
+          symbol.remove(0, 1);
         }
         if (symbol.size() == 4) {
           if (symbol == "'\\t'") {
@@ -668,7 +665,6 @@ void ExpressionVisitor::findMember( AST* node, AbstractType::Ptr base, const Ide
       m_lastInstance = Instance( true );
     } else if (token.kind == Token_true || token.kind == Token_false) {
       ///We have a boolean constant, we need to catch that here
-      LOCKDUCHAIN;
       ConstantIntegralType::Ptr type(new ConstantIntegralType(IntegralType::TypeBoolean));
       type->setValue<qint64>( token.kind == Token_true );
       m_lastType = type.cast<AbstractType>();
@@ -791,10 +787,10 @@ void ExpressionVisitor::findMember( AST* node, AbstractType::Ptr base, const Ide
   void ExpressionVisitor::visitPostfixExpression(PostfixExpressionAST* node)
   {
     clearLast();
-    
+
     //First evaluate the primary expression, or the type-specifier,
     //and then pass the result from sub-expression to sub-expression through m_lastType
-    
+
     if( node->type_specifier )
       visit( node->type_specifier );
 
@@ -922,7 +918,7 @@ void ExpressionVisitor::createDelayedType( AST* node , bool expression ) {
         m_parameterNodes.append(node->left_expression);
 
         //LOCKDUCHAIN;
-        //kDebug(9007) << "Adding parameter from left: " << (leftType.data() ? leftType->toString() : QString("<notype>"));
+        //qCDebug(CPPDUCHAIN) << "Adding parameter from left: " << (leftType.data() ? leftType->toString() : QString("<notype>"));
       } else {
         //If neither leftType nor leftInstance are true, the expression was probably another binary
         //expression that has put the types/instances into m_parameters and returns nothing.
@@ -935,7 +931,7 @@ void ExpressionVisitor::createDelayedType( AST* node , bool expression ) {
           m_parameters << OverloadResolver::Parameter(AbstractType::Ptr(), false);
           m_parameterNodes.append(node->left_expression);
           //LOCKDUCHAIN;
-          //kDebug(9007) << "Adding empty from left";
+          //qCDebug(CPPDUCHAIN) << "Adding empty from left";
         }
       }
     }
@@ -952,7 +948,7 @@ void ExpressionVisitor::createDelayedType( AST* node , bool expression ) {
         m_parameters << OverloadResolver::Parameter(rightType, isLValue( rightType, rightInstance ), rightInstance.declaration.data() );
         m_parameterNodes.append(node->right_expression);
         //LOCKDUCHAIN;
-        //kDebug(9007) << "Adding parameter from right: " << (rightType.data() ? rightType->toString() : QString("<notype>"));
+        //qCDebug(CPPDUCHAIN) << "Adding parameter from right: " << (rightType.data() ? rightType->toString() : QString("<notype>"));
       } else {
         //If neither leftType nor leftInstance are true, the expression was probably another binary
         //expression that has put the types/instances into m_parameters and returns nothing.
@@ -964,7 +960,7 @@ void ExpressionVisitor::createDelayedType( AST* node , bool expression ) {
 
           m_parameters << OverloadResolver::Parameter(AbstractType::Ptr(), false);
           m_parameterNodes.append(node->right_expression);
-          //kDebug(9007) << "Adding empty from right";
+          //qCDebug(CPPDUCHAIN) << "Adding empty from right";
         }
       }
 
@@ -1152,18 +1148,22 @@ void ExpressionVisitor::createDelayedType( AST* node , bool expression ) {
 
       bool fail = true;
 
-      size_t token = node->start_token;
+      size_t start_token = node->start_token;
       //NOTE: we might have an initializer in a class for pure virtual methods,
       //      but we just ignore that. See also TestDUChain::testForwardDeclaration4
-      if(node->initializer && m_currentContext->type() != DUContext::Class)
+      if(m_currentContext->type() != DUContext::Class)
       {
-        if(node->initializer->expression && !node->initializer->initializer_clause)
+        if (!node->initializer) {
+          // No InitializerAST => Default-initialization (e.g. '{ A a; }')
+          start_token = node->end_token;
+          fail = false;
+        } else if(node->initializer->expression && !node->initializer->initializer_clause)
         {
-          token = node->initializer->start_token;
+          start_token = node->initializer->start_token;
           fail = !buildParametersFromExpression(node->initializer->expression);
         } else if(!node->initializer->expression && node->initializer->initializer_clause && constructedType)
         { // report operator= use in i.e.: foo = bar;
-          token = node->initializer->start_token;
+          start_token = node->initializer->start_token;
           fail = !buildParametersFromExpression(node->initializer->initializer_clause);
           declarations.clear();
           LOCKDUCHAIN;
@@ -1178,7 +1178,7 @@ void ExpressionVisitor::createDelayedType( AST* node , bool expression ) {
           }
         } else if (!node->initializer->expression && !node->initializer->initializer_clause) {
           // ctor without parameters, i.e.: foo();
-          token = node->initializer->start_token;
+          start_token = node->initializer->start_token;
           fail = false;
         }
       }
@@ -1206,7 +1206,10 @@ void ExpressionVisitor::createDelayedType( AST* node , bool expression ) {
       }
 
       if(chosenFunction) {
-        newUse( node , token, token+1, chosenFunction );
+        // if there's an InitializerAST, we let 'Show Uses' point to the opening bracket of the ctor call
+        // unfortunately for cases '{ A a; }', we don't have anything we can point to
+        const size_t end_token = start_token + (node->initializer ? 1 : 0);
+        newUse( node , start_token, end_token, chosenFunction );
         if(m_mapAst) session()->mapCallAstToType(node, chosenFunction->type<FunctionType>());
       }
     }else{
@@ -1248,7 +1251,6 @@ void ExpressionVisitor::createDelayedType( AST* node , bool expression ) {
     visit(node->parameter_declaration_clause);
     visit(node->exception_spec);
     {
-    LOCKDUCHAIN;
     if( node->array_dimensions && oldLastType ) {
       ArrayType::Ptr p( new ArrayType() );
       p->setElementType( oldLastType );
@@ -1423,7 +1425,6 @@ void ExpressionVisitor::createDelayedType( AST* node , bool expression ) {
 
     if( m_lastType )
     {
-      LOCKDUCHAIN;
       ///@todo cv-qualifiers
       PointerType::Ptr p( new PointerType() );
       p->setBaseType( m_lastType );
@@ -1515,7 +1516,6 @@ void ExpressionVisitor::createDelayedType( AST* node , bool expression ) {
     visit(node->right_expression);
 
     {
-      LOCKDUCHAIN;
       if( const ConstantIntegralType::Ptr& condition = conditionType.cast<ConstantIntegralType>() ) {
         ///For constant integral types, the condition could be evaluated, so we choose the correct result.
         if( condition->value<quint64>() == 0 ) {
@@ -1735,7 +1735,7 @@ void ExpressionVisitor::createDelayedType( AST* node , bool expression ) {
     if(!m_lastInstance) {
       LOCKDUCHAIN;
       if(m_lastDeclarations.isEmpty() && m_lastType && !m_lastInstance) {
-        IdentifiedType* idType = dynamic_cast<IdentifiedType*>(m_lastType.unsafeData());
+        IdentifiedType* idType = dynamic_cast<IdentifiedType*>(m_lastType.data());
         if(idType) {
           Declaration* decl = idType->declaration(m_source);
           if(decl)
@@ -1867,7 +1867,7 @@ void ExpressionVisitor::createDelayedType( AST* node , bool expression ) {
         LOCKDUCHAIN;
         //The function-call operator may also be applied on instances that don't have an explicit declaration, like return-values
         AbstractType::Ptr type = realType(m_lastType);
-        IdentifiedType* identified = dynamic_cast<IdentifiedType*>(type.unsafeData());
+        IdentifiedType* identified = dynamic_cast<IdentifiedType*>(type.data());
         if(identified) {
           DeclarationPointer decl(identified->declaration(m_source));
           if(decl) {
@@ -1901,7 +1901,7 @@ void ExpressionVisitor::createDelayedType( AST* node , bool expression ) {
     helper.setConstness(TypeUtils::isConstant(oldLastType) ? OverloadResolver::Const : OverloadResolver::NonConst);
 
     MissingDeclarationType::Ptr missing;
-    
+
     Declaration* dec = declarations.isEmpty() ? 0 : declarations.first().data();
     if( !dec ) {
       missing = oldLastType.cast<Cpp::MissingDeclarationType>();
@@ -1918,7 +1918,7 @@ void ExpressionVisitor::createDelayedType( AST* node , bool expression ) {
       if(!m_hadMemberAccess)
         helper.setFunctionNameForADL(QualifiedIdentifier(dec->identifier()));
     }
-    
+
     ViableFunction viable;
 
     //Resolve functions normally
@@ -1930,7 +1930,7 @@ void ExpressionVisitor::createDelayedType( AST* node , bool expression ) {
       if(viable.isValid())
         chosenFunction = viable.declaration();
     }
-    
+
     if( !chosenFunction && constructedType )
     {
       //Default-constructor is used
@@ -1947,7 +1947,7 @@ void ExpressionVisitor::createDelayedType( AST* node , bool expression ) {
       m_parameters = oldParams;
       return;
     }
-    
+
     if( !chosenFunction && !m_strict ) {
       //Because we do not want to rely too much on our understanding of the code, we take the first function instead of totally failing.
 #ifdef DEBUG_FUNCTION_CALLS
@@ -1975,7 +1975,7 @@ void ExpressionVisitor::createDelayedType( AST* node , bool expression ) {
       //Since not all parameters could be evaluated, Choose the first function
       chosenFunction = declarations.front();
     }
-    
+
     if(missing && viable.isValid())
     {
       // Remove the MissingDeclarationProblem which has been created alongside MissingDeclarationType
@@ -1990,7 +1990,7 @@ void ExpressionVisitor::createDelayedType( AST* node , bool expression ) {
         }
       }
     }
-    
+
     clearLast();
 
     if( constructedType ) {
@@ -2010,11 +2010,11 @@ void ExpressionVisitor::createDelayedType( AST* node , bool expression ) {
       if(missing)
         m_lastType = missing.cast<AbstractType>(); // Forward the MissingType, as it will be used for assistants.
     }
-    
+
     if(chosenFunction)
       if(m_mapAst) session()->mapCallAstToType(node, chosenFunction->type<FunctionType>());
 
-    static IndexedString functionCallOperatorIdentifier("operator()");
+    static const IndexedString functionCallOperatorIdentifier("operator()");
 
     bool createUseOnParen = (bool)chosenFunction && (constructedType || chosenFunction->identifier().identifier() == functionCallOperatorIdentifier);
     //Re-create the use we have discarded earlier, this time with the correct overloaded function chosen.
@@ -2055,8 +2055,6 @@ void ExpressionVisitor::createDelayedType( AST* node , bool expression ) {
   void ExpressionVisitor::visitSignalSlotExpression(SignalSlotExpressionAST* node) {
 
     //So uses for the argument-types are built
-    LOCKDUCHAIN;
-
     putStringType();
 
     if(m_parameters.isEmpty())
@@ -2064,6 +2062,7 @@ void ExpressionVisitor::createDelayedType( AST* node , bool expression ) {
 
     DUContext* container = 0;///@todo check whether signal/slot match, warn if not.
 
+    LOCKDUCHAIN;
     StructureType::Ptr slotStructure = TypeUtils::targetType(TypeUtils::matchingClassPointer(qObjectPtrType(), TypeUtils::realType(m_parameters.back().type, m_topContext), m_topContext), m_topContext).cast<StructureType>();
     if(slotStructure)
       container = slotStructure->internalContext(m_topContext);
@@ -2205,7 +2204,6 @@ void ExpressionVisitor::createDelayedType( AST* node , bool expression ) {
   void ExpressionVisitor::visitSizeofExpression(SizeofExpressionAST* node)  {
     visit(node->type_id);
     visit(node->expression);
-    LOCKDUCHAIN;
     m_lastType = AbstractType::Ptr( new KDevelop::IntegralType(IntegralType::TypeInt) );
     m_lastInstance = Instance(true);
   }
@@ -2213,7 +2211,6 @@ void ExpressionVisitor::createDelayedType( AST* node , bool expression ) {
   void ExpressionVisitor::visitCondition(ConditionAST* node)
   {
     DefaultVisitor::visitCondition(node);
-    LOCKDUCHAIN;
     m_lastType = AbstractType::Ptr( new KDevelop::IntegralType(IntegralType::TypeBoolean) );
     m_lastInstance = Instance(true);
   }
@@ -2245,7 +2242,6 @@ void ExpressionVisitor::createDelayedType( AST* node , bool expression ) {
 
 
   void ExpressionVisitor::visitStringLiteral(StringLiteralAST* /*node*/) {
-    LOCKDUCHAIN;
     ///TODO: proper support for wchar_t, char16_t and char32_t strings
     putStringType();
   }
@@ -2270,7 +2266,7 @@ void ExpressionVisitor::createDelayedType( AST* node , bool expression ) {
         helper.setOperator( OverloadResolver::Parameter(m_lastType, isLValue( m_lastType, m_lastInstance ), m_lastInstance.declaration.data() ) );
 
         //Overloaded postfix operators have one additional int parameter
-        static AbstractType::Ptr integer = AbstractType::Ptr(new ConstantIntegralType(IntegralType::TypeInt));
+        static const AbstractType::Ptr integer = AbstractType::Ptr(new ConstantIntegralType(IntegralType::TypeInt));
         helper.setKnownParameters( OverloadResolver::Parameter( integer, false ) );
 
         ViableFunction viable = helper.resolve();
