@@ -18,15 +18,14 @@
 
 #include "macronavigationcontext.h"
 
-#include <QtGui/QTextDocument>
+#include <QTextDocument>
 
-#include <KLocale>
+#include <KLocalizedString>
 
 #include <KTextEditor/Editor>
 #include <KTextEditor/Document>
 #include <KTextEditor/View>
 #include <KTextEditor/ConfigInterface>
-#include <KTextEditor/HighlightInterface>
 
 #include <language/duchain/duchain.h>
 #include <interfaces/icore.h>
@@ -54,6 +53,7 @@ KTextEditor::View* createDocAndView(const QString& data, KTextEditor::Document**
   doc->setMode("C++");
   doc->setReadWrite(false);
   KTextEditor::View* view = doc->createView(0);
+  view->setStatusBarEnabled(false);
   if (KTextEditor::ConfigInterface* config = qobject_cast<KTextEditor::ConfigInterface*>(view)) {
     config->setConfigValue("icon-bar", false);
     config->setConfigValue("folding-bar", false);
@@ -132,16 +132,17 @@ QString MacroNavigationContext::html(bool shorten)
     args += ')';
   }
 
-  const KUrl url = m_macro->file.toUrl();
-  const QString path = url.pathOrUrl();
-  NavigationAction action(url, KTextEditor::Cursor(m_macro->sourceLine,0));
+  const QUrl url = m_macro->file.toUrl();
+  const QString path = url.toLocalFile();
+  KTextEditor::Cursor cursor(m_macro->sourceLine, 0);
+  NavigationAction action(url, cursor);
   modifyHtml() += i18nc("%1: macro type, i.e.: 'Function macro' or just 'Macro'"
                         "%2: the macro name and arguments"
                         "%3 the link to the definition",
                         "%1: %2, defined in %3",
                         (m_macro->function_like ? i18n("Function macro") : i18n("Macro")),
                         importantHighlight(m_macro->name.str()) + args,
-                        createLink(path, path, action) );
+                        createLink(QString("%1 :%2").arg(path).arg(cursor.line()+1), path, action));
 
   modifyHtml() += fontSizeSuffix(shorten) + "</p></body></html>";
   return currentHtml();
