@@ -20,7 +20,7 @@
 #include "cppduchain/typeutils.h"
 #include <language/duchain/ducontext.h>
 #include <language/duchain/declaration.h>
-#include <language/duchain/indexedstring.h>
+#include <serialization/indexedstring.h>
 #include <language/duchain/classfunctiondeclaration.h>
 #include "cppduchain/cpptypes.h"
 #include "viablefunctions.h"
@@ -30,6 +30,7 @@
 #include <QtAlgorithms>
 #include "adlhelper.h"
 #include "typeconversion.h"
+#include "debug.h"
 #include <language/duchain/persistentsymboltable.h>
 
 using namespace Cpp;
@@ -98,15 +99,15 @@ Declaration* OverloadResolver::resolve( const ParameterList& params, const Quali
 
   if (!resolvedDecl && functionName.count() == 1) {
     // start ADL lookup
-    
+
     QList<Declaration*> adlDecls = computeADLCandidates( params, functionName );
-    
+
     resolvedDecl = resolveList( params, adlDecls, noUserDefinedConversion );
 #ifdef DEBUG_ADL
     if (resolvedDecl)
-      kDebug() << "ADL found " << resolvedDecl->toString();
+      qCDebug(CPPDUCHAIN) << "ADL found " << resolvedDecl->toString();
     else
-      kDebug() << "ADL failed";
+      qCDebug(CPPDUCHAIN) << "ADL failed";
 #endif
   }
   return resolvedDecl;
@@ -199,14 +200,14 @@ Declaration* OverloadResolver::resolveList( const ParameterList& params, const Q
   for ( QSet<Declaration*>::const_iterator it = newDeclarations.constBegin(); it != newDeclarations.constEnd(); ++it )
   {
     Declaration* decl = applyImplicitTemplateParameters( params, *it );
-    ifDebugOverloadResolution(qDebug() << (*it)->toString() << decl; )
+    ifDebugOverloadResolution(qCDebug(CPPDUCHAIN) << (*it)->toString() << decl; )
     if ( !decl )
       continue;
 
     ViableFunction viable( m_topContext.data(), decl, m_constness, noUserDefinedConversion );
     viable.matchParameters( params );
 
-    ifDebugOverloadResolution(qDebug() << decl->toString() << viable.isBetter(bestViableFunction); )
+    ifDebugOverloadResolution(qCDebug(CPPDUCHAIN) << decl->toString() << viable.isBetter(bestViableFunction); )
     if ( viable.isBetter( bestViableFunction ) )
     {
       bestViableFunction = viable;
@@ -240,9 +241,9 @@ QList< ViableFunction > OverloadResolver::resolveListOffsetted( const ParameterL
   {
     ParameterList mergedParams = it.value();
     mergedParams.parameters += params.parameters;
-    
+
     Declaration* decl = applyImplicitTemplateParameters( mergedParams, it.key() );
-    ifDebugOverloadResolution(qDebug() << it.key()->toString() << decl; )
+    ifDebugOverloadResolution(qCDebug(CPPDUCHAIN) << it.key()->toString() << decl; )
     if ( !decl )
       continue;
 
@@ -255,7 +256,7 @@ QList< ViableFunction > OverloadResolver::resolveListOffsetted( const ParameterL
     viableFunctions << viable;
   }
 
-  qSort( viableFunctions );
+  std::sort(viableFunctions.begin(), viableFunctions.end());
 
   return viableFunctions;
 }
@@ -265,7 +266,7 @@ ViableFunction OverloadResolver::resolveListViable( const ParameterList& params,
   if ( !m_context || !m_topContext )
     return ViableFunction();
 
-  ifDebugOverloadResolution(qDebug() << "resolveListViable" << params; )
+  ifDebugOverloadResolution(qCDebug(CPPDUCHAIN) << "resolveListViable" << params; )
   ///Iso c++ draft 13.3.3
   m_worstConversionRank = ExactMatch;
 
@@ -280,16 +281,16 @@ ViableFunction OverloadResolver::resolveListViable( const ParameterList& params,
   {
     ParameterList mergedParams = it.value();
     mergedParams.parameters += params.parameters;
-    
+
     Declaration* decl = applyImplicitTemplateParameters( mergedParams, it.key() );
-    ifDebugOverloadResolution(qDebug() << it.key()->toString() << decl; )
+    ifDebugOverloadResolution(qCDebug(CPPDUCHAIN) << it.key()->toString() << decl; )
     if ( !decl )
       continue;
-    
+
     ViableFunction viable( m_topContext.data(), decl, m_constness );
     viable.matchParameters( mergedParams, partial );
 
-    ifDebugOverloadResolution(qDebug() << decl->toString() << viable.isBetter(bestViableFunction); )
+    ifDebugOverloadResolution(qCDebug(CPPDUCHAIN) << decl->toString() << viable.isBetter(bestViableFunction); )
     if ( viable.isBetter( bestViableFunction ) )
     {
       bestViableFunction = viable;
@@ -316,7 +317,7 @@ Declaration* OverloadResolver::applyImplicitTemplateParameters( const ParameterL
   FunctionType::Ptr functionType = declaration->type<FunctionType>();
   if ( !functionType )
   {
-    kDebug( 9007 ) << "Template function has no function type";
+    qCDebug(CPPDUCHAIN) << "Template function has no function type";
     return declaration;
   }
 
@@ -391,7 +392,7 @@ uint OverloadResolver::matchParameterTypes( const AbstractType::Ptr& argumentTyp
   if ( !argumentType || !parameterType )
     return 0;
 
-  ifDebugOverloadResolution( kDebug() << "matching" << argumentType->toString() << "to" << parameterType->toString(); )
+  ifDebugOverloadResolution( qCDebug(CPPDUCHAIN) << "matching" << argumentType->toString() << "to" << parameterType->toString(); )
 
   if ( instantiatedTypes.isEmpty() )
     return 1;
@@ -433,12 +434,12 @@ uint OverloadResolver::matchParameterTypes( const AbstractType::Ptr& argumentTyp
     if ( decl )
     {
       IndexedString id = decl->identifier().identifier();
-      if ( instantiatedTypes[id].isNull() )
+      if ( !instantiatedTypes[id] )
       {
         instantiatedTypes[id] = argumentType;
         return 1;
       }
-      else if ( instantiatedTypes[id]->equals( argumentType.unsafeData() ) )
+      else if ( instantiatedTypes[id]->equals( argumentType.data() ) )
       {
         return 1;
       }
@@ -451,8 +452,8 @@ uint OverloadResolver::matchParameterTypes( const AbstractType::Ptr& argumentTyp
   }
 
   ///Match assigned template-parameters, for example when matching QList<int> to QList<T>, assign int to T.
-  const IdentifiedType* identifiedArgument = dynamic_cast<const IdentifiedType*>( argumentType.unsafeData() );
-  const IdentifiedType* identifiedParameter = dynamic_cast<const IdentifiedType*>( parameterType.unsafeData() );
+  const IdentifiedType* identifiedArgument = dynamic_cast<const IdentifiedType*>( argumentType.data() );
+  const IdentifiedType* identifiedParameter = dynamic_cast<const IdentifiedType*>( parameterType.data() );
 
   if ( identifiedArgument && identifiedParameter )
   {
@@ -498,14 +499,14 @@ QList<Declaration *> OverloadResolver::computeADLCandidates( const ParameterList
   // Don't try to do ADL if there are delayed/unresolved types involved,
   // because then we cannot get a proper match as to ViableFunction anyway
   foreach( const Parameter & param, params.parameters ) {
-      if( fastCast<DelayedType*>(param.type.unsafeData()) ) {
-          ifDebugOverloadResolution(qDebug() << "Skipping ADL due to delayed types" << identifier << params; )
+      if( fastCast<DelayedType*>(param.type.data()) ) {
+          ifDebugOverloadResolution(qCDebug(CPPDUCHAIN) << "Skipping ADL due to delayed types" << identifier << params; )
           return QList<Declaration *>();
       }
   }
-  
+
   ADLHelper adlHelper( m_context, m_topContext );
-  
+
   foreach( const Parameter & param, params.parameters )
     adlHelper.addArgument( param );
 
@@ -514,33 +515,33 @@ QList<Declaration *> OverloadResolver::computeADLCandidates( const ParameterList
 #ifdef DEBUG_ADL
   foreach( QualifiedIdentifier ns, adlNamespaces )
   {
-    kDebug() << "  ADL found namespace: " << ns.toString();
+    qCDebug(CPPDUCHAIN) << "  ADL found namespace: " << ns.toString();
   }
 #endif
 
   QList<Declaration*> adlDecls;
 
 #ifdef DEBUG_ADL
-    kDebug() << "  ADL candidates for: " << identifier << params << params.parameters.size();
+    qCDebug(CPPDUCHAIN) << "  ADL candidates for: " << identifier << params << params.parameters.size();
 #endif
 
   foreach( QualifiedIdentifier adlFunctionName, adlNamespaces )
   {
     adlFunctionName += identifier;
-    
+
     // By using DeclarationId, we prevent a lot of complex logic which we don't require, as we
     // already have the fully qualified scope.
     PersistentSymbolTable::FilteredDeclarationIterator decls =
         PersistentSymbolTable::self().getFilteredDeclarations(IndexedQualifiedIdentifier(adlFunctionName), m_topContext->recursiveImportIndices());
-    
+
     for(; decls; ++decls)
     {
       Declaration* decl = decls->data();
       if(decl && decl->isFunctionDeclaration()) {
       adlDecls << decl;
 #ifdef DEBUG_ADL
-    kDebug() << "    ADL candidate: " << adlFunctionName << decl->toString();
-#endif      
+    qCDebug(CPPDUCHAIN) << "    ADL candidate: " << adlFunctionName << decl->toString();
+#endif
       }
     }
   }
@@ -553,7 +554,7 @@ AbstractType::Ptr getContainerType( AbstractType::Ptr type, int depth, TopDUCont
   for ( int a = 0; a < depth; a++ )
   {
     AbstractType::Ptr real = TypeUtils::realType( type, topContext );
-    IdentifiedType* idType = dynamic_cast<IdentifiedType*>( real.unsafeData() );
+    IdentifiedType* idType = dynamic_cast<IdentifiedType*>( real.data() );
     if ( !idType )
       return AbstractType::Ptr();
 
@@ -573,7 +574,7 @@ AbstractType::Ptr getContainerType( AbstractType::Ptr type, int depth, TopDUCont
 
 uint OverloadResolver::matchParameterTypes( AbstractType::Ptr argumentType, const IndexedTypeIdentifier& parameterType, QMap<IndexedString, AbstractType::Ptr>& instantiatedTypes, bool keepValue ) const
 {
-  ifDebugOverloadResolution( kDebug() << "1 matching" << argumentType->toString() << "to" << parameterType.toString() << parameterType.pointerDepth(); )
+  ifDebugOverloadResolution( qCDebug(CPPDUCHAIN) << "1 matching" << argumentType->toString() << "to" << parameterType.toString() << parameterType.pointerDepth(); )
   if ( !argumentType )
     return 1;
   if ( instantiatedTypes.isEmpty() )
@@ -627,7 +628,7 @@ uint OverloadResolver::matchParameterTypes( AbstractType::Ptr argumentType, cons
 
 uint OverloadResolver::matchParameterTypes( AbstractType::Ptr argumentType, const Identifier& parameterType, QMap<IndexedString, AbstractType::Ptr>& instantiatedTypes, bool keepValue ) const
 {
-  ifDebugOverloadResolution( kDebug() << "2 matching" << argumentType->toString() << "to" << parameterType.toString(); )
+  ifDebugOverloadResolution( qCDebug(CPPDUCHAIN) << "2 matching" << argumentType->toString() << "to" << parameterType.toString(); )
 
   if ( !argumentType )
     return 1;
@@ -645,7 +646,7 @@ uint OverloadResolver::matchParameterTypes( AbstractType::Ptr argumentType, cons
     return 1;
   }
 
-  IdentifiedType* identifiedArgument = dynamic_cast<IdentifiedType*>( argumentType.unsafeData() );
+  IdentifiedType* identifiedArgument = dynamic_cast<IdentifiedType*>( argumentType.data() );
   if ( !identifiedArgument )
     return 0;
 
@@ -673,7 +674,7 @@ uint OverloadResolver::matchParameterTypes( AbstractType::Ptr argumentType, cons
     }
     else
     {
-      kDebug( 9007 ) << "Template-declaration missing template-parameter context";
+      qCDebug(CPPDUCHAIN) << "Template-declaration missing template-parameter context";
     }
   }
 
