@@ -27,6 +27,7 @@
 
 #include "expressionvisitor.h"
 #include "typeconversion.h"
+#include "debug.h"
 #include <parsesession.h>
 
 #include <KLocalizedString>
@@ -134,7 +135,7 @@ class UseExpressionVisitor : public Cpp::ExpressionVisitor {
     reportRealProblems(true);
   }
   ~UseExpressionVisitor() {
-    typedef KSharedPtr<KDevelop::Problem> P;
+    typedef QExplicitlySharedDataPointer<KDevelop::Problem> P;
     foreach(const P& problem, realProblems())
       m_builder->addProblem(problem);
   }
@@ -142,15 +143,15 @@ class UseExpressionVisitor : public Cpp::ExpressionVisitor {
 
     virtual void usingDeclaration(AST* node,
                                   size_t start_token, size_t end_token,
-                                  const KDevelop::DeclarationPointer& decl) {
+                                  const KDevelop::DeclarationPointer& decl) override {
       RangeInRevision range = m_builder->editor()->findRange(start_token, end_token);
       m_builder->newUse(node, range, decl);
 
       if (decl && decl->isExplicitlyDeleted()) {
-        KSharedPtr<KDevelop::Problem> problem(new Problem);
+        QExplicitlySharedDataPointer<KDevelop::Problem> problem(new Problem);
         problem->setDescription(i18n("Use of deleted function: %1", decl->identifier().toString()));
 
-        problem->setSource(KDevelop::ProblemData::SemanticAnalysis);
+        problem->setSource(IProblem::SemanticAnalysis);
 
         CppEditorIntegrator editor(session());
         Q_ASSERT(topContext());
@@ -161,11 +162,11 @@ class UseExpressionVisitor : public Cpp::ExpressionVisitor {
       }
     }
 
-    virtual void problem(AST* node, const QString& str) {
+    virtual void problem(AST* node, const QString& str) override {
       if(m_dumpProblems)
         Cpp::ExpressionVisitor::problem(node, str);
 /*      else
-        kDebug(9007) << "problem";*/
+        qCDebug(CPPDUCHAIN) << "problem";*/
     }
 
     UseBuilder* m_builder;
@@ -177,7 +178,7 @@ void UseBuilder::visitExpression(AST* node) {
   UseExpressionVisitor visitor( editor()->parseSession(), this, false, m_mapAst );
   if( !node->ducontext )
     node->ducontext = currentContext();
-  
+
   visitor.parse( node );
 }
 
@@ -197,7 +198,7 @@ void UseBuilder::buildUsesForName(NameAST* name) {
     if(name) {
       if( !name->ducontext )
         name->ducontext = currentContext();
-      
+
       visitor.parse( name );
     }
   }
@@ -211,16 +212,16 @@ void UseBuilder::visitMemInitializer(MemInitializerAST * node)
 {
   if( !node->ducontext )
     node->ducontext = currentContext();
-  
+
   UseExpressionVisitor visitor( editor()->parseSession(), this, false, m_mapAst );
-    
+
   visitor.parse( node );
 }
 
 void UseBuilder::visitElaboratedTypeSpecifier(ElaboratedTypeSpecifierAST* node)
 {
   UseBuilderBase::visitElaboratedTypeSpecifier(node);
-  
+
   if(!node->isDeclaration) {
     UseExpressionVisitor visitor( editor()->parseSession(), this, false, m_mapAst );
     if( !node->ducontext ) {
@@ -229,7 +230,7 @@ void UseBuilder::visitElaboratedTypeSpecifier(ElaboratedTypeSpecifierAST* node)
       else
         node->ducontext = currentContext();
     }
-    
+
     visitor.parse( node );
   }
 }
@@ -248,9 +249,9 @@ void UseBuilder::visitSimpleDeclaration(SimpleDeclarationAST* node)
       else
         node->ducontext = currentContext();
     }
-    
+
     visitor.parse( node );
-    
+
     // Build uses for the name-prefixes of init declarators
     const ListNode<InitDeclaratorAST*>
       *it = node->init_declarators->toFront(),
@@ -267,14 +268,14 @@ void UseBuilder::visitSimpleDeclaration(SimpleDeclarationAST* node)
       it = it->next;
     } while (it != end);
   }else{
-    DefaultVisitor::visitSimpleDeclaration(node);    
+    DefaultVisitor::visitSimpleDeclaration(node);
   }
 }
 
 void UseBuilder::visitSimpleTypeSpecifier(SimpleTypeSpecifierAST* node)
 {
   UseBuilderBase::visitSimpleTypeSpecifier(node);
-  
+
   UseExpressionVisitor visitor( editor()->parseSession(), this, false, m_mapAst );
   if( !node->ducontext ) {
     if(lastContext() && lastContext()->type() == DUContext::Template && lastContext()->parentContext() == currentContext())
@@ -282,7 +283,7 @@ void UseBuilder::visitSimpleTypeSpecifier(SimpleTypeSpecifierAST* node)
     else
       node->ducontext = currentContext();
   }
-  
+
   visitor.parse( node );
 }
 
@@ -319,7 +320,7 @@ void UseBuilder::visitTypeId(TypeIdAST* node) {
 
     visitor.parse( node );
   }
-  
+
   UseBuilderBase::visitTypeId(node);
 }
 
@@ -335,10 +336,10 @@ void UseBuilder::visitUsing(UsingAST *node)
   UseBuilderBase::visitUsing(node);
 }
 
-void UseBuilder::addProblem(KSharedPtr< KDevelop::Problem > problem) {
+void UseBuilder::addProblem(QExplicitlySharedDataPointer< KDevelop::Problem > problem) {
   m_problems << problem;
 }
 
-QList< KSharedPtr< KDevelop::Problem > > UseBuilder::problems() const {
+QList< QExplicitlySharedDataPointer< KDevelop::Problem > > UseBuilder::problems() const {
   return m_problems;
 }
