@@ -30,7 +30,6 @@
 
 #include <QDateTime>
 #include <QThread>
-#include <QTimer>
 #include <QMutex>
 
 namespace rpp {
@@ -44,15 +43,8 @@ class SimpleRefactoring;
 
 namespace KDevelop {
   class ICodeHighlighting;
-  class SimpleRange;
   class CodeCompletion;
 }
-namespace Cpp {
-  class StaticCodeAssistant;
-}
-namespace CppTools {
-  class IncludePathResolver;
-}
 
 ///A class that helps detecting what exactly makes the UI block. To use it, just place a breakpoint on UIBlockTester::lockup() and inspect the execution-position of the main thread
 class UIBlockTester : public QObject {
@@ -60,7 +52,7 @@ Q_OBJECT
   class UIBlockTesterThread : public QThread {
     public:
       UIBlockTesterThread( UIBlockTester& parent );
-      void run();
+      void run() override;
       void stop();
     private:
       UIBlockTester& m_parent;
@@ -97,23 +89,22 @@ public:
     explicit CppLanguageSupport( QObject* parent, const QVariantList& args = QVariantList() );
     virtual ~CppLanguageSupport();
 
-    QString name() const;
+    QString name() const override;
 
-    KDevelop::ICodeHighlighting *codeHighlighting() const;
-    KDevelop::BasicRefactoring* refactoring() const;
-    KDevelop::ILanguage *language();
-    KDevelop::ContextMenuExtension contextMenuExtension(KDevelop::Context* context);
-    KDevelop::ParseJob *createParseJob( const KDevelop::IndexedString &url );
+    KDevelop::ICodeHighlighting *codeHighlighting() const override;
+    KDevelop::BasicRefactoring* refactoring() const override;
+    KDevelop::ContextMenuExtension contextMenuExtension(KDevelop::Context* context) override;
+    KDevelop::ParseJob *createParseJob( const KDevelop::IndexedString &url ) override;
     //KDevelop::AstRepresentationPtr  generateAst(const KDevelop::TopDUContext & topContext);
-    KDevelop::ICreateClassHelper* createClassHelper() const;
+    KDevelop::ICreateClassHelper* createClassHelper() const override;
     
     static CppLanguageSupport* self();
 
-    virtual QString indentationSample() const {
+    virtual QString indentationSample() const override {
       return "class C{\n class D {\n void c() {\n int m;\n }\n }\n};\n";
     }
     
-    virtual void createActionsForMainWindow(Sublime::MainWindow* window, QString& xmlFile, KActionCollection& actions);
+    virtual void createActionsForMainWindow(Sublime::MainWindow* window, QString& xmlFile, KActionCollection& actions) override;
 /**
  * There may be multiple differnt parsed versions of a document available in the du-chain.
  * This function helps choosing the right one, by creating a standard parsing-environment,
@@ -127,38 +118,35 @@ public:
  *
  * @warning The du-chain must be locked before calling this.
 * */
-  virtual KDevelop::TopDUContext *standardContext(const KUrl& url, bool proxyContext = false);
+  virtual KDevelop::TopDUContext *standardContext(const QUrl &url, bool proxyContext = false) override;
 
     /**
      * IBuddyDocumentFinder overrides.
      */
-    virtual bool areBuddies(const KUrl& url1, const KUrl& url2);
-    virtual bool buddyOrder(const KUrl& url1, const KUrl& url2);
-    virtual QVector<KUrl> getPotentialBuddies(const KUrl& url) const;
+    virtual bool areBuddies(const QUrl &url1, const QUrl& url2) override;
+    virtual bool buddyOrder(const QUrl &url1, const QUrl& url2) override;
+    virtual QVector<QUrl> getPotentialBuddies(const QUrl &url) const override;
 
 public slots:
     void findIncludePathsForJob(CPPParseJob* job);
 
-    ///UI:
-    void switchDefinitionDeclaration();
-
 private:
 
     //Returns the identifier and its range under the cursor as first return-value, and the tail behind it as the second
     //If the given line is an include directive, the complete line is returned starting at the directive
-    QPair<QPair<QString, KDevelop::SimpleRange>, QString> cursorIdentifier(const KUrl& url, const KDevelop::SimpleCursor& position) const;
+    QPair<QPair<QString, KTextEditor::Range>, QString> cursorIdentifier(const QUrl &url, const KTextEditor::Cursor& position) const;
 
-    QPair<KDevelop::TopDUContextPointer, KDevelop::SimpleRange> importedContextForPosition(const KUrl& url, const KDevelop::SimpleCursor& position);
+    QPair<KDevelop::TopDUContextPointer, KTextEditor::Range> importedContextForPosition(const QUrl &url, const KTextEditor::Cursor& position);
 
-    QPair<KDevelop::SimpleRange, const rpp::pp_macro*> usedMacroForPosition(const KUrl& url, const KDevelop::SimpleCursor& position);
+    QPair<KTextEditor::Range, const rpp::pp_macro> usedMacroForPosition(const QUrl &url, const KTextEditor::Cursor& position);
 
-    virtual KDevelop::SimpleRange specialLanguageObjectRange(const KUrl& url, const KDevelop::SimpleCursor& position);
+    virtual KTextEditor::Range specialLanguageObjectRange(const QUrl &url, const KTextEditor::Cursor& position) override;
 
-    virtual QPair<KUrl, KDevelop::SimpleCursor> specialLanguageObjectJumpCursor(const KUrl& url, const KDevelop::SimpleCursor& position);
+    virtual QPair<QUrl, KTextEditor::Cursor> specialLanguageObjectJumpCursor(const QUrl &url, const KTextEditor::Cursor& position) override;
 
-    virtual QWidget* specialLanguageObjectNavigationWidget(const KUrl& url, const KDevelop::SimpleCursor& position);
+    virtual QWidget* specialLanguageObjectNavigationWidget(const QUrl &url, const KTextEditor::Cursor& position) override;
 
-    bool isFunctionLike(const rpp::pp_macro* pm, const KUrl& url);
+    bool isFunctionLike(const rpp::pp_macro& pm, const QUrl& url);
 
     static CppLanguageSupport* m_self;
 
@@ -167,8 +155,6 @@ private:
     KDevelop::CodeCompletion *m_cc;
 
     IncludeFileDataProvider* m_quickOpenDataProvider;
-    
-    const QStringList m_mimeTypes;
 };
 
 #endif
