@@ -48,7 +48,7 @@
 QString preprocess(const QString& contents) {
   rpp::Preprocessor preprocessor;
   rpp::pp pp(&preprocessor);
-  QByteArray qba = stringFromContents(pp.processFile("anonymous", contents.toUtf8()));
+  QByteArray qba = stringFromContents(pp.processFile("/anonymous", contents.toUtf8()));
   if(pp.problems().empty())
     return QString::fromUtf8(qba);
   else
@@ -388,39 +388,39 @@ void TestParser::testComments5()
   QCOMPARE(problem_list.size(), initial_size + 6); // 6 to-dos
   KDevelop::ProblemPointer problem = problem_list[initial_size];
   QCOMPARE(problem->description(), QString("FIXME comment"));
-  QCOMPARE(problem->source(), KDevelop::ProblemData::ToDo);
-  QCOMPARE(problem->finalLocation().start, KDevelop::SimpleCursor(1, 4));
-  QCOMPARE(problem->finalLocation().end, KDevelop::SimpleCursor(1, 17));
+  QCOMPARE(problem->source(), KDevelop::IProblem::ToDo);
+  QCOMPARE(problem->finalLocation().start(), KTextEditor::Cursor(1, 4));
+  QCOMPARE(problem->finalLocation().end(), KTextEditor::Cursor(1, 17));
 
   problem = problem_list[initial_size + 1];
   QCOMPARE(problem->description(), QString("this is TODO"));
-  QCOMPARE(problem->source(), KDevelop::ProblemData::ToDo);
-  QCOMPARE(problem->finalLocation().start, KDevelop::SimpleCursor(2, 3));
-  QCOMPARE(problem->finalLocation().end, KDevelop::SimpleCursor(2, 15));
+  QCOMPARE(problem->source(), KDevelop::IProblem::ToDo);
+  QCOMPARE(problem->finalLocation().start(), KTextEditor::Cursor(2, 3));
+  QCOMPARE(problem->finalLocation().end(), KTextEditor::Cursor(2, 15));
 
   problem = problem_list[initial_size + 2];
   QCOMPARE(problem->description(), QString("TODO: comment"));
-  QCOMPARE(problem->source(), KDevelop::ProblemData::ToDo);
-  QCOMPARE(problem->finalLocation().start, KDevelop::SimpleCursor(3, 4));
-  QCOMPARE(problem->finalLocation().end, KDevelop::SimpleCursor(3, 17));
+  QCOMPARE(problem->source(), KDevelop::IProblem::ToDo);
+  QCOMPARE(problem->finalLocation().start(), KTextEditor::Cursor(3, 4));
+  QCOMPARE(problem->finalLocation().end(), KTextEditor::Cursor(3, 17));
 
   problem = problem_list[initial_size + 3];
   QCOMPARE(problem->description(), QString("another TODO"));
-  QCOMPARE(problem->source(), KDevelop::ProblemData::ToDo);
-  QCOMPARE(problem->finalLocation().start, KDevelop::SimpleCursor(4, 13));
-  QCOMPARE(problem->finalLocation().end, KDevelop::SimpleCursor(4, 25));
+  QCOMPARE(problem->source(), KDevelop::IProblem::ToDo);
+  QCOMPARE(problem->finalLocation().start(), KTextEditor::Cursor(4, 13));
+  QCOMPARE(problem->finalLocation().end(), KTextEditor::Cursor(4, 25));
 
   problem = problem_list[initial_size + 4];
   QCOMPARE(problem->description(), QString("TODO COMMENT"));
-  QCOMPARE(problem->source(), KDevelop::ProblemData::ToDo);
-  QCOMPARE(problem->finalLocation().start, KDevelop::SimpleCursor(8, 4));
-  QCOMPARE(problem->finalLocation().end, KDevelop::SimpleCursor(8, 16));
+  QCOMPARE(problem->source(), KDevelop::IProblem::ToDo);
+  QCOMPARE(problem->finalLocation().start(), KTextEditor::Cursor(8, 4));
+  QCOMPARE(problem->finalLocation().end(), KTextEditor::Cursor(8, 16));
 
   problem = problem_list[initial_size + 5];
   QCOMPARE(problem->description(), QString::fromUtf8("Non-ascii TODO 例えば"));
-  QCOMPARE(problem->source(), KDevelop::ProblemData::ToDo);
-  QCOMPARE(problem->finalLocation().start, KDevelop::SimpleCursor(10, 3));
-  QCOMPARE(problem->finalLocation().end, KDevelop::SimpleCursor(10, 27));
+  QCOMPARE(problem->source(), KDevelop::IProblem::ToDo);
+  QCOMPARE(problem->finalLocation().start(), KTextEditor::Cursor(10, 3));
+  QCOMPARE(problem->finalLocation().end(), KTextEditor::Cursor(10, 27));
 }
 
 void TestParser::testComments6() {
@@ -576,11 +576,11 @@ void TestParser::testEmptyInclude()
   // testcase for https://bugs.kde.org/show_bug.cgi?id=258972
   rpp::Preprocessor preprocessor;
   rpp::pp pp(&preprocessor);
-  pp.processFile("anonymous", QByteArray("#include\n\nint main(){\n    ;\n}\n"));
+  pp.processFile("/anonymous", QByteArray("#include\n\nint main(){\n    ;\n}\n"));
   QCOMPARE(pp.problems().size(), 1);
   qDebug() << pp.problems().first()->description();
-  QCOMPARE(pp.problems().first()->finalLocation().start, KDevelop::SimpleCursor(0, 8));
-  QCOMPARE(pp.problems().first()->finalLocation().end, KDevelop::SimpleCursor(0, 8));
+  QCOMPARE(pp.problems().first()->finalLocation().start(), KTextEditor::Cursor(0, 8));
+  QCOMPARE(pp.problems().first()->finalLocation().end(), KTextEditor::Cursor(0, 8));
 }
 
 void TestParser::testCondition()
@@ -963,7 +963,7 @@ void TestParser::testTernaryEmptyExpression()
   TranslationUnitAST* ast = parse(code);
   dumper.dump(ast, lastSession->token_stream);
   QCOMPARE(control.problems().count(), 1);
-  QCOMPARE(control.problems().first()->severity(), KDevelop::ProblemData::Warning);
+  QCOMPARE(control.problems().first()->severity(), KDevelop::IProblem::Warning);
   QVERIFY(ast);
 }
 
@@ -975,7 +975,7 @@ TranslationUnitAST* TestParser::parse(const QByteArray& unit)
 
   rpp::Preprocessor preprocessor;
   rpp::pp pp(&preprocessor);
-  lastSession->setContentsAndGenerateLocationTable(pp.processFile("anonymous", unit));
+  lastSession->setContentsAndGenerateLocationTable(pp.processFile("/anonymous", unit));
   return  parser.parse(lastSession);
 }
 
@@ -984,7 +984,7 @@ void TestParser::dump(AST* node)
   dumper.dump(node, lastSession->token_stream);
   if (!control.problems().isEmpty()) {
     foreach(const KDevelop::ProblemPointer&p, control.problems()) {
-      qDebug() << p->description() << p->explanation() << p->finalLocation().textRange();
+      qDebug() << p->description() << p->explanation() << p->finalLocation();
     }
   }
 }
@@ -1006,7 +1006,7 @@ struct HasKindVisitor : protected DefaultVisitor
     return ast != 0;
   }
 
-  void visit(AST* node)
+  void visit(AST* node) override
   {
     if (!ast && node) {
       if (node->kind == kind && --num < 0) {
@@ -1033,6 +1033,5 @@ AST* TestParser::getAST(AST* ast, AST::NODE_KIND kind, int num)
   return visitor.ast;
 }
 
-#include "test_parser.moc"
 
 QTEST_MAIN(TestParser)
