@@ -16,8 +16,8 @@
    Boston, MA 02110-1301, USA.
 */
 
-#ifndef TestCppAssistants_H
-#define TestCppAssistants_H
+#ifndef TEST_CPPASSISTANTS_H
+#define TEST_CPPASSISTANTS_H
 
 #include <QObject>
 
@@ -29,6 +29,7 @@ private slots:
   void cleanupTestCase();
   void testRenameAssistant_data();
   void testRenameAssistant();
+  void testRenameAssistantUndoRename();
   void testSignatureAssistant_data();
   void testSignatureAssistant();
   void testMacroExpansion();
