@@ -17,14 +17,14 @@
    Boston, MA 02110-1301, USA.
 */
 
-#ifndef TestCppCodeCompletion_H
-#define TestCppCodeCompletion_H
+#ifndef TEST_CPPCODECOMPLETION_H
+#define TEST_CPPCODECOMPLETION_H
 
 #include <QObject>
 #include <QByteArray>
 #include <QMap>
 
-#include <kurl.h>
+#include <QUrl>
 
 #include <language/editor/cursorinrevision.h>
 #include <language/duchain/identifier.h>
@@ -174,9 +174,9 @@ private:
   friend class TestPreprocessor;
 
   //Preprocesses the text, and parses all included strings within the correct context. Only strings that were added using addInclude(..) can be parsed. The url is only neede for the EnvironmentFile.
-  QString preprocess( const IndexedString& url, const QString& text, IncludeFileList& included, rpp::pp* parent = 0, bool stopAfterHeaders = false, KSharedPtr<Cpp::EnvironmentFile>* = 0, rpp::LocationTable** returnLocationTable = 0L, PreprocessedContents* contents = 0L );
+  QString preprocess( const IndexedString& url, const QString& text, IncludeFileList& included, rpp::pp* parent = 0, bool stopAfterHeaders = false, QExplicitlySharedDataPointer<Cpp::EnvironmentFile>* = 0, rpp::LocationTable** returnLocationTable = 0L, PreprocessedContents* contents = 0L );
 
-  KDevelop::TopDUContext* parse(const QByteArray& unit, DumpAreas dump = static_cast<DumpAreas>(DumpAST | DumpDUChain | DumpType), rpp::pp* parent = 0, KUrl identity = KUrl(), TopDUContext* update = 0);
+  KDevelop::TopDUContext* parse(const QByteArray& unit, DumpAreas dump = static_cast<DumpAreas>(DumpAST | DumpDUChain | DumpType), rpp::pp* parent = 0, QUrl identity = QUrl(), TopDUContext* update = 0);
 
   void release(KDevelop::DUContext* top);
 
