@@ -21,12 +21,4 @@
 
 #include "debugarea.h"
 
-namespace KDevelop {
-
-int definesAndIncludesDebugArea()
-{
-    static int area = KDebug::registerArea("kdevdefinesandincludes");
-    return area;
-}
-
-}
+Q_LOGGING_CATEGORY(DEFINESANDINCLUDES, "kdevelop.definesandincludes")
