@@ -1341,10 +1341,10 @@ void DeclarationBuilder::closeAndAssignType()
     closeType();
     Declaration* dec = currentDeclaration();
     Q_ASSERT(dec);
-    Q_ASSERT(lastType());
-    {
+
+    if (auto type = lastType()) {
         DUChainWriteLocker lock;
-        dec->setType(lastType());
+        dec->setType(type);
     }
     closeDeclaration();
 }
@@ -1429,7 +1429,7 @@ AbstractType::Ptr DeclarationBuilder::typeFromClassName(const QString& name)
 
 void DeclarationBuilder::addBaseClass(ClassDeclaration* classDecl, const QString& name)
 {
-    addBaseClass(classDecl, typeFromClassName(name)->indexed());
+    addBaseClass(classDecl, IndexedType(typeFromClassName(name)));
 }
 
 void DeclarationBuilder::addBaseClass(ClassDeclaration* classDecl, const IndexedType& type)
