@@ -43,6 +43,8 @@
 #include <interfaces/ilanguagecontroller.h>
 #include <interfaces/contextmenuextension.h>
 
+#include <QReadWriteLock>
+
 K_PLUGIN_FACTORY_WITH_JSON(KDevQmlJsSupportFactory, "kdevqmljs.json", registerPlugin<KDevQmlJsPlugin>(); )
 
 using namespace KDevelop;
@@ -82,6 +84,10 @@ KDevQmlJsPlugin::KDevQmlJsPlugin(QObject* parent, const QVariantList& )
 
 KDevQmlJsPlugin::~KDevQmlJsPlugin()
 {
+    parseLock()->lockForWrite();
+    // By locking the parse-mutexes, we make sure that parse jobs get a chance to finish in a good state
+    parseLock()->unlock();
+
     QmlJS::unregisterDUChainItems();
 }
 
@@ -182,7 +188,7 @@ QWidget* KDevQmlJsPlugin::specialLanguageObjectNavigationWidget(const QUrl& url,
         // if the property key is listed in the supported properties.
         QPair<KTextEditor::Range, KTextEditor::Range> property = parseProperty(doc->textDocument()->line(position.line()), position);
         if ( property.first.isValid() && property.second.isValid() ) {
-            Declaration* decl = DUChainUtils::itemUnderCursor(url, property.first.start());
+            Declaration* decl = DUChainUtils::itemUnderCursor(url, property.first.start()).declaration;
 
             return PropertyPreviewWidget::constructIfPossible(
                 doc->textDocument(),
