@@ -21,7 +21,6 @@
 #include "cmakeloadprojecttest.h"
 #include "cmake-test-paths.h"
 
-#include <qtest_kde.h>
 #include <language/duchain/duchainlock.h>
 #include <language/duchain/duchain.h>
 #include <language/duchain/topducontext.h>
@@ -40,7 +39,7 @@
 inline QDebug &operator<<(QDebug debug, const Target &target)
 { debug << target.name; return debug.maybeSpace(); }
 
-QTEST_KDEMAIN( CMakeLoadProjectTest, GUI )
+QTEST_MAIN( CMakeLoadProjectTest )
 
 using namespace KDevelop;
 
@@ -64,6 +63,27 @@ void CMakeLoadProjectTest::testTinyCMakeProject()
     QCOMPARE(v.vm.value("CMAKE_INCLUDE_CURRENT_DIR"), QStringList("OFF"));
 }
 
+#if QT_VERSION <= 0x050000
+void CMakeLoadProjectTest::testBug335803()
+{
+    CMakeProjectData v = parseProject(CMAKE_TESTS_PROJECTS_DIR "/bug335803");
+    QCOMPARE(v.projectName, QString("bug335803"));
+    QStringList names;
+    foreach(const Target& t, v.targets) {
+        names << t.name;
+    }
+    QCOMPARE(v.targets.count(), 8);
+    names.sort();
+    QCOMPARE(names[0], QLatin1String("echo-a"));
+    QCOMPARE(names[1], QLatin1String("echo-b"));
+    QCOMPARE(names[2], QLatin1String("echo-custom_name"));
+    QCOMPARE(names[3], QLatin1String("echo-d"));
+    QCOMPARE(names[4], QLatin1String("echo2-a"));
+    QCOMPARE(names[5], QLatin1String("echo2-b"));
+    QCOMPARE(names[6], QLatin1String("echo2-custom_name"));
+    QCOMPARE(names[7], QLatin1String("echo2-d")); // This one was missing before bug #335803 got fixed
+}
+
 void CMakeLoadProjectTest::testSmallQt4Project()
 {
     CMakeProjectData v = parseProject(CMAKE_TESTS_PROJECTS_DIR "/qt4app");
@@ -106,6 +126,7 @@ void CMakeLoadProjectTest::testSmallKDE4Project()
     QCOMPARE(v.targets.at( uninstallIdx ).name, QString("uninstall") );
     QCOMPARE(v.vm.value("CMAKE_INCLUDE_CURRENT_DIR"), QStringList("ON"));
 }
+#endif
 
 void CMakeLoadProjectTest::testSmallProjectWithTests()
 {
@@ -121,6 +142,7 @@ void CMakeLoadProjectTest::testSmallProjectWithTests()
     QCOMPARE(v.testSuites.at(3).arguments.at(0), QString("4"));
 }
 
+#if QT_VERSION <= 0x050000
 void CMakeLoadProjectTest::testKDE4ProjectWithTests()
 {
     CMakeProjectData v = parseProject(CMAKE_TESTS_PROJECTS_DIR "/unit_tests_kde");
@@ -130,6 +152,7 @@ void CMakeLoadProjectTest::testKDE4ProjectWithTests()
     QCOMPARE(v.testSuites.at(0).name, QString("cmake-test-unittestskde"));
     QCOMPARE(v.testSuites.at(0).arguments.count(), 0);
 }
+#endif
 
 CMakeProjectData CMakeLoadProjectTest::parseProject( const QString& sourcedir )
 {
@@ -185,5 +208,4 @@ CMakeProjectData CMakeLoadProjectTest::parseProject( const QString& sourcedir )
     return data;
 }
 
-#include "cmakeloadprojecttest.moc"
 
