@@ -21,6 +21,7 @@
 #include "testhelpers.h"
 #include "cmakemodelitems.h"
 #include "cmakeutils.h"
+#include "cmakeimportjsonjob.h"
 #include <icmakemanager.h>
 
 #include <qtest.h>
@@ -39,6 +40,8 @@ using namespace KDevelop;
 
 void TestCMakeManager::initTestCase()
 {
+    QLoggingCategory::setFilterRules(QStringLiteral("*.debug=false\ndefault.debug=true\nkdevelop.projectmanagers.cmake.debug=true\n"));
+
     AutoTestShell::init();
     TestCore::initialize();
 
@@ -332,3 +335,15 @@ void TestCMakeManager::testFaultyTarget()
 {
     loadProject("faulty_target");
 }
+
+void TestCMakeManager::testParenthesesInTestArguments()
+{
+    IProject* project = loadProject("parentheses_in_test_arguments");
+
+    Path sourceDir = project->path();
+    Path buildDir(sourceDir, "build/");
+
+    CMakeImportJob* job = new CMakeImportJob(project, this);
+    job->start();
+
+}
