@@ -20,60 +20,60 @@
 #include "kcm_custombuildsystem.h"
 
 #include <KPluginFactory>
+#include <KAboutData>
 #include <QVBoxLayout>
 
+#include <interfaces/icore.h>
+#include <interfaces/iprojectcontroller.h>
+
 #include "custombuildsystemconfigwidget.h"
-#include "kcfg_custombuildsystemconfig.h"
-#include <language/backgroundparser/parseprojectjob.h>
-#include <interfaces/iruncontroller.h>
 
-K_PLUGIN_FACTORY(CustomBuildSystemKCModuleFactory, registerPlugin<CustomBuildSystemKCModule>(); )
-K_EXPORT_PLUGIN(CustomBuildSystemKCModuleFactory("kcm_kdevcustombuildsystem", "kdevcustombuildsystem"))
-
-CustomBuildSystemKCModule::CustomBuildSystemKCModule( QWidget* parent, const QVariantList& args )
-    : ProjectKCModule<CustomBuildSystemSettings>( CustomBuildSystemKCModuleFactory::componentData(), parent, args )
+CustomBuildSystemKCModule::CustomBuildSystemKCModule(KDevelop::IPlugin* plugin, const KDevelop::ProjectConfigOptions& options, QWidget* parent)
+    : ProjectConfigPage<CustomBuildSystemSettings>(plugin, options, parent)
 {
     QVBoxLayout* layout = new QVBoxLayout( this );
     configWidget = new CustomBuildSystemConfigWidget( this );
-    connect( configWidget, SIGNAL(changed()), SLOT(dataChanged()) );
+    connect(configWidget, &CustomBuildSystemConfigWidget::changed, this, &ConfigPage::changed);
     layout->addWidget( configWidget );
-
-    addConfig( CustomBuildSystemSettings::self(), configWidget );
 }
 
-void CustomBuildSystemKCModule::dataChanged()
-{
-    emit changed(true);
-}
-
-
 CustomBuildSystemKCModule::~CustomBuildSystemKCModule()
 {
 }
 
-void CustomBuildSystemKCModule::load()
+void CustomBuildSystemKCModule::reset()
 {
-    KCModule::load();
-    configWidget->loadFrom( CustomBuildSystemSettings::self()->config() );
+    ProjectConfigPage::reset();
+    configWidget->loadFrom(CustomBuildSystemSettings::self()->config());
 }
 
-void CustomBuildSystemKCModule::save()
+void CustomBuildSystemKCModule::apply()
 {
-    configWidget->saveTo( CustomBuildSystemSettings::self()->config(), project() );
-    KCModule::save();
-
-    // Do this once all saving is done. This makes the widget itself usable with very little from KDevPlatform
-    if ( KDevelop::IProjectController::parseAllProjectSources()) {
-        KJob* parseProjectJob = new KDevelop::ParseProjectJob(project());
-        KDevelop::ICore::self()->runController()->registerJob(parseProjectJob);
+    configWidget->saveTo(CustomBuildSystemSettings::self()->config(), project());
+    ProjectConfigPage::apply();
+    if (KDevelop::IProjectController::parseAllProjectSources()) {
+        KDevelop::ICore::self()->projectController()->reparseProject(project());
     }
 }
 
 void CustomBuildSystemKCModule::defaults()
 {
-    KCModule::defaults();
+    ProjectConfigPage::defaults();
     configWidget->loadDefaults();
 }
 
-#include "kcm_custombuildsystem.moc"
+QString CustomBuildSystemKCModule::name() const
+{
+    return i18n("Custom BuildSystem");
+}
+
+QString CustomBuildSystemKCModule::fullName() const
+{
+    return i18n("Configure a projects custom build tool and includes/defines for the language support.");
+}
+
+QIcon CustomBuildSystemKCModule::icon() const
+{
+    return QIcon::fromTheme("kdevelop");
+}
 
